tests:
  - name: "{{ tool_prefix }}_get retrieves a resource"
    tool: "{{ tool_prefix }}_get"
    input:
      resource_id: "123"
    expect:
      status: "success"
      content_contains: "Resource 123"

  - name: "{{ tool_prefix }}_search returns results"
    tool: "{{ tool_prefix }}_search"
    input:
      query: "test"
    expect:
      status: "success"
