{
  "name": "{{ server_name }}",
  "version": "0.1.0",
  "description": "{{ description }}",
  "type": "module",
  "main": "dist/server.js",
  "bin": {
    "{{ server_name }}": "dist/server.js"
  },
  "scripts": {
    "build": "tsc",
    "start": "node dist/server.js",
    "dev": "tsc --watch"
  },
  "dependencies": {
    "@modelcontextprotocol/sdk": "^1.0.0"
  },
  "devDependencies": {
    "typescript": "^5.5.0",
    "@types/node": "^22.0.0"
  }
}
