[project]
name = "{{ server_name }}"
version = "0.1.0"
description = "{{ description }}"
readme = "README.md"
requires-python = ">=3.11"
{% if author %}authors = [{ name = "{{ author }}" }]
{% endif %}
dependencies = [
    "fastmcp>=2.0",
    "uvicorn>=0.30",
]

[project.scripts]
{{ server_name }} = "{{ python_package }}.server:main"

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[tool.hdx]
server_module = "{{ python_package }}.server"
server_command = "python -m {{ python_package }}.server"
server_transport = "http"
server_host = "127.0.0.1"
server_port = "8000"
fixtures_dir = "tests/fixtures"
