name: {{ name }}
description: "{{ description }}"
version: "0.1.0"

model:
  provider: {{ provider }}
  model: {{ model }}
  max_tokens: 4096
  temperature: 0.0

system_prompt_file: ./prompts/system.md

servers: []

settings:
  max_tool_calls: 50
  tool_call_timeout: 30s
  retry_on_error: true
  max_retries: 1
  tool_namespacing: auto
