tests:
  - name: "{{ tool_prefix }}_hello returns greeting"
    tool: "{{ tool_prefix }}_hello"
    input:
      name: "Alice"
    expect:
      status: "success"
      content_contains: "Hello, Alice"

  - name: "{{ tool_prefix }}_hello with default name"
    tool: "{{ tool_prefix }}_hello"
    input: {}
    expect:
      status: "success"
      content_contains: "Hello, World"
