var gh=Object.defineProperty;var yh=(f,m,g)=>m in f?gh(f,m,{enumerable:!0,configurable:!0,writable:!0,value:g}):f[m]=g;var B0=(f,m,g)=>yh(f,typeof m!="symbol"?m+"":m,g);import{r as xh,N as vh,u as bh,a as L,O as ph,L as vt,b as Z0,B as jh,d as Sh,e as Jt}from"./react-vendor-C4GiKtGw.js";import{r as Nh,R as Dn,L as Us,C as On,X as Un,Y as Cn,T as Hn,a as En,b as zh,A as Ah,c as Th,B as Eh,d as V0,e as Mh}from"./recharts-DR6HDaZF.js";(function(){const m=document.createElement("link").relList;if(m&&m.supports&&m.supports("modulepreload"))return;for(const N of document.querySelectorAll('link[rel="modulepreload"]'))d(N);new MutationObserver(N=>{for(const T of N)if(T.type==="childList")for(const E of T.addedNodes)E.tagName==="LINK"&&E.rel==="modulepreload"&&d(E)}).observe(document,{childList:!0,subtree:!0});function g(N){const T={};return N.integrity&&(T.integrity=N.integrity),N.referrerPolicy&&(T.referrerPolicy=N.referrerPolicy),N.crossOrigin==="use-credentials"?T.credentials="include":N.crossOrigin==="anonymous"?T.credentials="omit":T.credentials="same-origin",T}function d(N){if(N.ep)return;N.ep=!0;const T=g(N);fetch(N.href,T)}})();var Ts={exports:{}},An={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var R0;function _h(){if(R0)return An;R0=1;var f=Symbol.for("react.transitional.element"),m=Symbol.for("react.fragment");function g(d,N,T){var E=null;if(T!==void 0&&(E=""+T),N.key!==void 0&&(E=""+N.key),"key"in N){T={};for(var C in N)C!=="key"&&(T[C]=N[C])}else T=N;return N=T.ref,{$$typeof:f,type:d,key:E,ref:N!==void 0?N:null,props:T}}return An.Fragment=m,An.jsx=g,An.jsxs=g,An}var q0;function Dh(){return q0||(q0=1,Ts.exports=_h()),Ts.exports}var i=Dh(),Es={exports:{}},Tn={},Ms={exports:{}},_s={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Y0;function Oh(){return Y0||(Y0=1,(function(f){function m(z,_){var q=z.length;z.push(_);l:for(;0<q;){var cl=q-1>>>1,sl=z[cl];if(0<N(sl,_))z[cl]=_,z[q]=sl,q=cl;else break l}}function g(z){return z.length===0?null:z[0]}function d(z){if(z.length===0)return null;var _=z[0],q=z.pop();if(q!==_){z[0]=q;l:for(var cl=0,sl=z.length,Ul=sl>>>1;cl<Ul;){var ol=2*(cl+1)-1,P=z[ol],Nl=ol+1,pt=z[Nl];if(0>N(P,q))Nl<sl&&0>N(pt,P)?(z[cl]=pt,z[Nl]=q,cl=Nl):(z[cl]=P,z[ol]=q,cl=ol);else if(Nl<sl&&0>N(pt,q))z[cl]=pt,z[Nl]=q,cl=Nl;else break l}}return _}function N(z,_){var q=z.sortIndex-_.sortIndex;return q!==0?q:z.id-_.id}if(f.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var T=performance;f.unstable_now=function(){return T.now()}}else{var E=Date,C=E.now();f.unstable_now=function(){return E.now()-C}}var M=[],Z=[],D=1,j=null,R=3,Y=!1,G=!1,V=!1,mt=!1,Tl=typeof setTimeout=="function"?setTimeout:null,je=typeof clearTimeout=="function"?clearTimeout:null,Hl=typeof setImmediate<"u"?setImmediate:null;function lt(z){for(var _=g(Z);_!==null;){if(_.callback===null)d(Z);else if(_.startTime<=z)d(Z),_.sortIndex=_.expirationTime,m(M,_);else break;_=g(Z)}}function Tt(z){if(V=!1,lt(z),!G)if(g(M)!==null)G=!0,Zl||(Zl=!0,jl());else{var _=g(Z);_!==null&&Et(Tt,_.startTime-z)}}var Zl=!1,ht=-1,tt=5,et=-1;function Le(){return mt?!0:!(f.unstable_now()-et<tt)}function il(){if(mt=!1,Zl){var z=f.unstable_now();et=z;var _=!0;try{l:{G=!1,V&&(V=!1,je(ht),ht=-1),Y=!0;var q=R;try{t:{for(lt(z),j=g(M);j!==null&&!(j.expirationTime>z&&Le());){var cl=j.callback;if(typeof cl=="function"){j.callback=null,R=j.priorityLevel;var sl=cl(j.expirationTime<=z);if(z=f.unstable_now(),typeof sl=="function"){j.callback=sl,lt(z),_=!0;break t}j===g(M)&&d(M),lt(z)}else d(M);j=g(M)}if(j!==null)_=!0;else{var Ul=g(Z);Ul!==null&&Et(Tt,Ul.startTime-z),_=!1}}break l}finally{j=null,R=q,Y=!1}_=void 0}}finally{_?jl():Zl=!1}}}var jl;if(typeof Hl=="function")jl=function(){Hl(il)};else if(typeof MessageChannel<"u"){var bt=new MessageChannel,Oa=bt.port2;bt.port1.onmessage=il,jl=function(){Oa.postMessage(null)}}else jl=function(){Tl(il,0)};function Et(z,_){ht=Tl(function(){z(f.unstable_now())},_)}f.unstable_IdlePriority=5,f.unstable_ImmediatePriority=1,f.unstable_LowPriority=4,f.unstable_NormalPriority=3,f.unstable_Profiling=null,f.unstable_UserBlockingPriority=2,f.unstable_cancelCallback=function(z){z.callback=null},f.unstable_forceFrameRate=function(z){0>z||125<z?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):tt=0<z?Math.floor(1e3/z):5},f.unstable_getCurrentPriorityLevel=function(){return R},f.unstable_next=function(z){switch(R){case 1:case 2:case 3:var _=3;break;default:_=R}var q=R;R=_;try{return z()}finally{R=q}},f.unstable_requestPaint=function(){mt=!0},f.unstable_runWithPriority=function(z,_){switch(z){case 1:case 2:case 3:case 4:case 5:break;default:z=3}var q=R;R=z;try{return _()}finally{R=q}},f.unstable_scheduleCallback=function(z,_,q){var cl=f.unstable_now();switch(typeof q=="object"&&q!==null?(q=q.delay,q=typeof q=="number"&&0<q?cl+q:cl):q=cl,z){case 1:var sl=-1;break;case 2:sl=250;break;case 5:sl=1073741823;break;case 4:sl=1e4;break;default:sl=5e3}return sl=q+sl,z={id:D++,callback:_,priorityLevel:z,startTime:q,expirationTime:sl,sortIndex:-1},q>cl?(z.sortIndex=q,m(Z,z),g(M)===null&&z===g(Z)&&(V?(je(ht),ht=-1):V=!0,Et(Tt,q-cl))):(z.sortIndex=sl,m(M,z),G||Y||(G=!0,Zl||(Zl=!0,jl()))),z},f.unstable_shouldYield=Le,f.unstable_wrapCallback=function(z){var _=R;return function(){var q=R;R=_;try{return z.apply(this,arguments)}finally{R=q}}}})(_s)),_s}var Q0;function Uh(){return Q0||(Q0=1,Ms.exports=Oh()),Ms.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var X0;function Ch(){if(X0)return Tn;X0=1;var f=Uh(),m=xh(),g=Nh();function d(l){var t="https://react.dev/errors/"+l;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var e=2;e<arguments.length;e++)t+="&args[]="+encodeURIComponent(arguments[e])}return"Minified React error #"+l+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function N(l){return!(!l||l.nodeType!==1&&l.nodeType!==9&&l.nodeType!==11)}function T(l){var t=l,e=l;if(l.alternate)for(;t.return;)t=t.return;else{l=t;do t=l,(t.flags&4098)!==0&&(e=t.return),l=t.return;while(l)}return t.tag===3?e:null}function E(l){if(l.tag===13){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function C(l){if(l.tag===31){var t=l.memoizedState;if(t===null&&(l=l.alternate,l!==null&&(t=l.memoizedState)),t!==null)return t.dehydrated}return null}function M(l){if(T(l)!==l)throw Error(d(188))}function Z(l){var t=l.alternate;if(!t){if(t=T(l),t===null)throw Error(d(188));return t!==l?null:l}for(var e=l,a=t;;){var n=e.return;if(n===null)break;var u=n.alternate;if(u===null){if(a=n.return,a!==null){e=a;continue}break}if(n.child===u.child){for(u=n.child;u;){if(u===e)return M(n),l;if(u===a)return M(n),t;u=u.sibling}throw Error(d(188))}if(e.return!==a.return)e=n,a=u;else{for(var c=!1,s=n.child;s;){if(s===e){c=!0,e=n,a=u;break}if(s===a){c=!0,a=n,e=u;break}s=s.sibling}if(!c){for(s=u.child;s;){if(s===e){c=!0,e=u,a=n;break}if(s===a){c=!0,a=u,e=n;break}s=s.sibling}if(!c)throw Error(d(189))}}if(e.alternate!==a)throw Error(d(190))}if(e.tag!==3)throw Error(d(188));return e.stateNode.current===e?l:t}function D(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l;for(l=l.child;l!==null;){if(t=D(l),t!==null)return t;l=l.sibling}return null}var j=Object.assign,R=Symbol.for("react.element"),Y=Symbol.for("react.transitional.element"),G=Symbol.for("react.portal"),V=Symbol.for("react.fragment"),mt=Symbol.for("react.strict_mode"),Tl=Symbol.for("react.profiler"),je=Symbol.for("react.consumer"),Hl=Symbol.for("react.context"),lt=Symbol.for("react.forward_ref"),Tt=Symbol.for("react.suspense"),Zl=Symbol.for("react.suspense_list"),ht=Symbol.for("react.memo"),tt=Symbol.for("react.lazy"),et=Symbol.for("react.activity"),Le=Symbol.for("react.memo_cache_sentinel"),il=Symbol.iterator;function jl(l){return l===null||typeof l!="object"?null:(l=il&&l[il]||l["@@iterator"],typeof l=="function"?l:null)}var bt=Symbol.for("react.client.reference");function Oa(l){if(l==null)return null;if(typeof l=="function")return l.$$typeof===bt?null:l.displayName||l.name||null;if(typeof l=="string")return l;switch(l){case V:return"Fragment";case Tl:return"Profiler";case mt:return"StrictMode";case Tt:return"Suspense";case Zl:return"SuspenseList";case et:return"Activity"}if(typeof l=="object")switch(l.$$typeof){case G:return"Portal";case Hl:return l.displayName||"Context";case je:return(l._context.displayName||"Context")+".Consumer";case lt:var t=l.render;return l=l.displayName,l||(l=t.displayName||t.name||"",l=l!==""?"ForwardRef("+l+")":"ForwardRef"),l;case ht:return t=l.displayName||null,t!==null?t:Oa(l.type)||"Memo";case tt:t=l._payload,l=l._init;try{return Oa(l(t))}catch{}}return null}var Et=Array.isArray,z=m.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,_=g.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,q={pending:!1,data:null,method:null,action:null},cl=[],sl=-1;function Ul(l){return{current:l}}function ol(l){0>sl||(l.current=cl[sl],cl[sl]=null,sl--)}function P(l,t){sl++,cl[sl]=l.current,l.current=t}var Nl=Ul(null),pt=Ul(null),wt=Ul(null),Bn=Ul(null);function Rn(l,t){switch(P(wt,t),P(pt,l),P(Nl,null),t.nodeType){case 9:case 11:l=(l=t.documentElement)&&(l=l.namespaceURI)?n0(l):0;break;default:if(l=t.tagName,t=t.namespaceURI)t=n0(t),l=u0(t,l);else switch(l){case"svg":l=1;break;case"math":l=2;break;default:l=0}}ol(Nl),P(Nl,l)}function Ze(){ol(Nl),ol(pt),ol(wt)}function ci(l){l.memoizedState!==null&&P(Bn,l);var t=Nl.current,e=u0(t,l.type);t!==e&&(P(pt,l),P(Nl,e))}function qn(l){pt.current===l&&(ol(Nl),ol(pt)),Bn.current===l&&(ol(Bn),jn._currentValue=q)}var si,Cs;function Se(l){if(si===void 0)try{throw Error()}catch(e){var t=e.stack.trim().match(/\n( *(at )?)/);si=t&&t[1]||"",Cs=-1<e.stack.indexOf(`
    at`)?" (<anonymous>)":-1<e.stack.indexOf("@")?"@unknown:0:0":""}return`
`+si+l+Cs}var fi=!1;function di(l,t){if(!l||fi)return"";fi=!0;var e=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var A=function(){throw Error()};if(Object.defineProperty(A.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(A,[])}catch(b){var v=b}Reflect.construct(l,[],A)}else{try{A.call()}catch(b){v=b}l.call(A.prototype)}}else{try{throw Error()}catch(b){v=b}(A=l())&&typeof A.catch=="function"&&A.catch(function(){})}}catch(b){if(b&&v&&typeof b.stack=="string")return[b.stack,v.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var n=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");n&&n.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var u=a.DetermineComponentFrameRoot(),c=u[0],s=u[1];if(c&&s){var r=c.split(`
`),x=s.split(`
`);for(n=a=0;a<r.length&&!r[a].includes("DetermineComponentFrameRoot");)a++;for(;n<x.length&&!x[n].includes("DetermineComponentFrameRoot");)n++;if(a===r.length||n===x.length)for(a=r.length-1,n=x.length-1;1<=a&&0<=n&&r[a]!==x[n];)n--;for(;1<=a&&0<=n;a--,n--)if(r[a]!==x[n]){if(a!==1||n!==1)do if(a--,n--,0>n||r[a]!==x[n]){var p=`
`+r[a].replace(" at new "," at ");return l.displayName&&p.includes("<anonymous>")&&(p=p.replace("<anonymous>",l.displayName)),p}while(1<=a&&0<=n);break}}}finally{fi=!1,Error.prepareStackTrace=e}return(e=l?l.displayName||l.name:"")?Se(e):""}function K0(l,t){switch(l.tag){case 26:case 27:case 5:return Se(l.type);case 16:return Se("Lazy");case 13:return l.child!==t&&t!==null?Se("Suspense Fallback"):Se("Suspense");case 19:return Se("SuspenseList");case 0:case 15:return di(l.type,!1);case 11:return di(l.type.render,!1);case 1:return di(l.type,!0);case 31:return Se("Activity");default:return""}}function Hs(l){try{var t="",e=null;do t+=K0(l,e),e=l,l=l.return;while(l);return t}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}var ri=Object.prototype.hasOwnProperty,oi=f.unstable_scheduleCallback,mi=f.unstable_cancelCallback,J0=f.unstable_shouldYield,k0=f.unstable_requestPaint,Vl=f.unstable_now,w0=f.unstable_getCurrentPriorityLevel,Bs=f.unstable_ImmediatePriority,Rs=f.unstable_UserBlockingPriority,Yn=f.unstable_NormalPriority,$0=f.unstable_LowPriority,qs=f.unstable_IdlePriority,W0=f.log,F0=f.unstable_setDisableYieldValue,Ua=null,Kl=null;function $t(l){if(typeof W0=="function"&&F0(l),Kl&&typeof Kl.setStrictMode=="function")try{Kl.setStrictMode(Ua,l)}catch{}}var Jl=Math.clz32?Math.clz32:lo,I0=Math.log,P0=Math.LN2;function lo(l){return l>>>=0,l===0?32:31-(I0(l)/P0|0)|0}var Qn=256,Xn=262144,Gn=4194304;function Ne(l){var t=l&42;if(t!==0)return t;switch(l&-l){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return l&261888;case 262144:case 524288:case 1048576:case 2097152:return l&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return l&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return l}}function Ln(l,t,e){var a=l.pendingLanes;if(a===0)return 0;var n=0,u=l.suspendedLanes,c=l.pingedLanes;l=l.warmLanes;var s=a&134217727;return s!==0?(a=s&~u,a!==0?n=Ne(a):(c&=s,c!==0?n=Ne(c):e||(e=s&~l,e!==0&&(n=Ne(e))))):(s=a&~u,s!==0?n=Ne(s):c!==0?n=Ne(c):e||(e=a&~l,e!==0&&(n=Ne(e)))),n===0?0:t!==0&&t!==n&&(t&u)===0&&(u=n&-n,e=t&-t,u>=e||u===32&&(e&4194048)!==0)?t:n}function Ca(l,t){return(l.pendingLanes&~(l.suspendedLanes&~l.pingedLanes)&t)===0}function to(l,t){switch(l){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Ys(){var l=Gn;return Gn<<=1,(Gn&62914560)===0&&(Gn=4194304),l}function hi(l){for(var t=[],e=0;31>e;e++)t.push(l);return t}function Ha(l,t){l.pendingLanes|=t,t!==268435456&&(l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0)}function eo(l,t,e,a,n,u){var c=l.pendingLanes;l.pendingLanes=e,l.suspendedLanes=0,l.pingedLanes=0,l.warmLanes=0,l.expiredLanes&=e,l.entangledLanes&=e,l.errorRecoveryDisabledLanes&=e,l.shellSuspendCounter=0;var s=l.entanglements,r=l.expirationTimes,x=l.hiddenUpdates;for(e=c&~e;0<e;){var p=31-Jl(e),A=1<<p;s[p]=0,r[p]=-1;var v=x[p];if(v!==null)for(x[p]=null,p=0;p<v.length;p++){var b=v[p];b!==null&&(b.lane&=-536870913)}e&=~A}a!==0&&Qs(l,a,0),u!==0&&n===0&&l.tag!==0&&(l.suspendedLanes|=u&~(c&~t))}function Qs(l,t,e){l.pendingLanes|=t,l.suspendedLanes&=~t;var a=31-Jl(t);l.entangledLanes|=t,l.entanglements[a]=l.entanglements[a]|1073741824|e&261930}function Xs(l,t){var e=l.entangledLanes|=t;for(l=l.entanglements;e;){var a=31-Jl(e),n=1<<a;n&t|l[a]&t&&(l[a]|=t),e&=~n}}function Gs(l,t){var e=t&-t;return e=(e&42)!==0?1:gi(e),(e&(l.suspendedLanes|t))!==0?0:e}function gi(l){switch(l){case 2:l=1;break;case 8:l=4;break;case 32:l=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:l=128;break;case 268435456:l=134217728;break;default:l=0}return l}function yi(l){return l&=-l,2<l?8<l?(l&134217727)!==0?32:268435456:8:2}function Ls(){var l=_.p;return l!==0?l:(l=window.event,l===void 0?32:M0(l.type))}function Zs(l,t){var e=_.p;try{return _.p=l,t()}finally{_.p=e}}var Wt=Math.random().toString(36).slice(2),El="__reactFiber$"+Wt,Bl="__reactProps$"+Wt,Ve="__reactContainer$"+Wt,xi="__reactEvents$"+Wt,ao="__reactListeners$"+Wt,no="__reactHandles$"+Wt,Vs="__reactResources$"+Wt,Ba="__reactMarker$"+Wt;function vi(l){delete l[El],delete l[Bl],delete l[xi],delete l[ao],delete l[no]}function Ke(l){var t=l[El];if(t)return t;for(var e=l.parentNode;e;){if(t=e[Ve]||e[El]){if(e=t.alternate,t.child!==null||e!==null&&e.child!==null)for(l=o0(l);l!==null;){if(e=l[El])return e;l=o0(l)}return t}l=e,e=l.parentNode}return null}function Je(l){if(l=l[El]||l[Ve]){var t=l.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return l}return null}function Ra(l){var t=l.tag;if(t===5||t===26||t===27||t===6)return l.stateNode;throw Error(d(33))}function ke(l){var t=l[Vs];return t||(t=l[Vs]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function zl(l){l[Ba]=!0}var Ks=new Set,Js={};function ze(l,t){we(l,t),we(l+"Capture",t)}function we(l,t){for(Js[l]=t,l=0;l<t.length;l++)Ks.add(t[l])}var uo=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),ks={},ws={};function io(l){return ri.call(ws,l)?!0:ri.call(ks,l)?!1:uo.test(l)?ws[l]=!0:(ks[l]=!0,!1)}function Zn(l,t,e){if(io(t))if(e===null)l.removeAttribute(t);else{switch(typeof e){case"undefined":case"function":case"symbol":l.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){l.removeAttribute(t);return}}l.setAttribute(t,""+e)}}function Vn(l,t,e){if(e===null)l.removeAttribute(t);else{switch(typeof e){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(t);return}l.setAttribute(t,""+e)}}function Mt(l,t,e,a){if(a===null)l.removeAttribute(e);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":l.removeAttribute(e);return}l.setAttributeNS(t,e,""+a)}}function at(l){switch(typeof l){case"bigint":case"boolean":case"number":case"string":case"undefined":return l;case"object":return l;default:return""}}function $s(l){var t=l.type;return(l=l.nodeName)&&l.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function co(l,t,e){var a=Object.getOwnPropertyDescriptor(l.constructor.prototype,t);if(!l.hasOwnProperty(t)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var n=a.get,u=a.set;return Object.defineProperty(l,t,{configurable:!0,get:function(){return n.call(this)},set:function(c){e=""+c,u.call(this,c)}}),Object.defineProperty(l,t,{enumerable:a.enumerable}),{getValue:function(){return e},setValue:function(c){e=""+c},stopTracking:function(){l._valueTracker=null,delete l[t]}}}}function bi(l){if(!l._valueTracker){var t=$s(l)?"checked":"value";l._valueTracker=co(l,t,""+l[t])}}function Ws(l){if(!l)return!1;var t=l._valueTracker;if(!t)return!0;var e=t.getValue(),a="";return l&&(a=$s(l)?l.checked?"true":"false":l.value),l=a,l!==e?(t.setValue(l),!0):!1}function Kn(l){if(l=l||(typeof document<"u"?document:void 0),typeof l>"u")return null;try{return l.activeElement||l.body}catch{return l.body}}var so=/[\n"\\]/g;function nt(l){return l.replace(so,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function pi(l,t,e,a,n,u,c,s){l.name="",c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?l.type=c:l.removeAttribute("type"),t!=null?c==="number"?(t===0&&l.value===""||l.value!=t)&&(l.value=""+at(t)):l.value!==""+at(t)&&(l.value=""+at(t)):c!=="submit"&&c!=="reset"||l.removeAttribute("value"),t!=null?ji(l,c,at(t)):e!=null?ji(l,c,at(e)):a!=null&&l.removeAttribute("value"),n==null&&u!=null&&(l.defaultChecked=!!u),n!=null&&(l.checked=n&&typeof n!="function"&&typeof n!="symbol"),s!=null&&typeof s!="function"&&typeof s!="symbol"&&typeof s!="boolean"?l.name=""+at(s):l.removeAttribute("name")}function Fs(l,t,e,a,n,u,c,s){if(u!=null&&typeof u!="function"&&typeof u!="symbol"&&typeof u!="boolean"&&(l.type=u),t!=null||e!=null){if(!(u!=="submit"&&u!=="reset"||t!=null)){bi(l);return}e=e!=null?""+at(e):"",t=t!=null?""+at(t):e,s||t===l.value||(l.value=t),l.defaultValue=t}a=a??n,a=typeof a!="function"&&typeof a!="symbol"&&!!a,l.checked=s?l.checked:!!a,l.defaultChecked=!!a,c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(l.name=c),bi(l)}function ji(l,t,e){t==="number"&&Kn(l.ownerDocument)===l||l.defaultValue===""+e||(l.defaultValue=""+e)}function $e(l,t,e,a){if(l=l.options,t){t={};for(var n=0;n<e.length;n++)t["$"+e[n]]=!0;for(e=0;e<l.length;e++)n=t.hasOwnProperty("$"+l[e].value),l[e].selected!==n&&(l[e].selected=n),n&&a&&(l[e].defaultSelected=!0)}else{for(e=""+at(e),t=null,n=0;n<l.length;n++){if(l[n].value===e){l[n].selected=!0,a&&(l[n].defaultSelected=!0);return}t!==null||l[n].disabled||(t=l[n])}t!==null&&(t.selected=!0)}}function Is(l,t,e){if(t!=null&&(t=""+at(t),t!==l.value&&(l.value=t),e==null)){l.defaultValue!==t&&(l.defaultValue=t);return}l.defaultValue=e!=null?""+at(e):""}function Ps(l,t,e,a){if(t==null){if(a!=null){if(e!=null)throw Error(d(92));if(Et(a)){if(1<a.length)throw Error(d(93));a=a[0]}e=a}e==null&&(e=""),t=e}e=at(t),l.defaultValue=e,a=l.textContent,a===e&&a!==""&&a!==null&&(l.value=a),bi(l)}function We(l,t){if(t){var e=l.firstChild;if(e&&e===l.lastChild&&e.nodeType===3){e.nodeValue=t;return}}l.textContent=t}var fo=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function lf(l,t,e){var a=t.indexOf("--")===0;e==null||typeof e=="boolean"||e===""?a?l.setProperty(t,""):t==="float"?l.cssFloat="":l[t]="":a?l.setProperty(t,e):typeof e!="number"||e===0||fo.has(t)?t==="float"?l.cssFloat=e:l[t]=(""+e).trim():l[t]=e+"px"}function tf(l,t,e){if(t!=null&&typeof t!="object")throw Error(d(62));if(l=l.style,e!=null){for(var a in e)!e.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?l.setProperty(a,""):a==="float"?l.cssFloat="":l[a]="");for(var n in t)a=t[n],t.hasOwnProperty(n)&&e[n]!==a&&lf(l,n,a)}else for(var u in t)t.hasOwnProperty(u)&&lf(l,u,t[u])}function Si(l){if(l.indexOf("-")===-1)return!1;switch(l){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var ro=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),oo=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Jn(l){return oo.test(""+l)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":l}function _t(){}var Ni=null;function zi(l){return l=l.target||l.srcElement||window,l.correspondingUseElement&&(l=l.correspondingUseElement),l.nodeType===3?l.parentNode:l}var Fe=null,Ie=null;function ef(l){var t=Je(l);if(t&&(l=t.stateNode)){var e=l[Bl]||null;l:switch(l=t.stateNode,t.type){case"input":if(pi(l,e.value,e.defaultValue,e.defaultValue,e.checked,e.defaultChecked,e.type,e.name),t=e.name,e.type==="radio"&&t!=null){for(e=l;e.parentNode;)e=e.parentNode;for(e=e.querySelectorAll('input[name="'+nt(""+t)+'"][type="radio"]'),t=0;t<e.length;t++){var a=e[t];if(a!==l&&a.form===l.form){var n=a[Bl]||null;if(!n)throw Error(d(90));pi(a,n.value,n.defaultValue,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name)}}for(t=0;t<e.length;t++)a=e[t],a.form===l.form&&Ws(a)}break l;case"textarea":Is(l,e.value,e.defaultValue);break l;case"select":t=e.value,t!=null&&$e(l,!!e.multiple,t,!1)}}}var Ai=!1;function af(l,t,e){if(Ai)return l(t,e);Ai=!0;try{var a=l(t);return a}finally{if(Ai=!1,(Fe!==null||Ie!==null)&&(Cu(),Fe&&(t=Fe,l=Ie,Ie=Fe=null,ef(t),l)))for(t=0;t<l.length;t++)ef(l[t])}}function qa(l,t){var e=l.stateNode;if(e===null)return null;var a=e[Bl]||null;if(a===null)return null;e=a[t];l:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(l=l.type,a=!(l==="button"||l==="input"||l==="select"||l==="textarea")),l=!a;break l;default:l=!1}if(l)return null;if(e&&typeof e!="function")throw Error(d(231,t,typeof e));return e}var Dt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),Ti=!1;if(Dt)try{var Ya={};Object.defineProperty(Ya,"passive",{get:function(){Ti=!0}}),window.addEventListener("test",Ya,Ya),window.removeEventListener("test",Ya,Ya)}catch{Ti=!1}var Ft=null,Ei=null,kn=null;function nf(){if(kn)return kn;var l,t=Ei,e=t.length,a,n="value"in Ft?Ft.value:Ft.textContent,u=n.length;for(l=0;l<e&&t[l]===n[l];l++);var c=e-l;for(a=1;a<=c&&t[e-a]===n[u-a];a++);return kn=n.slice(l,1<a?1-a:void 0)}function wn(l){var t=l.keyCode;return"charCode"in l?(l=l.charCode,l===0&&t===13&&(l=13)):l=t,l===10&&(l=13),32<=l||l===13?l:0}function $n(){return!0}function uf(){return!1}function Rl(l){function t(e,a,n,u,c){this._reactName=e,this._targetInst=n,this.type=a,this.nativeEvent=u,this.target=c,this.currentTarget=null;for(var s in l)l.hasOwnProperty(s)&&(e=l[s],this[s]=e?e(u):u[s]);return this.isDefaultPrevented=(u.defaultPrevented!=null?u.defaultPrevented:u.returnValue===!1)?$n:uf,this.isPropagationStopped=uf,this}return j(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var e=this.nativeEvent;e&&(e.preventDefault?e.preventDefault():typeof e.returnValue!="unknown"&&(e.returnValue=!1),this.isDefaultPrevented=$n)},stopPropagation:function(){var e=this.nativeEvent;e&&(e.stopPropagation?e.stopPropagation():typeof e.cancelBubble!="unknown"&&(e.cancelBubble=!0),this.isPropagationStopped=$n)},persist:function(){},isPersistent:$n}),t}var Ae={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(l){return l.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Wn=Rl(Ae),Qa=j({},Ae,{view:0,detail:0}),mo=Rl(Qa),Mi,_i,Xa,Fn=j({},Qa,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Oi,button:0,buttons:0,relatedTarget:function(l){return l.relatedTarget===void 0?l.fromElement===l.srcElement?l.toElement:l.fromElement:l.relatedTarget},movementX:function(l){return"movementX"in l?l.movementX:(l!==Xa&&(Xa&&l.type==="mousemove"?(Mi=l.screenX-Xa.screenX,_i=l.screenY-Xa.screenY):_i=Mi=0,Xa=l),Mi)},movementY:function(l){return"movementY"in l?l.movementY:_i}}),cf=Rl(Fn),ho=j({},Fn,{dataTransfer:0}),go=Rl(ho),yo=j({},Qa,{relatedTarget:0}),Di=Rl(yo),xo=j({},Ae,{animationName:0,elapsedTime:0,pseudoElement:0}),vo=Rl(xo),bo=j({},Ae,{clipboardData:function(l){return"clipboardData"in l?l.clipboardData:window.clipboardData}}),po=Rl(bo),jo=j({},Ae,{data:0}),sf=Rl(jo),So={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},No={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},zo={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Ao(l){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(l):(l=zo[l])?!!t[l]:!1}function Oi(){return Ao}var To=j({},Qa,{key:function(l){if(l.key){var t=So[l.key]||l.key;if(t!=="Unidentified")return t}return l.type==="keypress"?(l=wn(l),l===13?"Enter":String.fromCharCode(l)):l.type==="keydown"||l.type==="keyup"?No[l.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Oi,charCode:function(l){return l.type==="keypress"?wn(l):0},keyCode:function(l){return l.type==="keydown"||l.type==="keyup"?l.keyCode:0},which:function(l){return l.type==="keypress"?wn(l):l.type==="keydown"||l.type==="keyup"?l.keyCode:0}}),Eo=Rl(To),Mo=j({},Fn,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),ff=Rl(Mo),_o=j({},Qa,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Oi}),Do=Rl(_o),Oo=j({},Ae,{propertyName:0,elapsedTime:0,pseudoElement:0}),Uo=Rl(Oo),Co=j({},Fn,{deltaX:function(l){return"deltaX"in l?l.deltaX:"wheelDeltaX"in l?-l.wheelDeltaX:0},deltaY:function(l){return"deltaY"in l?l.deltaY:"wheelDeltaY"in l?-l.wheelDeltaY:"wheelDelta"in l?-l.wheelDelta:0},deltaZ:0,deltaMode:0}),Ho=Rl(Co),Bo=j({},Ae,{newState:0,oldState:0}),Ro=Rl(Bo),qo=[9,13,27,32],Ui=Dt&&"CompositionEvent"in window,Ga=null;Dt&&"documentMode"in document&&(Ga=document.documentMode);var Yo=Dt&&"TextEvent"in window&&!Ga,df=Dt&&(!Ui||Ga&&8<Ga&&11>=Ga),rf=" ",of=!1;function mf(l,t){switch(l){case"keyup":return qo.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function hf(l){return l=l.detail,typeof l=="object"&&"data"in l?l.data:null}var Pe=!1;function Qo(l,t){switch(l){case"compositionend":return hf(t);case"keypress":return t.which!==32?null:(of=!0,rf);case"textInput":return l=t.data,l===rf&&of?null:l;default:return null}}function Xo(l,t){if(Pe)return l==="compositionend"||!Ui&&mf(l,t)?(l=nf(),kn=Ei=Ft=null,Pe=!1,l):null;switch(l){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return df&&t.locale!=="ko"?null:t.data;default:return null}}var Go={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function gf(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t==="input"?!!Go[l.type]:t==="textarea"}function yf(l,t,e,a){Fe?Ie?Ie.push(a):Ie=[a]:Fe=a,t=Xu(t,"onChange"),0<t.length&&(e=new Wn("onChange","change",null,e,a),l.push({event:e,listeners:t}))}var La=null,Za=null;function Lo(l){Ir(l,0)}function In(l){var t=Ra(l);if(Ws(t))return l}function xf(l,t){if(l==="change")return t}var vf=!1;if(Dt){var Ci;if(Dt){var Hi="oninput"in document;if(!Hi){var bf=document.createElement("div");bf.setAttribute("oninput","return;"),Hi=typeof bf.oninput=="function"}Ci=Hi}else Ci=!1;vf=Ci&&(!document.documentMode||9<document.documentMode)}function pf(){La&&(La.detachEvent("onpropertychange",jf),Za=La=null)}function jf(l){if(l.propertyName==="value"&&In(Za)){var t=[];yf(t,Za,l,zi(l)),af(Lo,t)}}function Zo(l,t,e){l==="focusin"?(pf(),La=t,Za=e,La.attachEvent("onpropertychange",jf)):l==="focusout"&&pf()}function Vo(l){if(l==="selectionchange"||l==="keyup"||l==="keydown")return In(Za)}function Ko(l,t){if(l==="click")return In(t)}function Jo(l,t){if(l==="input"||l==="change")return In(t)}function ko(l,t){return l===t&&(l!==0||1/l===1/t)||l!==l&&t!==t}var kl=typeof Object.is=="function"?Object.is:ko;function Va(l,t){if(kl(l,t))return!0;if(typeof l!="object"||l===null||typeof t!="object"||t===null)return!1;var e=Object.keys(l),a=Object.keys(t);if(e.length!==a.length)return!1;for(a=0;a<e.length;a++){var n=e[a];if(!ri.call(t,n)||!kl(l[n],t[n]))return!1}return!0}function Sf(l){for(;l&&l.firstChild;)l=l.firstChild;return l}function Nf(l,t){var e=Sf(l);l=0;for(var a;e;){if(e.nodeType===3){if(a=l+e.textContent.length,l<=t&&a>=t)return{node:e,offset:t-l};l=a}l:{for(;e;){if(e.nextSibling){e=e.nextSibling;break l}e=e.parentNode}e=void 0}e=Sf(e)}}function zf(l,t){return l&&t?l===t?!0:l&&l.nodeType===3?!1:t&&t.nodeType===3?zf(l,t.parentNode):"contains"in l?l.contains(t):l.compareDocumentPosition?!!(l.compareDocumentPosition(t)&16):!1:!1}function Af(l){l=l!=null&&l.ownerDocument!=null&&l.ownerDocument.defaultView!=null?l.ownerDocument.defaultView:window;for(var t=Kn(l.document);t instanceof l.HTMLIFrameElement;){try{var e=typeof t.contentWindow.location.href=="string"}catch{e=!1}if(e)l=t.contentWindow;else break;t=Kn(l.document)}return t}function Bi(l){var t=l&&l.nodeName&&l.nodeName.toLowerCase();return t&&(t==="input"&&(l.type==="text"||l.type==="search"||l.type==="tel"||l.type==="url"||l.type==="password")||t==="textarea"||l.contentEditable==="true")}var wo=Dt&&"documentMode"in document&&11>=document.documentMode,la=null,Ri=null,Ka=null,qi=!1;function Tf(l,t,e){var a=e.window===e?e.document:e.nodeType===9?e:e.ownerDocument;qi||la==null||la!==Kn(a)||(a=la,"selectionStart"in a&&Bi(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),Ka&&Va(Ka,a)||(Ka=a,a=Xu(Ri,"onSelect"),0<a.length&&(t=new Wn("onSelect","select",null,t,e),l.push({event:t,listeners:a}),t.target=la)))}function Te(l,t){var e={};return e[l.toLowerCase()]=t.toLowerCase(),e["Webkit"+l]="webkit"+t,e["Moz"+l]="moz"+t,e}var ta={animationend:Te("Animation","AnimationEnd"),animationiteration:Te("Animation","AnimationIteration"),animationstart:Te("Animation","AnimationStart"),transitionrun:Te("Transition","TransitionRun"),transitionstart:Te("Transition","TransitionStart"),transitioncancel:Te("Transition","TransitionCancel"),transitionend:Te("Transition","TransitionEnd")},Yi={},Ef={};Dt&&(Ef=document.createElement("div").style,"AnimationEvent"in window||(delete ta.animationend.animation,delete ta.animationiteration.animation,delete ta.animationstart.animation),"TransitionEvent"in window||delete ta.transitionend.transition);function Ee(l){if(Yi[l])return Yi[l];if(!ta[l])return l;var t=ta[l],e;for(e in t)if(t.hasOwnProperty(e)&&e in Ef)return Yi[l]=t[e];return l}var Mf=Ee("animationend"),_f=Ee("animationiteration"),Df=Ee("animationstart"),$o=Ee("transitionrun"),Wo=Ee("transitionstart"),Fo=Ee("transitioncancel"),Of=Ee("transitionend"),Uf=new Map,Qi="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Qi.push("scrollEnd");function gt(l,t){Uf.set(l,t),ze(t,[l])}var Pn=typeof reportError=="function"?reportError:function(l){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof l=="object"&&l!==null&&typeof l.message=="string"?String(l.message):String(l),error:l});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",l);return}console.error(l)},ut=[],ea=0,Xi=0;function lu(){for(var l=ea,t=Xi=ea=0;t<l;){var e=ut[t];ut[t++]=null;var a=ut[t];ut[t++]=null;var n=ut[t];ut[t++]=null;var u=ut[t];if(ut[t++]=null,a!==null&&n!==null){var c=a.pending;c===null?n.next=n:(n.next=c.next,c.next=n),a.pending=n}u!==0&&Cf(e,n,u)}}function tu(l,t,e,a){ut[ea++]=l,ut[ea++]=t,ut[ea++]=e,ut[ea++]=a,Xi|=a,l.lanes|=a,l=l.alternate,l!==null&&(l.lanes|=a)}function Gi(l,t,e,a){return tu(l,t,e,a),eu(l)}function Me(l,t){return tu(l,null,null,t),eu(l)}function Cf(l,t,e){l.lanes|=e;var a=l.alternate;a!==null&&(a.lanes|=e);for(var n=!1,u=l.return;u!==null;)u.childLanes|=e,a=u.alternate,a!==null&&(a.childLanes|=e),u.tag===22&&(l=u.stateNode,l===null||l._visibility&1||(n=!0)),l=u,u=u.return;return l.tag===3?(u=l.stateNode,n&&t!==null&&(n=31-Jl(e),l=u.hiddenUpdates,a=l[n],a===null?l[n]=[t]:a.push(t),t.lane=e|536870912),u):null}function eu(l){if(50<hn)throw hn=0,Wc=null,Error(d(185));for(var t=l.return;t!==null;)l=t,t=l.return;return l.tag===3?l.stateNode:null}var aa={};function Io(l,t,e,a){this.tag=l,this.key=e,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function wl(l,t,e,a){return new Io(l,t,e,a)}function Li(l){return l=l.prototype,!(!l||!l.isReactComponent)}function Ot(l,t){var e=l.alternate;return e===null?(e=wl(l.tag,t,l.key,l.mode),e.elementType=l.elementType,e.type=l.type,e.stateNode=l.stateNode,e.alternate=l,l.alternate=e):(e.pendingProps=t,e.type=l.type,e.flags=0,e.subtreeFlags=0,e.deletions=null),e.flags=l.flags&65011712,e.childLanes=l.childLanes,e.lanes=l.lanes,e.child=l.child,e.memoizedProps=l.memoizedProps,e.memoizedState=l.memoizedState,e.updateQueue=l.updateQueue,t=l.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},e.sibling=l.sibling,e.index=l.index,e.ref=l.ref,e.refCleanup=l.refCleanup,e}function Hf(l,t){l.flags&=65011714;var e=l.alternate;return e===null?(l.childLanes=0,l.lanes=t,l.child=null,l.subtreeFlags=0,l.memoizedProps=null,l.memoizedState=null,l.updateQueue=null,l.dependencies=null,l.stateNode=null):(l.childLanes=e.childLanes,l.lanes=e.lanes,l.child=e.child,l.subtreeFlags=0,l.deletions=null,l.memoizedProps=e.memoizedProps,l.memoizedState=e.memoizedState,l.updateQueue=e.updateQueue,l.type=e.type,t=e.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),l}function au(l,t,e,a,n,u){var c=0;if(a=l,typeof l=="function")Li(l)&&(c=1);else if(typeof l=="string")c=ah(l,e,Nl.current)?26:l==="html"||l==="head"||l==="body"?27:5;else l:switch(l){case et:return l=wl(31,e,t,n),l.elementType=et,l.lanes=u,l;case V:return _e(e.children,n,u,t);case mt:c=8,n|=24;break;case Tl:return l=wl(12,e,t,n|2),l.elementType=Tl,l.lanes=u,l;case Tt:return l=wl(13,e,t,n),l.elementType=Tt,l.lanes=u,l;case Zl:return l=wl(19,e,t,n),l.elementType=Zl,l.lanes=u,l;default:if(typeof l=="object"&&l!==null)switch(l.$$typeof){case Hl:c=10;break l;case je:c=9;break l;case lt:c=11;break l;case ht:c=14;break l;case tt:c=16,a=null;break l}c=29,e=Error(d(130,l===null?"null":typeof l,"")),a=null}return t=wl(c,e,t,n),t.elementType=l,t.type=a,t.lanes=u,t}function _e(l,t,e,a){return l=wl(7,l,a,t),l.lanes=e,l}function Zi(l,t,e){return l=wl(6,l,null,t),l.lanes=e,l}function Bf(l){var t=wl(18,null,null,0);return t.stateNode=l,t}function Vi(l,t,e){return t=wl(4,l.children!==null?l.children:[],l.key,t),t.lanes=e,t.stateNode={containerInfo:l.containerInfo,pendingChildren:null,implementation:l.implementation},t}var Rf=new WeakMap;function it(l,t){if(typeof l=="object"&&l!==null){var e=Rf.get(l);return e!==void 0?e:(t={value:l,source:t,stack:Hs(t)},Rf.set(l,t),t)}return{value:l,source:t,stack:Hs(t)}}var na=[],ua=0,nu=null,Ja=0,ct=[],st=0,It=null,jt=1,St="";function Ut(l,t){na[ua++]=Ja,na[ua++]=nu,nu=l,Ja=t}function qf(l,t,e){ct[st++]=jt,ct[st++]=St,ct[st++]=It,It=l;var a=jt;l=St;var n=32-Jl(a)-1;a&=~(1<<n),e+=1;var u=32-Jl(t)+n;if(30<u){var c=n-n%5;u=(a&(1<<c)-1).toString(32),a>>=c,n-=c,jt=1<<32-Jl(t)+n|e<<n|a,St=u+l}else jt=1<<u|e<<n|a,St=l}function Ki(l){l.return!==null&&(Ut(l,1),qf(l,1,0))}function Ji(l){for(;l===nu;)nu=na[--ua],na[ua]=null,Ja=na[--ua],na[ua]=null;for(;l===It;)It=ct[--st],ct[st]=null,St=ct[--st],ct[st]=null,jt=ct[--st],ct[st]=null}function Yf(l,t){ct[st++]=jt,ct[st++]=St,ct[st++]=It,jt=t.id,St=t.overflow,It=l}var Ml=null,fl=null,$=!1,Pt=null,ft=!1,ki=Error(d(519));function le(l){var t=Error(d(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw ka(it(t,l)),ki}function Qf(l){var t=l.stateNode,e=l.type,a=l.memoizedProps;switch(t[El]=l,t[Bl]=a,e){case"dialog":J("cancel",t),J("close",t);break;case"iframe":case"object":case"embed":J("load",t);break;case"video":case"audio":for(e=0;e<yn.length;e++)J(yn[e],t);break;case"source":J("error",t);break;case"img":case"image":case"link":J("error",t),J("load",t);break;case"details":J("toggle",t);break;case"input":J("invalid",t),Fs(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0);break;case"select":J("invalid",t);break;case"textarea":J("invalid",t),Ps(t,a.value,a.defaultValue,a.children)}e=a.children,typeof e!="string"&&typeof e!="number"&&typeof e!="bigint"||t.textContent===""+e||a.suppressHydrationWarning===!0||e0(t.textContent,e)?(a.popover!=null&&(J("beforetoggle",t),J("toggle",t)),a.onScroll!=null&&J("scroll",t),a.onScrollEnd!=null&&J("scrollend",t),a.onClick!=null&&(t.onclick=_t),t=!0):t=!1,t||le(l,!0)}function Xf(l){for(Ml=l.return;Ml;)switch(Ml.tag){case 5:case 31:case 13:ft=!1;return;case 27:case 3:ft=!0;return;default:Ml=Ml.return}}function ia(l){if(l!==Ml)return!1;if(!$)return Xf(l),$=!0,!1;var t=l.tag,e;if((e=t!==3&&t!==27)&&((e=t===5)&&(e=l.type,e=!(e!=="form"&&e!=="button")||rs(l.type,l.memoizedProps)),e=!e),e&&fl&&le(l),Xf(l),t===13){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(d(317));fl=r0(l)}else if(t===31){if(l=l.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(d(317));fl=r0(l)}else t===27?(t=fl,he(l.type)?(l=ys,ys=null,fl=l):fl=t):fl=Ml?rt(l.stateNode.nextSibling):null;return!0}function De(){fl=Ml=null,$=!1}function wi(){var l=Pt;return l!==null&&(Xl===null?Xl=l:Xl.push.apply(Xl,l),Pt=null),l}function ka(l){Pt===null?Pt=[l]:Pt.push(l)}var $i=Ul(null),Oe=null,Ct=null;function te(l,t,e){P($i,t._currentValue),t._currentValue=e}function Ht(l){l._currentValue=$i.current,ol($i)}function Wi(l,t,e){for(;l!==null;){var a=l.alternate;if((l.childLanes&t)!==t?(l.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),l===e)break;l=l.return}}function Fi(l,t,e,a){var n=l.child;for(n!==null&&(n.return=l);n!==null;){var u=n.dependencies;if(u!==null){var c=n.child;u=u.firstContext;l:for(;u!==null;){var s=u;u=n;for(var r=0;r<t.length;r++)if(s.context===t[r]){u.lanes|=e,s=u.alternate,s!==null&&(s.lanes|=e),Wi(u.return,e,l),a||(c=null);break l}u=s.next}}else if(n.tag===18){if(c=n.return,c===null)throw Error(d(341));c.lanes|=e,u=c.alternate,u!==null&&(u.lanes|=e),Wi(c,e,l),c=null}else c=n.child;if(c!==null)c.return=n;else for(c=n;c!==null;){if(c===l){c=null;break}if(n=c.sibling,n!==null){n.return=c.return,c=n;break}c=c.return}n=c}}function ca(l,t,e,a){l=null;for(var n=t,u=!1;n!==null;){if(!u){if((n.flags&524288)!==0)u=!0;else if((n.flags&262144)!==0)break}if(n.tag===10){var c=n.alternate;if(c===null)throw Error(d(387));if(c=c.memoizedProps,c!==null){var s=n.type;kl(n.pendingProps.value,c.value)||(l!==null?l.push(s):l=[s])}}else if(n===Bn.current){if(c=n.alternate,c===null)throw Error(d(387));c.memoizedState.memoizedState!==n.memoizedState.memoizedState&&(l!==null?l.push(jn):l=[jn])}n=n.return}l!==null&&Fi(t,l,e,a),t.flags|=262144}function uu(l){for(l=l.firstContext;l!==null;){if(!kl(l.context._currentValue,l.memoizedValue))return!0;l=l.next}return!1}function Ue(l){Oe=l,Ct=null,l=l.dependencies,l!==null&&(l.firstContext=null)}function _l(l){return Gf(Oe,l)}function iu(l,t){return Oe===null&&Ue(l),Gf(l,t)}function Gf(l,t){var e=t._currentValue;if(t={context:t,memoizedValue:e,next:null},Ct===null){if(l===null)throw Error(d(308));Ct=t,l.dependencies={lanes:0,firstContext:t},l.flags|=524288}else Ct=Ct.next=t;return e}var Po=typeof AbortController<"u"?AbortController:function(){var l=[],t=this.signal={aborted:!1,addEventListener:function(e,a){l.push(a)}};this.abort=function(){t.aborted=!0,l.forEach(function(e){return e()})}},lm=f.unstable_scheduleCallback,tm=f.unstable_NormalPriority,xl={$$typeof:Hl,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Ii(){return{controller:new Po,data:new Map,refCount:0}}function wa(l){l.refCount--,l.refCount===0&&lm(tm,function(){l.controller.abort()})}var $a=null,Pi=0,sa=0,fa=null;function em(l,t){if($a===null){var e=$a=[];Pi=0,sa=es(),fa={status:"pending",value:void 0,then:function(a){e.push(a)}}}return Pi++,t.then(Lf,Lf),t}function Lf(){if(--Pi===0&&$a!==null){fa!==null&&(fa.status="fulfilled");var l=$a;$a=null,sa=0,fa=null;for(var t=0;t<l.length;t++)(0,l[t])()}}function am(l,t){var e=[],a={status:"pending",value:null,reason:null,then:function(n){e.push(n)}};return l.then(function(){a.status="fulfilled",a.value=t;for(var n=0;n<e.length;n++)(0,e[n])(t)},function(n){for(a.status="rejected",a.reason=n,n=0;n<e.length;n++)(0,e[n])(void 0)}),a}var Zf=z.S;z.S=function(l,t){Tr=Vl(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&em(l,t),Zf!==null&&Zf(l,t)};var Ce=Ul(null);function lc(){var l=Ce.current;return l!==null?l:ul.pooledCache}function cu(l,t){t===null?P(Ce,Ce.current):P(Ce,t.pool)}function Vf(){var l=lc();return l===null?null:{parent:xl._currentValue,pool:l}}var da=Error(d(460)),tc=Error(d(474)),su=Error(d(542)),fu={then:function(){}};function Kf(l){return l=l.status,l==="fulfilled"||l==="rejected"}function Jf(l,t,e){switch(e=l[e],e===void 0?l.push(t):e!==t&&(t.then(_t,_t),t=e),t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,wf(l),l;default:if(typeof t.status=="string")t.then(_t,_t);else{if(l=ul,l!==null&&100<l.shellSuspendCounter)throw Error(d(482));l=t,l.status="pending",l.then(function(a){if(t.status==="pending"){var n=t;n.status="fulfilled",n.value=a}},function(a){if(t.status==="pending"){var n=t;n.status="rejected",n.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw l=t.reason,wf(l),l}throw Be=t,da}}function He(l){try{var t=l._init;return t(l._payload)}catch(e){throw e!==null&&typeof e=="object"&&typeof e.then=="function"?(Be=e,da):e}}var Be=null;function kf(){if(Be===null)throw Error(d(459));var l=Be;return Be=null,l}function wf(l){if(l===da||l===su)throw Error(d(483))}var ra=null,Wa=0;function du(l){var t=Wa;return Wa+=1,ra===null&&(ra=[]),Jf(ra,l,t)}function Fa(l,t){t=t.props.ref,l.ref=t!==void 0?t:null}function ru(l,t){throw t.$$typeof===R?Error(d(525)):(l=Object.prototype.toString.call(t),Error(d(31,l==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":l)))}function $f(l){function t(h,o){if(l){var y=h.deletions;y===null?(h.deletions=[o],h.flags|=16):y.push(o)}}function e(h,o){if(!l)return null;for(;o!==null;)t(h,o),o=o.sibling;return null}function a(h){for(var o=new Map;h!==null;)h.key!==null?o.set(h.key,h):o.set(h.index,h),h=h.sibling;return o}function n(h,o){return h=Ot(h,o),h.index=0,h.sibling=null,h}function u(h,o,y){return h.index=y,l?(y=h.alternate,y!==null?(y=y.index,y<o?(h.flags|=67108866,o):y):(h.flags|=67108866,o)):(h.flags|=1048576,o)}function c(h){return l&&h.alternate===null&&(h.flags|=67108866),h}function s(h,o,y,S){return o===null||o.tag!==6?(o=Zi(y,h.mode,S),o.return=h,o):(o=n(o,y),o.return=h,o)}function r(h,o,y,S){var H=y.type;return H===V?p(h,o,y.props.children,S,y.key):o!==null&&(o.elementType===H||typeof H=="object"&&H!==null&&H.$$typeof===tt&&He(H)===o.type)?(o=n(o,y.props),Fa(o,y),o.return=h,o):(o=au(y.type,y.key,y.props,null,h.mode,S),Fa(o,y),o.return=h,o)}function x(h,o,y,S){return o===null||o.tag!==4||o.stateNode.containerInfo!==y.containerInfo||o.stateNode.implementation!==y.implementation?(o=Vi(y,h.mode,S),o.return=h,o):(o=n(o,y.children||[]),o.return=h,o)}function p(h,o,y,S,H){return o===null||o.tag!==7?(o=_e(y,h.mode,S,H),o.return=h,o):(o=n(o,y),o.return=h,o)}function A(h,o,y){if(typeof o=="string"&&o!==""||typeof o=="number"||typeof o=="bigint")return o=Zi(""+o,h.mode,y),o.return=h,o;if(typeof o=="object"&&o!==null){switch(o.$$typeof){case Y:return y=au(o.type,o.key,o.props,null,h.mode,y),Fa(y,o),y.return=h,y;case G:return o=Vi(o,h.mode,y),o.return=h,o;case tt:return o=He(o),A(h,o,y)}if(Et(o)||jl(o))return o=_e(o,h.mode,y,null),o.return=h,o;if(typeof o.then=="function")return A(h,du(o),y);if(o.$$typeof===Hl)return A(h,iu(h,o),y);ru(h,o)}return null}function v(h,o,y,S){var H=o!==null?o.key:null;if(typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint")return H!==null?null:s(h,o,""+y,S);if(typeof y=="object"&&y!==null){switch(y.$$typeof){case Y:return y.key===H?r(h,o,y,S):null;case G:return y.key===H?x(h,o,y,S):null;case tt:return y=He(y),v(h,o,y,S)}if(Et(y)||jl(y))return H!==null?null:p(h,o,y,S,null);if(typeof y.then=="function")return v(h,o,du(y),S);if(y.$$typeof===Hl)return v(h,o,iu(h,y),S);ru(h,y)}return null}function b(h,o,y,S,H){if(typeof S=="string"&&S!==""||typeof S=="number"||typeof S=="bigint")return h=h.get(y)||null,s(o,h,""+S,H);if(typeof S=="object"&&S!==null){switch(S.$$typeof){case Y:return h=h.get(S.key===null?y:S.key)||null,r(o,h,S,H);case G:return h=h.get(S.key===null?y:S.key)||null,x(o,h,S,H);case tt:return S=He(S),b(h,o,y,S,H)}if(Et(S)||jl(S))return h=h.get(y)||null,p(o,h,S,H,null);if(typeof S.then=="function")return b(h,o,y,du(S),H);if(S.$$typeof===Hl)return b(h,o,y,iu(o,S),H);ru(o,S)}return null}function O(h,o,y,S){for(var H=null,W=null,U=o,X=o=0,w=null;U!==null&&X<y.length;X++){U.index>X?(w=U,U=null):w=U.sibling;var F=v(h,U,y[X],S);if(F===null){U===null&&(U=w);break}l&&U&&F.alternate===null&&t(h,U),o=u(F,o,X),W===null?H=F:W.sibling=F,W=F,U=w}if(X===y.length)return e(h,U),$&&Ut(h,X),H;if(U===null){for(;X<y.length;X++)U=A(h,y[X],S),U!==null&&(o=u(U,o,X),W===null?H=U:W.sibling=U,W=U);return $&&Ut(h,X),H}for(U=a(U);X<y.length;X++)w=b(U,h,X,y[X],S),w!==null&&(l&&w.alternate!==null&&U.delete(w.key===null?X:w.key),o=u(w,o,X),W===null?H=w:W.sibling=w,W=w);return l&&U.forEach(function(be){return t(h,be)}),$&&Ut(h,X),H}function B(h,o,y,S){if(y==null)throw Error(d(151));for(var H=null,W=null,U=o,X=o=0,w=null,F=y.next();U!==null&&!F.done;X++,F=y.next()){U.index>X?(w=U,U=null):w=U.sibling;var be=v(h,U,F.value,S);if(be===null){U===null&&(U=w);break}l&&U&&be.alternate===null&&t(h,U),o=u(be,o,X),W===null?H=be:W.sibling=be,W=be,U=w}if(F.done)return e(h,U),$&&Ut(h,X),H;if(U===null){for(;!F.done;X++,F=y.next())F=A(h,F.value,S),F!==null&&(o=u(F,o,X),W===null?H=F:W.sibling=F,W=F);return $&&Ut(h,X),H}for(U=a(U);!F.done;X++,F=y.next())F=b(U,h,X,F.value,S),F!==null&&(l&&F.alternate!==null&&U.delete(F.key===null?X:F.key),o=u(F,o,X),W===null?H=F:W.sibling=F,W=F);return l&&U.forEach(function(hh){return t(h,hh)}),$&&Ut(h,X),H}function nl(h,o,y,S){if(typeof y=="object"&&y!==null&&y.type===V&&y.key===null&&(y=y.props.children),typeof y=="object"&&y!==null){switch(y.$$typeof){case Y:l:{for(var H=y.key;o!==null;){if(o.key===H){if(H=y.type,H===V){if(o.tag===7){e(h,o.sibling),S=n(o,y.props.children),S.return=h,h=S;break l}}else if(o.elementType===H||typeof H=="object"&&H!==null&&H.$$typeof===tt&&He(H)===o.type){e(h,o.sibling),S=n(o,y.props),Fa(S,y),S.return=h,h=S;break l}e(h,o);break}else t(h,o);o=o.sibling}y.type===V?(S=_e(y.props.children,h.mode,S,y.key),S.return=h,h=S):(S=au(y.type,y.key,y.props,null,h.mode,S),Fa(S,y),S.return=h,h=S)}return c(h);case G:l:{for(H=y.key;o!==null;){if(o.key===H)if(o.tag===4&&o.stateNode.containerInfo===y.containerInfo&&o.stateNode.implementation===y.implementation){e(h,o.sibling),S=n(o,y.children||[]),S.return=h,h=S;break l}else{e(h,o);break}else t(h,o);o=o.sibling}S=Vi(y,h.mode,S),S.return=h,h=S}return c(h);case tt:return y=He(y),nl(h,o,y,S)}if(Et(y))return O(h,o,y,S);if(jl(y)){if(H=jl(y),typeof H!="function")throw Error(d(150));return y=H.call(y),B(h,o,y,S)}if(typeof y.then=="function")return nl(h,o,du(y),S);if(y.$$typeof===Hl)return nl(h,o,iu(h,y),S);ru(h,y)}return typeof y=="string"&&y!==""||typeof y=="number"||typeof y=="bigint"?(y=""+y,o!==null&&o.tag===6?(e(h,o.sibling),S=n(o,y),S.return=h,h=S):(e(h,o),S=Zi(y,h.mode,S),S.return=h,h=S),c(h)):e(h,o)}return function(h,o,y,S){try{Wa=0;var H=nl(h,o,y,S);return ra=null,H}catch(U){if(U===da||U===su)throw U;var W=wl(29,U,null,h.mode);return W.lanes=S,W.return=h,W}finally{}}}var Re=$f(!0),Wf=$f(!1),ee=!1;function ec(l){l.updateQueue={baseState:l.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function ac(l,t){l=l.updateQueue,t.updateQueue===l&&(t.updateQueue={baseState:l.baseState,firstBaseUpdate:l.firstBaseUpdate,lastBaseUpdate:l.lastBaseUpdate,shared:l.shared,callbacks:null})}function ae(l){return{lane:l,tag:0,payload:null,callback:null,next:null}}function ne(l,t,e){var a=l.updateQueue;if(a===null)return null;if(a=a.shared,(I&2)!==0){var n=a.pending;return n===null?t.next=t:(t.next=n.next,n.next=t),a.pending=t,t=eu(l),Cf(l,null,e),t}return tu(l,a,t,e),eu(l)}function Ia(l,t,e){if(t=t.updateQueue,t!==null&&(t=t.shared,(e&4194048)!==0)){var a=t.lanes;a&=l.pendingLanes,e|=a,t.lanes=e,Xs(l,e)}}function nc(l,t){var e=l.updateQueue,a=l.alternate;if(a!==null&&(a=a.updateQueue,e===a)){var n=null,u=null;if(e=e.firstBaseUpdate,e!==null){do{var c={lane:e.lane,tag:e.tag,payload:e.payload,callback:null,next:null};u===null?n=u=c:u=u.next=c,e=e.next}while(e!==null);u===null?n=u=t:u=u.next=t}else n=u=t;e={baseState:a.baseState,firstBaseUpdate:n,lastBaseUpdate:u,shared:a.shared,callbacks:a.callbacks},l.updateQueue=e;return}l=e.lastBaseUpdate,l===null?e.firstBaseUpdate=t:l.next=t,e.lastBaseUpdate=t}var uc=!1;function Pa(){if(uc){var l=fa;if(l!==null)throw l}}function ln(l,t,e,a){uc=!1;var n=l.updateQueue;ee=!1;var u=n.firstBaseUpdate,c=n.lastBaseUpdate,s=n.shared.pending;if(s!==null){n.shared.pending=null;var r=s,x=r.next;r.next=null,c===null?u=x:c.next=x,c=r;var p=l.alternate;p!==null&&(p=p.updateQueue,s=p.lastBaseUpdate,s!==c&&(s===null?p.firstBaseUpdate=x:s.next=x,p.lastBaseUpdate=r))}if(u!==null){var A=n.baseState;c=0,p=x=r=null,s=u;do{var v=s.lane&-536870913,b=v!==s.lane;if(b?(k&v)===v:(a&v)===v){v!==0&&v===sa&&(uc=!0),p!==null&&(p=p.next={lane:0,tag:s.tag,payload:s.payload,callback:null,next:null});l:{var O=l,B=s;v=t;var nl=e;switch(B.tag){case 1:if(O=B.payload,typeof O=="function"){A=O.call(nl,A,v);break l}A=O;break l;case 3:O.flags=O.flags&-65537|128;case 0:if(O=B.payload,v=typeof O=="function"?O.call(nl,A,v):O,v==null)break l;A=j({},A,v);break l;case 2:ee=!0}}v=s.callback,v!==null&&(l.flags|=64,b&&(l.flags|=8192),b=n.callbacks,b===null?n.callbacks=[v]:b.push(v))}else b={lane:v,tag:s.tag,payload:s.payload,callback:s.callback,next:null},p===null?(x=p=b,r=A):p=p.next=b,c|=v;if(s=s.next,s===null){if(s=n.shared.pending,s===null)break;b=s,s=b.next,b.next=null,n.lastBaseUpdate=b,n.shared.pending=null}}while(!0);p===null&&(r=A),n.baseState=r,n.firstBaseUpdate=x,n.lastBaseUpdate=p,u===null&&(n.shared.lanes=0),fe|=c,l.lanes=c,l.memoizedState=A}}function Ff(l,t){if(typeof l!="function")throw Error(d(191,l));l.call(t)}function If(l,t){var e=l.callbacks;if(e!==null)for(l.callbacks=null,l=0;l<e.length;l++)Ff(e[l],t)}var oa=Ul(null),ou=Ul(0);function Pf(l,t){l=Zt,P(ou,l),P(oa,t),Zt=l|t.baseLanes}function ic(){P(ou,Zt),P(oa,oa.current)}function cc(){Zt=ou.current,ol(oa),ol(ou)}var $l=Ul(null),dt=null;function ue(l){var t=l.alternate;P(gl,gl.current&1),P($l,l),dt===null&&(t===null||oa.current!==null||t.memoizedState!==null)&&(dt=l)}function sc(l){P(gl,gl.current),P($l,l),dt===null&&(dt=l)}function ld(l){l.tag===22?(P(gl,gl.current),P($l,l),dt===null&&(dt=l)):ie()}function ie(){P(gl,gl.current),P($l,$l.current)}function Wl(l){ol($l),dt===l&&(dt=null),ol(gl)}var gl=Ul(0);function mu(l){for(var t=l;t!==null;){if(t.tag===13){var e=t.memoizedState;if(e!==null&&(e=e.dehydrated,e===null||hs(e)||gs(e)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Bt=0,Q=null,el=null,vl=null,hu=!1,ma=!1,qe=!1,gu=0,tn=0,ha=null,nm=0;function ml(){throw Error(d(321))}function fc(l,t){if(t===null)return!1;for(var e=0;e<t.length&&e<l.length;e++)if(!kl(l[e],t[e]))return!1;return!0}function dc(l,t,e,a,n,u){return Bt=u,Q=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,z.H=l===null||l.memoizedState===null?qd:Ac,qe=!1,u=e(a,n),qe=!1,ma&&(u=ed(t,e,a,n)),td(l),u}function td(l){z.H=nn;var t=el!==null&&el.next!==null;if(Bt=0,vl=el=Q=null,hu=!1,tn=0,ha=null,t)throw Error(d(300));l===null||bl||(l=l.dependencies,l!==null&&uu(l)&&(bl=!0))}function ed(l,t,e,a){Q=l;var n=0;do{if(ma&&(ha=null),tn=0,ma=!1,25<=n)throw Error(d(301));if(n+=1,vl=el=null,l.updateQueue!=null){var u=l.updateQueue;u.lastEffect=null,u.events=null,u.stores=null,u.memoCache!=null&&(u.memoCache.index=0)}z.H=Yd,u=t(e,a)}while(ma);return u}function um(){var l=z.H,t=l.useState()[0];return t=typeof t.then=="function"?en(t):t,l=l.useState()[0],(el!==null?el.memoizedState:null)!==l&&(Q.flags|=1024),t}function rc(){var l=gu!==0;return gu=0,l}function oc(l,t,e){t.updateQueue=l.updateQueue,t.flags&=-2053,l.lanes&=~e}function mc(l){if(hu){for(l=l.memoizedState;l!==null;){var t=l.queue;t!==null&&(t.pending=null),l=l.next}hu=!1}Bt=0,vl=el=Q=null,ma=!1,tn=gu=0,ha=null}function Cl(){var l={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return vl===null?Q.memoizedState=vl=l:vl=vl.next=l,vl}function yl(){if(el===null){var l=Q.alternate;l=l!==null?l.memoizedState:null}else l=el.next;var t=vl===null?Q.memoizedState:vl.next;if(t!==null)vl=t,el=l;else{if(l===null)throw Q.alternate===null?Error(d(467)):Error(d(310));el=l,l={memoizedState:el.memoizedState,baseState:el.baseState,baseQueue:el.baseQueue,queue:el.queue,next:null},vl===null?Q.memoizedState=vl=l:vl=vl.next=l}return vl}function yu(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function en(l){var t=tn;return tn+=1,ha===null&&(ha=[]),l=Jf(ha,l,t),t=Q,(vl===null?t.memoizedState:vl.next)===null&&(t=t.alternate,z.H=t===null||t.memoizedState===null?qd:Ac),l}function xu(l){if(l!==null&&typeof l=="object"){if(typeof l.then=="function")return en(l);if(l.$$typeof===Hl)return _l(l)}throw Error(d(438,String(l)))}function hc(l){var t=null,e=Q.updateQueue;if(e!==null&&(t=e.memoCache),t==null){var a=Q.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(n){return n.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),e===null&&(e=yu(),Q.updateQueue=e),e.memoCache=t,e=t.data[t.index],e===void 0)for(e=t.data[t.index]=Array(l),a=0;a<l;a++)e[a]=Le;return t.index++,e}function Rt(l,t){return typeof t=="function"?t(l):t}function vu(l){var t=yl();return gc(t,el,l)}function gc(l,t,e){var a=l.queue;if(a===null)throw Error(d(311));a.lastRenderedReducer=e;var n=l.baseQueue,u=a.pending;if(u!==null){if(n!==null){var c=n.next;n.next=u.next,u.next=c}t.baseQueue=n=u,a.pending=null}if(u=l.baseState,n===null)l.memoizedState=u;else{t=n.next;var s=c=null,r=null,x=t,p=!1;do{var A=x.lane&-536870913;if(A!==x.lane?(k&A)===A:(Bt&A)===A){var v=x.revertLane;if(v===0)r!==null&&(r=r.next={lane:0,revertLane:0,gesture:null,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null}),A===sa&&(p=!0);else if((Bt&v)===v){x=x.next,v===sa&&(p=!0);continue}else A={lane:0,revertLane:x.revertLane,gesture:null,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null},r===null?(s=r=A,c=u):r=r.next=A,Q.lanes|=v,fe|=v;A=x.action,qe&&e(u,A),u=x.hasEagerState?x.eagerState:e(u,A)}else v={lane:A,revertLane:x.revertLane,gesture:x.gesture,action:x.action,hasEagerState:x.hasEagerState,eagerState:x.eagerState,next:null},r===null?(s=r=v,c=u):r=r.next=v,Q.lanes|=A,fe|=A;x=x.next}while(x!==null&&x!==t);if(r===null?c=u:r.next=s,!kl(u,l.memoizedState)&&(bl=!0,p&&(e=fa,e!==null)))throw e;l.memoizedState=u,l.baseState=c,l.baseQueue=r,a.lastRenderedState=u}return n===null&&(a.lanes=0),[l.memoizedState,a.dispatch]}function yc(l){var t=yl(),e=t.queue;if(e===null)throw Error(d(311));e.lastRenderedReducer=l;var a=e.dispatch,n=e.pending,u=t.memoizedState;if(n!==null){e.pending=null;var c=n=n.next;do u=l(u,c.action),c=c.next;while(c!==n);kl(u,t.memoizedState)||(bl=!0),t.memoizedState=u,t.baseQueue===null&&(t.baseState=u),e.lastRenderedState=u}return[u,a]}function ad(l,t,e){var a=Q,n=yl(),u=$;if(u){if(e===void 0)throw Error(d(407));e=e()}else e=t();var c=!kl((el||n).memoizedState,e);if(c&&(n.memoizedState=e,bl=!0),n=n.queue,bc(id.bind(null,a,n,l),[l]),n.getSnapshot!==t||c||vl!==null&&vl.memoizedState.tag&1){if(a.flags|=2048,ga(9,{destroy:void 0},ud.bind(null,a,n,e,t),null),ul===null)throw Error(d(349));u||(Bt&127)!==0||nd(a,t,e)}return e}function nd(l,t,e){l.flags|=16384,l={getSnapshot:t,value:e},t=Q.updateQueue,t===null?(t=yu(),Q.updateQueue=t,t.stores=[l]):(e=t.stores,e===null?t.stores=[l]:e.push(l))}function ud(l,t,e,a){t.value=e,t.getSnapshot=a,cd(t)&&sd(l)}function id(l,t,e){return e(function(){cd(t)&&sd(l)})}function cd(l){var t=l.getSnapshot;l=l.value;try{var e=t();return!kl(l,e)}catch{return!0}}function sd(l){var t=Me(l,2);t!==null&&Gl(t,l,2)}function xc(l){var t=Cl();if(typeof l=="function"){var e=l;if(l=e(),qe){$t(!0);try{e()}finally{$t(!1)}}}return t.memoizedState=t.baseState=l,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Rt,lastRenderedState:l},t}function fd(l,t,e,a){return l.baseState=e,gc(l,el,typeof a=="function"?a:Rt)}function im(l,t,e,a,n){if(ju(l))throw Error(d(485));if(l=t.action,l!==null){var u={payload:n,action:l,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(c){u.listeners.push(c)}};z.T!==null?e(!0):u.isTransition=!1,a(u),e=t.pending,e===null?(u.next=t.pending=u,dd(t,u)):(u.next=e.next,t.pending=e.next=u)}}function dd(l,t){var e=t.action,a=t.payload,n=l.state;if(t.isTransition){var u=z.T,c={};z.T=c;try{var s=e(n,a),r=z.S;r!==null&&r(c,s),rd(l,t,s)}catch(x){vc(l,t,x)}finally{u!==null&&c.types!==null&&(u.types=c.types),z.T=u}}else try{u=e(n,a),rd(l,t,u)}catch(x){vc(l,t,x)}}function rd(l,t,e){e!==null&&typeof e=="object"&&typeof e.then=="function"?e.then(function(a){od(l,t,a)},function(a){return vc(l,t,a)}):od(l,t,e)}function od(l,t,e){t.status="fulfilled",t.value=e,md(t),l.state=e,t=l.pending,t!==null&&(e=t.next,e===t?l.pending=null:(e=e.next,t.next=e,dd(l,e)))}function vc(l,t,e){var a=l.pending;if(l.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=e,md(t),t=t.next;while(t!==a)}l.action=null}function md(l){l=l.listeners;for(var t=0;t<l.length;t++)(0,l[t])()}function hd(l,t){return t}function gd(l,t){if($){var e=ul.formState;if(e!==null){l:{var a=Q;if($){if(fl){t:{for(var n=fl,u=ft;n.nodeType!==8;){if(!u){n=null;break t}if(n=rt(n.nextSibling),n===null){n=null;break t}}u=n.data,n=u==="F!"||u==="F"?n:null}if(n){fl=rt(n.nextSibling),a=n.data==="F!";break l}}le(a)}a=!1}a&&(t=e[0])}}return e=Cl(),e.memoizedState=e.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:hd,lastRenderedState:t},e.queue=a,e=Hd.bind(null,Q,a),a.dispatch=e,a=xc(!1),u=zc.bind(null,Q,!1,a.queue),a=Cl(),n={state:t,dispatch:null,action:l,pending:null},a.queue=n,e=im.bind(null,Q,n,u,e),n.dispatch=e,a.memoizedState=l,[t,e,!1]}function yd(l){var t=yl();return xd(t,el,l)}function xd(l,t,e){if(t=gc(l,t,hd)[0],l=vu(Rt)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=en(t)}catch(c){throw c===da?su:c}else a=t;t=yl();var n=t.queue,u=n.dispatch;return e!==t.memoizedState&&(Q.flags|=2048,ga(9,{destroy:void 0},cm.bind(null,n,e),null)),[a,u,l]}function cm(l,t){l.action=t}function vd(l){var t=yl(),e=el;if(e!==null)return xd(t,e,l);yl(),t=t.memoizedState,e=yl();var a=e.queue.dispatch;return e.memoizedState=l,[t,a,!1]}function ga(l,t,e,a){return l={tag:l,create:e,deps:a,inst:t,next:null},t=Q.updateQueue,t===null&&(t=yu(),Q.updateQueue=t),e=t.lastEffect,e===null?t.lastEffect=l.next=l:(a=e.next,e.next=l,l.next=a,t.lastEffect=l),l}function bd(){return yl().memoizedState}function bu(l,t,e,a){var n=Cl();Q.flags|=l,n.memoizedState=ga(1|t,{destroy:void 0},e,a===void 0?null:a)}function pu(l,t,e,a){var n=yl();a=a===void 0?null:a;var u=n.memoizedState.inst;el!==null&&a!==null&&fc(a,el.memoizedState.deps)?n.memoizedState=ga(t,u,e,a):(Q.flags|=l,n.memoizedState=ga(1|t,u,e,a))}function pd(l,t){bu(8390656,8,l,t)}function bc(l,t){pu(2048,8,l,t)}function sm(l){Q.flags|=4;var t=Q.updateQueue;if(t===null)t=yu(),Q.updateQueue=t,t.events=[l];else{var e=t.events;e===null?t.events=[l]:e.push(l)}}function jd(l){var t=yl().memoizedState;return sm({ref:t,nextImpl:l}),function(){if((I&2)!==0)throw Error(d(440));return t.impl.apply(void 0,arguments)}}function Sd(l,t){return pu(4,2,l,t)}function Nd(l,t){return pu(4,4,l,t)}function zd(l,t){if(typeof t=="function"){l=l();var e=t(l);return function(){typeof e=="function"?e():t(null)}}if(t!=null)return l=l(),t.current=l,function(){t.current=null}}function Ad(l,t,e){e=e!=null?e.concat([l]):null,pu(4,4,zd.bind(null,t,l),e)}function pc(){}function Td(l,t){var e=yl();t=t===void 0?null:t;var a=e.memoizedState;return t!==null&&fc(t,a[1])?a[0]:(e.memoizedState=[l,t],l)}function Ed(l,t){var e=yl();t=t===void 0?null:t;var a=e.memoizedState;if(t!==null&&fc(t,a[1]))return a[0];if(a=l(),qe){$t(!0);try{l()}finally{$t(!1)}}return e.memoizedState=[a,t],a}function jc(l,t,e){return e===void 0||(Bt&1073741824)!==0&&(k&261930)===0?l.memoizedState=t:(l.memoizedState=e,l=Mr(),Q.lanes|=l,fe|=l,e)}function Md(l,t,e,a){return kl(e,t)?e:oa.current!==null?(l=jc(l,e,a),kl(l,t)||(bl=!0),l):(Bt&42)===0||(Bt&1073741824)!==0&&(k&261930)===0?(bl=!0,l.memoizedState=e):(l=Mr(),Q.lanes|=l,fe|=l,t)}function _d(l,t,e,a,n){var u=_.p;_.p=u!==0&&8>u?u:8;var c=z.T,s={};z.T=s,zc(l,!1,t,e);try{var r=n(),x=z.S;if(x!==null&&x(s,r),r!==null&&typeof r=="object"&&typeof r.then=="function"){var p=am(r,a);an(l,t,p,Pl(l))}else an(l,t,a,Pl(l))}catch(A){an(l,t,{then:function(){},status:"rejected",reason:A},Pl())}finally{_.p=u,c!==null&&s.types!==null&&(c.types=s.types),z.T=c}}function fm(){}function Sc(l,t,e,a){if(l.tag!==5)throw Error(d(476));var n=Dd(l).queue;_d(l,n,t,q,e===null?fm:function(){return Od(l),e(a)})}function Dd(l){var t=l.memoizedState;if(t!==null)return t;t={memoizedState:q,baseState:q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Rt,lastRenderedState:q},next:null};var e={};return t.next={memoizedState:e,baseState:e,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Rt,lastRenderedState:e},next:null},l.memoizedState=t,l=l.alternate,l!==null&&(l.memoizedState=t),t}function Od(l){var t=Dd(l);t.next===null&&(t=l.alternate.memoizedState),an(l,t.next.queue,{},Pl())}function Nc(){return _l(jn)}function Ud(){return yl().memoizedState}function Cd(){return yl().memoizedState}function dm(l){for(var t=l.return;t!==null;){switch(t.tag){case 24:case 3:var e=Pl();l=ae(e);var a=ne(t,l,e);a!==null&&(Gl(a,t,e),Ia(a,t,e)),t={cache:Ii()},l.payload=t;return}t=t.return}}function rm(l,t,e){var a=Pl();e={lane:a,revertLane:0,gesture:null,action:e,hasEagerState:!1,eagerState:null,next:null},ju(l)?Bd(t,e):(e=Gi(l,t,e,a),e!==null&&(Gl(e,l,a),Rd(e,t,a)))}function Hd(l,t,e){var a=Pl();an(l,t,e,a)}function an(l,t,e,a){var n={lane:a,revertLane:0,gesture:null,action:e,hasEagerState:!1,eagerState:null,next:null};if(ju(l))Bd(t,n);else{var u=l.alternate;if(l.lanes===0&&(u===null||u.lanes===0)&&(u=t.lastRenderedReducer,u!==null))try{var c=t.lastRenderedState,s=u(c,e);if(n.hasEagerState=!0,n.eagerState=s,kl(s,c))return tu(l,t,n,0),ul===null&&lu(),!1}catch{}finally{}if(e=Gi(l,t,n,a),e!==null)return Gl(e,l,a),Rd(e,t,a),!0}return!1}function zc(l,t,e,a){if(a={lane:2,revertLane:es(),gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},ju(l)){if(t)throw Error(d(479))}else t=Gi(l,e,a,2),t!==null&&Gl(t,l,2)}function ju(l){var t=l.alternate;return l===Q||t!==null&&t===Q}function Bd(l,t){ma=hu=!0;var e=l.pending;e===null?t.next=t:(t.next=e.next,e.next=t),l.pending=t}function Rd(l,t,e){if((e&4194048)!==0){var a=t.lanes;a&=l.pendingLanes,e|=a,t.lanes=e,Xs(l,e)}}var nn={readContext:_l,use:xu,useCallback:ml,useContext:ml,useEffect:ml,useImperativeHandle:ml,useLayoutEffect:ml,useInsertionEffect:ml,useMemo:ml,useReducer:ml,useRef:ml,useState:ml,useDebugValue:ml,useDeferredValue:ml,useTransition:ml,useSyncExternalStore:ml,useId:ml,useHostTransitionStatus:ml,useFormState:ml,useActionState:ml,useOptimistic:ml,useMemoCache:ml,useCacheRefresh:ml};nn.useEffectEvent=ml;var qd={readContext:_l,use:xu,useCallback:function(l,t){return Cl().memoizedState=[l,t===void 0?null:t],l},useContext:_l,useEffect:pd,useImperativeHandle:function(l,t,e){e=e!=null?e.concat([l]):null,bu(4194308,4,zd.bind(null,t,l),e)},useLayoutEffect:function(l,t){return bu(4194308,4,l,t)},useInsertionEffect:function(l,t){bu(4,2,l,t)},useMemo:function(l,t){var e=Cl();t=t===void 0?null:t;var a=l();if(qe){$t(!0);try{l()}finally{$t(!1)}}return e.memoizedState=[a,t],a},useReducer:function(l,t,e){var a=Cl();if(e!==void 0){var n=e(t);if(qe){$t(!0);try{e(t)}finally{$t(!1)}}}else n=t;return a.memoizedState=a.baseState=n,l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:l,lastRenderedState:n},a.queue=l,l=l.dispatch=rm.bind(null,Q,l),[a.memoizedState,l]},useRef:function(l){var t=Cl();return l={current:l},t.memoizedState=l},useState:function(l){l=xc(l);var t=l.queue,e=Hd.bind(null,Q,t);return t.dispatch=e,[l.memoizedState,e]},useDebugValue:pc,useDeferredValue:function(l,t){var e=Cl();return jc(e,l,t)},useTransition:function(){var l=xc(!1);return l=_d.bind(null,Q,l.queue,!0,!1),Cl().memoizedState=l,[!1,l]},useSyncExternalStore:function(l,t,e){var a=Q,n=Cl();if($){if(e===void 0)throw Error(d(407));e=e()}else{if(e=t(),ul===null)throw Error(d(349));(k&127)!==0||nd(a,t,e)}n.memoizedState=e;var u={value:e,getSnapshot:t};return n.queue=u,pd(id.bind(null,a,u,l),[l]),a.flags|=2048,ga(9,{destroy:void 0},ud.bind(null,a,u,e,t),null),e},useId:function(){var l=Cl(),t=ul.identifierPrefix;if($){var e=St,a=jt;e=(a&~(1<<32-Jl(a)-1)).toString(32)+e,t="_"+t+"R_"+e,e=gu++,0<e&&(t+="H"+e.toString(32)),t+="_"}else e=nm++,t="_"+t+"r_"+e.toString(32)+"_";return l.memoizedState=t},useHostTransitionStatus:Nc,useFormState:gd,useActionState:gd,useOptimistic:function(l){var t=Cl();t.memoizedState=t.baseState=l;var e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=e,t=zc.bind(null,Q,!0,e),e.dispatch=t,[l,t]},useMemoCache:hc,useCacheRefresh:function(){return Cl().memoizedState=dm.bind(null,Q)},useEffectEvent:function(l){var t=Cl(),e={impl:l};return t.memoizedState=e,function(){if((I&2)!==0)throw Error(d(440));return e.impl.apply(void 0,arguments)}}},Ac={readContext:_l,use:xu,useCallback:Td,useContext:_l,useEffect:bc,useImperativeHandle:Ad,useInsertionEffect:Sd,useLayoutEffect:Nd,useMemo:Ed,useReducer:vu,useRef:bd,useState:function(){return vu(Rt)},useDebugValue:pc,useDeferredValue:function(l,t){var e=yl();return Md(e,el.memoizedState,l,t)},useTransition:function(){var l=vu(Rt)[0],t=yl().memoizedState;return[typeof l=="boolean"?l:en(l),t]},useSyncExternalStore:ad,useId:Ud,useHostTransitionStatus:Nc,useFormState:yd,useActionState:yd,useOptimistic:function(l,t){var e=yl();return fd(e,el,l,t)},useMemoCache:hc,useCacheRefresh:Cd};Ac.useEffectEvent=jd;var Yd={readContext:_l,use:xu,useCallback:Td,useContext:_l,useEffect:bc,useImperativeHandle:Ad,useInsertionEffect:Sd,useLayoutEffect:Nd,useMemo:Ed,useReducer:yc,useRef:bd,useState:function(){return yc(Rt)},useDebugValue:pc,useDeferredValue:function(l,t){var e=yl();return el===null?jc(e,l,t):Md(e,el.memoizedState,l,t)},useTransition:function(){var l=yc(Rt)[0],t=yl().memoizedState;return[typeof l=="boolean"?l:en(l),t]},useSyncExternalStore:ad,useId:Ud,useHostTransitionStatus:Nc,useFormState:vd,useActionState:vd,useOptimistic:function(l,t){var e=yl();return el!==null?fd(e,el,l,t):(e.baseState=l,[l,e.queue.dispatch])},useMemoCache:hc,useCacheRefresh:Cd};Yd.useEffectEvent=jd;function Tc(l,t,e,a){t=l.memoizedState,e=e(a,t),e=e==null?t:j({},t,e),l.memoizedState=e,l.lanes===0&&(l.updateQueue.baseState=e)}var Ec={enqueueSetState:function(l,t,e){l=l._reactInternals;var a=Pl(),n=ae(a);n.payload=t,e!=null&&(n.callback=e),t=ne(l,n,a),t!==null&&(Gl(t,l,a),Ia(t,l,a))},enqueueReplaceState:function(l,t,e){l=l._reactInternals;var a=Pl(),n=ae(a);n.tag=1,n.payload=t,e!=null&&(n.callback=e),t=ne(l,n,a),t!==null&&(Gl(t,l,a),Ia(t,l,a))},enqueueForceUpdate:function(l,t){l=l._reactInternals;var e=Pl(),a=ae(e);a.tag=2,t!=null&&(a.callback=t),t=ne(l,a,e),t!==null&&(Gl(t,l,e),Ia(t,l,e))}};function Qd(l,t,e,a,n,u,c){return l=l.stateNode,typeof l.shouldComponentUpdate=="function"?l.shouldComponentUpdate(a,u,c):t.prototype&&t.prototype.isPureReactComponent?!Va(e,a)||!Va(n,u):!0}function Xd(l,t,e,a){l=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(e,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(e,a),t.state!==l&&Ec.enqueueReplaceState(t,t.state,null)}function Ye(l,t){var e=t;if("ref"in t){e={};for(var a in t)a!=="ref"&&(e[a]=t[a])}if(l=l.defaultProps){e===t&&(e=j({},e));for(var n in l)e[n]===void 0&&(e[n]=l[n])}return e}function Gd(l){Pn(l)}function Ld(l){console.error(l)}function Zd(l){Pn(l)}function Su(l,t){try{var e=l.onUncaughtError;e(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function Vd(l,t,e){try{var a=l.onCaughtError;a(e.value,{componentStack:e.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(n){setTimeout(function(){throw n})}}function Mc(l,t,e){return e=ae(e),e.tag=3,e.payload={element:null},e.callback=function(){Su(l,t)},e}function Kd(l){return l=ae(l),l.tag=3,l}function Jd(l,t,e,a){var n=e.type.getDerivedStateFromError;if(typeof n=="function"){var u=a.value;l.payload=function(){return n(u)},l.callback=function(){Vd(t,e,a)}}var c=e.stateNode;c!==null&&typeof c.componentDidCatch=="function"&&(l.callback=function(){Vd(t,e,a),typeof n!="function"&&(de===null?de=new Set([this]):de.add(this));var s=a.stack;this.componentDidCatch(a.value,{componentStack:s!==null?s:""})})}function om(l,t,e,a,n){if(e.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=e.alternate,t!==null&&ca(t,e,n,!0),e=$l.current,e!==null){switch(e.tag){case 31:case 13:return dt===null?Hu():e.alternate===null&&hl===0&&(hl=3),e.flags&=-257,e.flags|=65536,e.lanes=n,a===fu?e.flags|=16384:(t=e.updateQueue,t===null?e.updateQueue=new Set([a]):t.add(a),Pc(l,a,n)),!1;case 22:return e.flags|=65536,a===fu?e.flags|=16384:(t=e.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},e.updateQueue=t):(e=t.retryQueue,e===null?t.retryQueue=new Set([a]):e.add(a)),Pc(l,a,n)),!1}throw Error(d(435,e.tag))}return Pc(l,a,n),Hu(),!1}if($)return t=$l.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=n,a!==ki&&(l=Error(d(422),{cause:a}),ka(it(l,e)))):(a!==ki&&(t=Error(d(423),{cause:a}),ka(it(t,e))),l=l.current.alternate,l.flags|=65536,n&=-n,l.lanes|=n,a=it(a,e),n=Mc(l.stateNode,a,n),nc(l,n),hl!==4&&(hl=2)),!1;var u=Error(d(520),{cause:a});if(u=it(u,e),mn===null?mn=[u]:mn.push(u),hl!==4&&(hl=2),t===null)return!0;a=it(a,e),e=t;do{switch(e.tag){case 3:return e.flags|=65536,l=n&-n,e.lanes|=l,l=Mc(e.stateNode,a,l),nc(e,l),!1;case 1:if(t=e.type,u=e.stateNode,(e.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||u!==null&&typeof u.componentDidCatch=="function"&&(de===null||!de.has(u))))return e.flags|=65536,n&=-n,e.lanes|=n,n=Kd(n),Jd(n,l,e,a),nc(e,n),!1}e=e.return}while(e!==null);return!1}var _c=Error(d(461)),bl=!1;function Dl(l,t,e,a){t.child=l===null?Wf(t,null,e,a):Re(t,l.child,e,a)}function kd(l,t,e,a,n){e=e.render;var u=t.ref;if("ref"in a){var c={};for(var s in a)s!=="ref"&&(c[s]=a[s])}else c=a;return Ue(t),a=dc(l,t,e,c,u,n),s=rc(),l!==null&&!bl?(oc(l,t,n),qt(l,t,n)):($&&s&&Ki(t),t.flags|=1,Dl(l,t,a,n),t.child)}function wd(l,t,e,a,n){if(l===null){var u=e.type;return typeof u=="function"&&!Li(u)&&u.defaultProps===void 0&&e.compare===null?(t.tag=15,t.type=u,$d(l,t,u,a,n)):(l=au(e.type,null,a,t,t.mode,n),l.ref=t.ref,l.return=t,t.child=l)}if(u=l.child,!qc(l,n)){var c=u.memoizedProps;if(e=e.compare,e=e!==null?e:Va,e(c,a)&&l.ref===t.ref)return qt(l,t,n)}return t.flags|=1,l=Ot(u,a),l.ref=t.ref,l.return=t,t.child=l}function $d(l,t,e,a,n){if(l!==null){var u=l.memoizedProps;if(Va(u,a)&&l.ref===t.ref)if(bl=!1,t.pendingProps=a=u,qc(l,n))(l.flags&131072)!==0&&(bl=!0);else return t.lanes=l.lanes,qt(l,t,n)}return Dc(l,t,e,a,n)}function Wd(l,t,e,a){var n=a.children,u=l!==null?l.memoizedState:null;if(l===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),a.mode==="hidden"){if((t.flags&128)!==0){if(u=u!==null?u.baseLanes|e:e,l!==null){for(a=t.child=l.child,n=0;a!==null;)n=n|a.lanes|a.childLanes,a=a.sibling;a=n&~u}else a=0,t.child=null;return Fd(l,t,u,e,a)}if((e&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},l!==null&&cu(t,u!==null?u.cachePool:null),u!==null?Pf(t,u):ic(),ld(t);else return a=t.lanes=536870912,Fd(l,t,u!==null?u.baseLanes|e:e,e,a)}else u!==null?(cu(t,u.cachePool),Pf(t,u),ie(),t.memoizedState=null):(l!==null&&cu(t,null),ic(),ie());return Dl(l,t,n,e),t.child}function un(l,t){return l!==null&&l.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function Fd(l,t,e,a,n){var u=lc();return u=u===null?null:{parent:xl._currentValue,pool:u},t.memoizedState={baseLanes:e,cachePool:u},l!==null&&cu(t,null),ic(),ld(t),l!==null&&ca(l,t,a,!0),t.childLanes=n,null}function Nu(l,t){return t=Au({mode:t.mode,children:t.children},l.mode),t.ref=l.ref,l.child=t,t.return=l,t}function Id(l,t,e){return Re(t,l.child,null,e),l=Nu(t,t.pendingProps),l.flags|=2,Wl(t),t.memoizedState=null,l}function mm(l,t,e){var a=t.pendingProps,n=(t.flags&128)!==0;if(t.flags&=-129,l===null){if($){if(a.mode==="hidden")return l=Nu(t,a),t.lanes=536870912,un(null,l);if(sc(t),(l=fl)?(l=d0(l,ft),l=l!==null&&l.data==="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:It!==null?{id:jt,overflow:St}:null,retryLane:536870912,hydrationErrors:null},e=Bf(l),e.return=t,t.child=e,Ml=t,fl=null)):l=null,l===null)throw le(t);return t.lanes=536870912,null}return Nu(t,a)}var u=l.memoizedState;if(u!==null){var c=u.dehydrated;if(sc(t),n)if(t.flags&256)t.flags&=-257,t=Id(l,t,e);else if(t.memoizedState!==null)t.child=l.child,t.flags|=128,t=null;else throw Error(d(558));else if(bl||ca(l,t,e,!1),n=(e&l.childLanes)!==0,bl||n){if(a=ul,a!==null&&(c=Gs(a,e),c!==0&&c!==u.retryLane))throw u.retryLane=c,Me(l,c),Gl(a,l,c),_c;Hu(),t=Id(l,t,e)}else l=u.treeContext,fl=rt(c.nextSibling),Ml=t,$=!0,Pt=null,ft=!1,l!==null&&Yf(t,l),t=Nu(t,a),t.flags|=4096;return t}return l=Ot(l.child,{mode:a.mode,children:a.children}),l.ref=t.ref,t.child=l,l.return=t,l}function zu(l,t){var e=t.ref;if(e===null)l!==null&&l.ref!==null&&(t.flags|=4194816);else{if(typeof e!="function"&&typeof e!="object")throw Error(d(284));(l===null||l.ref!==e)&&(t.flags|=4194816)}}function Dc(l,t,e,a,n){return Ue(t),e=dc(l,t,e,a,void 0,n),a=rc(),l!==null&&!bl?(oc(l,t,n),qt(l,t,n)):($&&a&&Ki(t),t.flags|=1,Dl(l,t,e,n),t.child)}function Pd(l,t,e,a,n,u){return Ue(t),t.updateQueue=null,e=ed(t,a,e,n),td(l),a=rc(),l!==null&&!bl?(oc(l,t,u),qt(l,t,u)):($&&a&&Ki(t),t.flags|=1,Dl(l,t,e,u),t.child)}function lr(l,t,e,a,n){if(Ue(t),t.stateNode===null){var u=aa,c=e.contextType;typeof c=="object"&&c!==null&&(u=_l(c)),u=new e(a,u),t.memoizedState=u.state!==null&&u.state!==void 0?u.state:null,u.updater=Ec,t.stateNode=u,u._reactInternals=t,u=t.stateNode,u.props=a,u.state=t.memoizedState,u.refs={},ec(t),c=e.contextType,u.context=typeof c=="object"&&c!==null?_l(c):aa,u.state=t.memoizedState,c=e.getDerivedStateFromProps,typeof c=="function"&&(Tc(t,e,c,a),u.state=t.memoizedState),typeof e.getDerivedStateFromProps=="function"||typeof u.getSnapshotBeforeUpdate=="function"||typeof u.UNSAFE_componentWillMount!="function"&&typeof u.componentWillMount!="function"||(c=u.state,typeof u.componentWillMount=="function"&&u.componentWillMount(),typeof u.UNSAFE_componentWillMount=="function"&&u.UNSAFE_componentWillMount(),c!==u.state&&Ec.enqueueReplaceState(u,u.state,null),ln(t,a,u,n),Pa(),u.state=t.memoizedState),typeof u.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(l===null){u=t.stateNode;var s=t.memoizedProps,r=Ye(e,s);u.props=r;var x=u.context,p=e.contextType;c=aa,typeof p=="object"&&p!==null&&(c=_l(p));var A=e.getDerivedStateFromProps;p=typeof A=="function"||typeof u.getSnapshotBeforeUpdate=="function",s=t.pendingProps!==s,p||typeof u.UNSAFE_componentWillReceiveProps!="function"&&typeof u.componentWillReceiveProps!="function"||(s||x!==c)&&Xd(t,u,a,c),ee=!1;var v=t.memoizedState;u.state=v,ln(t,a,u,n),Pa(),x=t.memoizedState,s||v!==x||ee?(typeof A=="function"&&(Tc(t,e,A,a),x=t.memoizedState),(r=ee||Qd(t,e,r,a,v,x,c))?(p||typeof u.UNSAFE_componentWillMount!="function"&&typeof u.componentWillMount!="function"||(typeof u.componentWillMount=="function"&&u.componentWillMount(),typeof u.UNSAFE_componentWillMount=="function"&&u.UNSAFE_componentWillMount()),typeof u.componentDidMount=="function"&&(t.flags|=4194308)):(typeof u.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=x),u.props=a,u.state=x,u.context=c,a=r):(typeof u.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{u=t.stateNode,ac(l,t),c=t.memoizedProps,p=Ye(e,c),u.props=p,A=t.pendingProps,v=u.context,x=e.contextType,r=aa,typeof x=="object"&&x!==null&&(r=_l(x)),s=e.getDerivedStateFromProps,(x=typeof s=="function"||typeof u.getSnapshotBeforeUpdate=="function")||typeof u.UNSAFE_componentWillReceiveProps!="function"&&typeof u.componentWillReceiveProps!="function"||(c!==A||v!==r)&&Xd(t,u,a,r),ee=!1,v=t.memoizedState,u.state=v,ln(t,a,u,n),Pa();var b=t.memoizedState;c!==A||v!==b||ee||l!==null&&l.dependencies!==null&&uu(l.dependencies)?(typeof s=="function"&&(Tc(t,e,s,a),b=t.memoizedState),(p=ee||Qd(t,e,p,a,v,b,r)||l!==null&&l.dependencies!==null&&uu(l.dependencies))?(x||typeof u.UNSAFE_componentWillUpdate!="function"&&typeof u.componentWillUpdate!="function"||(typeof u.componentWillUpdate=="function"&&u.componentWillUpdate(a,b,r),typeof u.UNSAFE_componentWillUpdate=="function"&&u.UNSAFE_componentWillUpdate(a,b,r)),typeof u.componentDidUpdate=="function"&&(t.flags|=4),typeof u.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof u.componentDidUpdate!="function"||c===l.memoizedProps&&v===l.memoizedState||(t.flags|=4),typeof u.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&v===l.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=b),u.props=a,u.state=b,u.context=r,a=p):(typeof u.componentDidUpdate!="function"||c===l.memoizedProps&&v===l.memoizedState||(t.flags|=4),typeof u.getSnapshotBeforeUpdate!="function"||c===l.memoizedProps&&v===l.memoizedState||(t.flags|=1024),a=!1)}return u=a,zu(l,t),a=(t.flags&128)!==0,u||a?(u=t.stateNode,e=a&&typeof e.getDerivedStateFromError!="function"?null:u.render(),t.flags|=1,l!==null&&a?(t.child=Re(t,l.child,null,n),t.child=Re(t,null,e,n)):Dl(l,t,e,n),t.memoizedState=u.state,l=t.child):l=qt(l,t,n),l}function tr(l,t,e,a){return De(),t.flags|=256,Dl(l,t,e,a),t.child}var Oc={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Uc(l){return{baseLanes:l,cachePool:Vf()}}function Cc(l,t,e){return l=l!==null?l.childLanes&~e:0,t&&(l|=Il),l}function er(l,t,e){var a=t.pendingProps,n=!1,u=(t.flags&128)!==0,c;if((c=u)||(c=l!==null&&l.memoizedState===null?!1:(gl.current&2)!==0),c&&(n=!0,t.flags&=-129),c=(t.flags&32)!==0,t.flags&=-33,l===null){if($){if(n?ue(t):ie(),(l=fl)?(l=d0(l,ft),l=l!==null&&l.data!=="&"?l:null,l!==null&&(t.memoizedState={dehydrated:l,treeContext:It!==null?{id:jt,overflow:St}:null,retryLane:536870912,hydrationErrors:null},e=Bf(l),e.return=t,t.child=e,Ml=t,fl=null)):l=null,l===null)throw le(t);return gs(l)?t.lanes=32:t.lanes=536870912,null}var s=a.children;return a=a.fallback,n?(ie(),n=t.mode,s=Au({mode:"hidden",children:s},n),a=_e(a,n,e,null),s.return=t,a.return=t,s.sibling=a,t.child=s,a=t.child,a.memoizedState=Uc(e),a.childLanes=Cc(l,c,e),t.memoizedState=Oc,un(null,a)):(ue(t),Hc(t,s))}var r=l.memoizedState;if(r!==null&&(s=r.dehydrated,s!==null)){if(u)t.flags&256?(ue(t),t.flags&=-257,t=Bc(l,t,e)):t.memoizedState!==null?(ie(),t.child=l.child,t.flags|=128,t=null):(ie(),s=a.fallback,n=t.mode,a=Au({mode:"visible",children:a.children},n),s=_e(s,n,e,null),s.flags|=2,a.return=t,s.return=t,a.sibling=s,t.child=a,Re(t,l.child,null,e),a=t.child,a.memoizedState=Uc(e),a.childLanes=Cc(l,c,e),t.memoizedState=Oc,t=un(null,a));else if(ue(t),gs(s)){if(c=s.nextSibling&&s.nextSibling.dataset,c)var x=c.dgst;c=x,a=Error(d(419)),a.stack="",a.digest=c,ka({value:a,source:null,stack:null}),t=Bc(l,t,e)}else if(bl||ca(l,t,e,!1),c=(e&l.childLanes)!==0,bl||c){if(c=ul,c!==null&&(a=Gs(c,e),a!==0&&a!==r.retryLane))throw r.retryLane=a,Me(l,a),Gl(c,l,a),_c;hs(s)||Hu(),t=Bc(l,t,e)}else hs(s)?(t.flags|=192,t.child=l.child,t=null):(l=r.treeContext,fl=rt(s.nextSibling),Ml=t,$=!0,Pt=null,ft=!1,l!==null&&Yf(t,l),t=Hc(t,a.children),t.flags|=4096);return t}return n?(ie(),s=a.fallback,n=t.mode,r=l.child,x=r.sibling,a=Ot(r,{mode:"hidden",children:a.children}),a.subtreeFlags=r.subtreeFlags&65011712,x!==null?s=Ot(x,s):(s=_e(s,n,e,null),s.flags|=2),s.return=t,a.return=t,a.sibling=s,t.child=a,un(null,a),a=t.child,s=l.child.memoizedState,s===null?s=Uc(e):(n=s.cachePool,n!==null?(r=xl._currentValue,n=n.parent!==r?{parent:r,pool:r}:n):n=Vf(),s={baseLanes:s.baseLanes|e,cachePool:n}),a.memoizedState=s,a.childLanes=Cc(l,c,e),t.memoizedState=Oc,un(l.child,a)):(ue(t),e=l.child,l=e.sibling,e=Ot(e,{mode:"visible",children:a.children}),e.return=t,e.sibling=null,l!==null&&(c=t.deletions,c===null?(t.deletions=[l],t.flags|=16):c.push(l)),t.child=e,t.memoizedState=null,e)}function Hc(l,t){return t=Au({mode:"visible",children:t},l.mode),t.return=l,l.child=t}function Au(l,t){return l=wl(22,l,null,t),l.lanes=0,l}function Bc(l,t,e){return Re(t,l.child,null,e),l=Hc(t,t.pendingProps.children),l.flags|=2,t.memoizedState=null,l}function ar(l,t,e){l.lanes|=t;var a=l.alternate;a!==null&&(a.lanes|=t),Wi(l.return,t,e)}function Rc(l,t,e,a,n,u){var c=l.memoizedState;c===null?l.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:e,tailMode:n,treeForkCount:u}:(c.isBackwards=t,c.rendering=null,c.renderingStartTime=0,c.last=a,c.tail=e,c.tailMode=n,c.treeForkCount=u)}function nr(l,t,e){var a=t.pendingProps,n=a.revealOrder,u=a.tail;a=a.children;var c=gl.current,s=(c&2)!==0;if(s?(c=c&1|2,t.flags|=128):c&=1,P(gl,c),Dl(l,t,a,e),a=$?Ja:0,!s&&l!==null&&(l.flags&128)!==0)l:for(l=t.child;l!==null;){if(l.tag===13)l.memoizedState!==null&&ar(l,e,t);else if(l.tag===19)ar(l,e,t);else if(l.child!==null){l.child.return=l,l=l.child;continue}if(l===t)break l;for(;l.sibling===null;){if(l.return===null||l.return===t)break l;l=l.return}l.sibling.return=l.return,l=l.sibling}switch(n){case"forwards":for(e=t.child,n=null;e!==null;)l=e.alternate,l!==null&&mu(l)===null&&(n=e),e=e.sibling;e=n,e===null?(n=t.child,t.child=null):(n=e.sibling,e.sibling=null),Rc(t,!1,n,e,u,a);break;case"backwards":case"unstable_legacy-backwards":for(e=null,n=t.child,t.child=null;n!==null;){if(l=n.alternate,l!==null&&mu(l)===null){t.child=n;break}l=n.sibling,n.sibling=e,e=n,n=l}Rc(t,!0,e,null,u,a);break;case"together":Rc(t,!1,null,null,void 0,a);break;default:t.memoizedState=null}return t.child}function qt(l,t,e){if(l!==null&&(t.dependencies=l.dependencies),fe|=t.lanes,(e&t.childLanes)===0)if(l!==null){if(ca(l,t,e,!1),(e&t.childLanes)===0)return null}else return null;if(l!==null&&t.child!==l.child)throw Error(d(153));if(t.child!==null){for(l=t.child,e=Ot(l,l.pendingProps),t.child=e,e.return=t;l.sibling!==null;)l=l.sibling,e=e.sibling=Ot(l,l.pendingProps),e.return=t;e.sibling=null}return t.child}function qc(l,t){return(l.lanes&t)!==0?!0:(l=l.dependencies,!!(l!==null&&uu(l)))}function hm(l,t,e){switch(t.tag){case 3:Rn(t,t.stateNode.containerInfo),te(t,xl,l.memoizedState.cache),De();break;case 27:case 5:ci(t);break;case 4:Rn(t,t.stateNode.containerInfo);break;case 10:te(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,sc(t),null;break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(ue(t),t.flags|=128,null):(e&t.child.childLanes)!==0?er(l,t,e):(ue(t),l=qt(l,t,e),l!==null?l.sibling:null);ue(t);break;case 19:var n=(l.flags&128)!==0;if(a=(e&t.childLanes)!==0,a||(ca(l,t,e,!1),a=(e&t.childLanes)!==0),n){if(a)return nr(l,t,e);t.flags|=128}if(n=t.memoizedState,n!==null&&(n.rendering=null,n.tail=null,n.lastEffect=null),P(gl,gl.current),a)break;return null;case 22:return t.lanes=0,Wd(l,t,e,t.pendingProps);case 24:te(t,xl,l.memoizedState.cache)}return qt(l,t,e)}function ur(l,t,e){if(l!==null)if(l.memoizedProps!==t.pendingProps)bl=!0;else{if(!qc(l,e)&&(t.flags&128)===0)return bl=!1,hm(l,t,e);bl=(l.flags&131072)!==0}else bl=!1,$&&(t.flags&1048576)!==0&&qf(t,Ja,t.index);switch(t.lanes=0,t.tag){case 16:l:{var a=t.pendingProps;if(l=He(t.elementType),t.type=l,typeof l=="function")Li(l)?(a=Ye(l,a),t.tag=1,t=lr(null,t,l,a,e)):(t.tag=0,t=Dc(null,t,l,a,e));else{if(l!=null){var n=l.$$typeof;if(n===lt){t.tag=11,t=kd(null,t,l,a,e);break l}else if(n===ht){t.tag=14,t=wd(null,t,l,a,e);break l}}throw t=Oa(l)||l,Error(d(306,t,""))}}return t;case 0:return Dc(l,t,t.type,t.pendingProps,e);case 1:return a=t.type,n=Ye(a,t.pendingProps),lr(l,t,a,n,e);case 3:l:{if(Rn(t,t.stateNode.containerInfo),l===null)throw Error(d(387));a=t.pendingProps;var u=t.memoizedState;n=u.element,ac(l,t),ln(t,a,null,e);var c=t.memoizedState;if(a=c.cache,te(t,xl,a),a!==u.cache&&Fi(t,[xl],e,!0),Pa(),a=c.element,u.isDehydrated)if(u={element:a,isDehydrated:!1,cache:c.cache},t.updateQueue.baseState=u,t.memoizedState=u,t.flags&256){t=tr(l,t,a,e);break l}else if(a!==n){n=it(Error(d(424)),t),ka(n),t=tr(l,t,a,e);break l}else{switch(l=t.stateNode.containerInfo,l.nodeType){case 9:l=l.body;break;default:l=l.nodeName==="HTML"?l.ownerDocument.body:l}for(fl=rt(l.firstChild),Ml=t,$=!0,Pt=null,ft=!0,e=Wf(t,null,a,e),t.child=e;e;)e.flags=e.flags&-3|4096,e=e.sibling}else{if(De(),a===n){t=qt(l,t,e);break l}Dl(l,t,a,e)}t=t.child}return t;case 26:return zu(l,t),l===null?(e=y0(t.type,null,t.pendingProps,null))?t.memoizedState=e:$||(e=t.type,l=t.pendingProps,a=Gu(wt.current).createElement(e),a[El]=t,a[Bl]=l,Ol(a,e,l),zl(a),t.stateNode=a):t.memoizedState=y0(t.type,l.memoizedProps,t.pendingProps,l.memoizedState),null;case 27:return ci(t),l===null&&$&&(a=t.stateNode=m0(t.type,t.pendingProps,wt.current),Ml=t,ft=!0,n=fl,he(t.type)?(ys=n,fl=rt(a.firstChild)):fl=n),Dl(l,t,t.pendingProps.children,e),zu(l,t),l===null&&(t.flags|=4194304),t.child;case 5:return l===null&&$&&((n=a=fl)&&(a=Vm(a,t.type,t.pendingProps,ft),a!==null?(t.stateNode=a,Ml=t,fl=rt(a.firstChild),ft=!1,n=!0):n=!1),n||le(t)),ci(t),n=t.type,u=t.pendingProps,c=l!==null?l.memoizedProps:null,a=u.children,rs(n,u)?a=null:c!==null&&rs(n,c)&&(t.flags|=32),t.memoizedState!==null&&(n=dc(l,t,um,null,null,e),jn._currentValue=n),zu(l,t),Dl(l,t,a,e),t.child;case 6:return l===null&&$&&((l=e=fl)&&(e=Km(e,t.pendingProps,ft),e!==null?(t.stateNode=e,Ml=t,fl=null,l=!0):l=!1),l||le(t)),null;case 13:return er(l,t,e);case 4:return Rn(t,t.stateNode.containerInfo),a=t.pendingProps,l===null?t.child=Re(t,null,a,e):Dl(l,t,a,e),t.child;case 11:return kd(l,t,t.type,t.pendingProps,e);case 7:return Dl(l,t,t.pendingProps,e),t.child;case 8:return Dl(l,t,t.pendingProps.children,e),t.child;case 12:return Dl(l,t,t.pendingProps.children,e),t.child;case 10:return a=t.pendingProps,te(t,t.type,a.value),Dl(l,t,a.children,e),t.child;case 9:return n=t.type._context,a=t.pendingProps.children,Ue(t),n=_l(n),a=a(n),t.flags|=1,Dl(l,t,a,e),t.child;case 14:return wd(l,t,t.type,t.pendingProps,e);case 15:return $d(l,t,t.type,t.pendingProps,e);case 19:return nr(l,t,e);case 31:return mm(l,t,e);case 22:return Wd(l,t,e,t.pendingProps);case 24:return Ue(t),a=_l(xl),l===null?(n=lc(),n===null&&(n=ul,u=Ii(),n.pooledCache=u,u.refCount++,u!==null&&(n.pooledCacheLanes|=e),n=u),t.memoizedState={parent:a,cache:n},ec(t),te(t,xl,n)):((l.lanes&e)!==0&&(ac(l,t),ln(t,null,null,e),Pa()),n=l.memoizedState,u=t.memoizedState,n.parent!==a?(n={parent:a,cache:a},t.memoizedState=n,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=n),te(t,xl,a)):(a=u.cache,te(t,xl,a),a!==n.cache&&Fi(t,[xl],e,!0))),Dl(l,t,t.pendingProps.children,e),t.child;case 29:throw t.pendingProps}throw Error(d(156,t.tag))}function Yt(l){l.flags|=4}function Yc(l,t,e,a,n){if((t=(l.mode&32)!==0)&&(t=!1),t){if(l.flags|=16777216,(n&335544128)===n)if(l.stateNode.complete)l.flags|=8192;else if(Ur())l.flags|=8192;else throw Be=fu,tc}else l.flags&=-16777217}function ir(l,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)l.flags&=-16777217;else if(l.flags|=16777216,!j0(t))if(Ur())l.flags|=8192;else throw Be=fu,tc}function Tu(l,t){t!==null&&(l.flags|=4),l.flags&16384&&(t=l.tag!==22?Ys():536870912,l.lanes|=t,ba|=t)}function cn(l,t){if(!$)switch(l.tailMode){case"hidden":t=l.tail;for(var e=null;t!==null;)t.alternate!==null&&(e=t),t=t.sibling;e===null?l.tail=null:e.sibling=null;break;case"collapsed":e=l.tail;for(var a=null;e!==null;)e.alternate!==null&&(a=e),e=e.sibling;a===null?t||l.tail===null?l.tail=null:l.tail.sibling=null:a.sibling=null}}function dl(l){var t=l.alternate!==null&&l.alternate.child===l.child,e=0,a=0;if(t)for(var n=l.child;n!==null;)e|=n.lanes|n.childLanes,a|=n.subtreeFlags&65011712,a|=n.flags&65011712,n.return=l,n=n.sibling;else for(n=l.child;n!==null;)e|=n.lanes|n.childLanes,a|=n.subtreeFlags,a|=n.flags,n.return=l,n=n.sibling;return l.subtreeFlags|=a,l.childLanes=e,t}function gm(l,t,e){var a=t.pendingProps;switch(Ji(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return dl(t),null;case 1:return dl(t),null;case 3:return e=t.stateNode,a=null,l!==null&&(a=l.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),Ht(xl),Ze(),e.pendingContext&&(e.context=e.pendingContext,e.pendingContext=null),(l===null||l.child===null)&&(ia(t)?Yt(t):l===null||l.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,wi())),dl(t),null;case 26:var n=t.type,u=t.memoizedState;return l===null?(Yt(t),u!==null?(dl(t),ir(t,u)):(dl(t),Yc(t,n,null,a,e))):u?u!==l.memoizedState?(Yt(t),dl(t),ir(t,u)):(dl(t),t.flags&=-16777217):(l=l.memoizedProps,l!==a&&Yt(t),dl(t),Yc(t,n,l,a,e)),null;case 27:if(qn(t),e=wt.current,n=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(d(166));return dl(t),null}l=Nl.current,ia(t)?Qf(t):(l=m0(n,a,e),t.stateNode=l,Yt(t))}return dl(t),null;case 5:if(qn(t),n=t.type,l!==null&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(!a){if(t.stateNode===null)throw Error(d(166));return dl(t),null}if(u=Nl.current,ia(t))Qf(t);else{var c=Gu(wt.current);switch(u){case 1:u=c.createElementNS("http://www.w3.org/2000/svg",n);break;case 2:u=c.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;default:switch(n){case"svg":u=c.createElementNS("http://www.w3.org/2000/svg",n);break;case"math":u=c.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;case"script":u=c.createElement("div"),u.innerHTML="<script><\/script>",u=u.removeChild(u.firstChild);break;case"select":u=typeof a.is=="string"?c.createElement("select",{is:a.is}):c.createElement("select"),a.multiple?u.multiple=!0:a.size&&(u.size=a.size);break;default:u=typeof a.is=="string"?c.createElement(n,{is:a.is}):c.createElement(n)}}u[El]=t,u[Bl]=a;l:for(c=t.child;c!==null;){if(c.tag===5||c.tag===6)u.appendChild(c.stateNode);else if(c.tag!==4&&c.tag!==27&&c.child!==null){c.child.return=c,c=c.child;continue}if(c===t)break l;for(;c.sibling===null;){if(c.return===null||c.return===t)break l;c=c.return}c.sibling.return=c.return,c=c.sibling}t.stateNode=u;l:switch(Ol(u,n,a),n){case"button":case"input":case"select":case"textarea":a=!!a.autoFocus;break l;case"img":a=!0;break l;default:a=!1}a&&Yt(t)}}return dl(t),Yc(t,t.type,l===null?null:l.memoizedProps,t.pendingProps,e),null;case 6:if(l&&t.stateNode!=null)l.memoizedProps!==a&&Yt(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(d(166));if(l=wt.current,ia(t)){if(l=t.stateNode,e=t.memoizedProps,a=null,n=Ml,n!==null)switch(n.tag){case 27:case 5:a=n.memoizedProps}l[El]=t,l=!!(l.nodeValue===e||a!==null&&a.suppressHydrationWarning===!0||e0(l.nodeValue,e)),l||le(t,!0)}else l=Gu(l).createTextNode(a),l[El]=t,t.stateNode=l}return dl(t),null;case 31:if(e=t.memoizedState,l===null||l.memoizedState!==null){if(a=ia(t),e!==null){if(l===null){if(!a)throw Error(d(318));if(l=t.memoizedState,l=l!==null?l.dehydrated:null,!l)throw Error(d(557));l[El]=t}else De(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;dl(t),l=!1}else e=wi(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=e),l=!0;if(!l)return t.flags&256?(Wl(t),t):(Wl(t),null);if((t.flags&128)!==0)throw Error(d(558))}return dl(t),null;case 13:if(a=t.memoizedState,l===null||l.memoizedState!==null&&l.memoizedState.dehydrated!==null){if(n=ia(t),a!==null&&a.dehydrated!==null){if(l===null){if(!n)throw Error(d(318));if(n=t.memoizedState,n=n!==null?n.dehydrated:null,!n)throw Error(d(317));n[El]=t}else De(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;dl(t),n=!1}else n=wi(),l!==null&&l.memoizedState!==null&&(l.memoizedState.hydrationErrors=n),n=!0;if(!n)return t.flags&256?(Wl(t),t):(Wl(t),null)}return Wl(t),(t.flags&128)!==0?(t.lanes=e,t):(e=a!==null,l=l!==null&&l.memoizedState!==null,e&&(a=t.child,n=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(n=a.alternate.memoizedState.cachePool.pool),u=null,a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(u=a.memoizedState.cachePool.pool),u!==n&&(a.flags|=2048)),e!==l&&e&&(t.child.flags|=8192),Tu(t,t.updateQueue),dl(t),null);case 4:return Ze(),l===null&&is(t.stateNode.containerInfo),dl(t),null;case 10:return Ht(t.type),dl(t),null;case 19:if(ol(gl),a=t.memoizedState,a===null)return dl(t),null;if(n=(t.flags&128)!==0,u=a.rendering,u===null)if(n)cn(a,!1);else{if(hl!==0||l!==null&&(l.flags&128)!==0)for(l=t.child;l!==null;){if(u=mu(l),u!==null){for(t.flags|=128,cn(a,!1),l=u.updateQueue,t.updateQueue=l,Tu(t,l),t.subtreeFlags=0,l=e,e=t.child;e!==null;)Hf(e,l),e=e.sibling;return P(gl,gl.current&1|2),$&&Ut(t,a.treeForkCount),t.child}l=l.sibling}a.tail!==null&&Vl()>Ou&&(t.flags|=128,n=!0,cn(a,!1),t.lanes=4194304)}else{if(!n)if(l=mu(u),l!==null){if(t.flags|=128,n=!0,l=l.updateQueue,t.updateQueue=l,Tu(t,l),cn(a,!0),a.tail===null&&a.tailMode==="hidden"&&!u.alternate&&!$)return dl(t),null}else 2*Vl()-a.renderingStartTime>Ou&&e!==536870912&&(t.flags|=128,n=!0,cn(a,!1),t.lanes=4194304);a.isBackwards?(u.sibling=t.child,t.child=u):(l=a.last,l!==null?l.sibling=u:t.child=u,a.last=u)}return a.tail!==null?(l=a.tail,a.rendering=l,a.tail=l.sibling,a.renderingStartTime=Vl(),l.sibling=null,e=gl.current,P(gl,n?e&1|2:e&1),$&&Ut(t,a.treeForkCount),l):(dl(t),null);case 22:case 23:return Wl(t),cc(),a=t.memoizedState!==null,l!==null?l.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(e&536870912)!==0&&(t.flags&128)===0&&(dl(t),t.subtreeFlags&6&&(t.flags|=8192)):dl(t),e=t.updateQueue,e!==null&&Tu(t,e.retryQueue),e=null,l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(e=l.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==e&&(t.flags|=2048),l!==null&&ol(Ce),null;case 24:return e=null,l!==null&&(e=l.memoizedState.cache),t.memoizedState.cache!==e&&(t.flags|=2048),Ht(xl),dl(t),null;case 25:return null;case 30:return null}throw Error(d(156,t.tag))}function ym(l,t){switch(Ji(t),t.tag){case 1:return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 3:return Ht(xl),Ze(),l=t.flags,(l&65536)!==0&&(l&128)===0?(t.flags=l&-65537|128,t):null;case 26:case 27:case 5:return qn(t),null;case 31:if(t.memoizedState!==null){if(Wl(t),t.alternate===null)throw Error(d(340));De()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 13:if(Wl(t),l=t.memoizedState,l!==null&&l.dehydrated!==null){if(t.alternate===null)throw Error(d(340));De()}return l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 19:return ol(gl),null;case 4:return Ze(),null;case 10:return Ht(t.type),null;case 22:case 23:return Wl(t),cc(),l!==null&&ol(Ce),l=t.flags,l&65536?(t.flags=l&-65537|128,t):null;case 24:return Ht(xl),null;case 25:return null;default:return null}}function cr(l,t){switch(Ji(t),t.tag){case 3:Ht(xl),Ze();break;case 26:case 27:case 5:qn(t);break;case 4:Ze();break;case 31:t.memoizedState!==null&&Wl(t);break;case 13:Wl(t);break;case 19:ol(gl);break;case 10:Ht(t.type);break;case 22:case 23:Wl(t),cc(),l!==null&&ol(Ce);break;case 24:Ht(xl)}}function sn(l,t){try{var e=t.updateQueue,a=e!==null?e.lastEffect:null;if(a!==null){var n=a.next;e=n;do{if((e.tag&l)===l){a=void 0;var u=e.create,c=e.inst;a=u(),c.destroy=a}e=e.next}while(e!==n)}}catch(s){tl(t,t.return,s)}}function ce(l,t,e){try{var a=t.updateQueue,n=a!==null?a.lastEffect:null;if(n!==null){var u=n.next;a=u;do{if((a.tag&l)===l){var c=a.inst,s=c.destroy;if(s!==void 0){c.destroy=void 0,n=t;var r=e,x=s;try{x()}catch(p){tl(n,r,p)}}}a=a.next}while(a!==u)}}catch(p){tl(t,t.return,p)}}function sr(l){var t=l.updateQueue;if(t!==null){var e=l.stateNode;try{If(t,e)}catch(a){tl(l,l.return,a)}}}function fr(l,t,e){e.props=Ye(l.type,l.memoizedProps),e.state=l.memoizedState;try{e.componentWillUnmount()}catch(a){tl(l,t,a)}}function fn(l,t){try{var e=l.ref;if(e!==null){switch(l.tag){case 26:case 27:case 5:var a=l.stateNode;break;case 30:a=l.stateNode;break;default:a=l.stateNode}typeof e=="function"?l.refCleanup=e(a):e.current=a}}catch(n){tl(l,t,n)}}function Nt(l,t){var e=l.ref,a=l.refCleanup;if(e!==null)if(typeof a=="function")try{a()}catch(n){tl(l,t,n)}finally{l.refCleanup=null,l=l.alternate,l!=null&&(l.refCleanup=null)}else if(typeof e=="function")try{e(null)}catch(n){tl(l,t,n)}else e.current=null}function dr(l){var t=l.type,e=l.memoizedProps,a=l.stateNode;try{l:switch(t){case"button":case"input":case"select":case"textarea":e.autoFocus&&a.focus();break l;case"img":e.src?a.src=e.src:e.srcSet&&(a.srcset=e.srcSet)}}catch(n){tl(l,l.return,n)}}function Qc(l,t,e){try{var a=l.stateNode;Ym(a,l.type,e,t),a[Bl]=t}catch(n){tl(l,l.return,n)}}function rr(l){return l.tag===5||l.tag===3||l.tag===26||l.tag===27&&he(l.type)||l.tag===4}function Xc(l){l:for(;;){for(;l.sibling===null;){if(l.return===null||rr(l.return))return null;l=l.return}for(l.sibling.return=l.return,l=l.sibling;l.tag!==5&&l.tag!==6&&l.tag!==18;){if(l.tag===27&&he(l.type)||l.flags&2||l.child===null||l.tag===4)continue l;l.child.return=l,l=l.child}if(!(l.flags&2))return l.stateNode}}function Gc(l,t,e){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e).insertBefore(l,t):(t=e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,t.appendChild(l),e=e._reactRootContainer,e!=null||t.onclick!==null||(t.onclick=_t));else if(a!==4&&(a===27&&he(l.type)&&(e=l.stateNode,t=null),l=l.child,l!==null))for(Gc(l,t,e),l=l.sibling;l!==null;)Gc(l,t,e),l=l.sibling}function Eu(l,t,e){var a=l.tag;if(a===5||a===6)l=l.stateNode,t?e.insertBefore(l,t):e.appendChild(l);else if(a!==4&&(a===27&&he(l.type)&&(e=l.stateNode),l=l.child,l!==null))for(Eu(l,t,e),l=l.sibling;l!==null;)Eu(l,t,e),l=l.sibling}function or(l){var t=l.stateNode,e=l.memoizedProps;try{for(var a=l.type,n=t.attributes;n.length;)t.removeAttributeNode(n[0]);Ol(t,a,e),t[El]=l,t[Bl]=e}catch(u){tl(l,l.return,u)}}var Qt=!1,pl=!1,Lc=!1,mr=typeof WeakSet=="function"?WeakSet:Set,Al=null;function xm(l,t){if(l=l.containerInfo,fs=wu,l=Af(l),Bi(l)){if("selectionStart"in l)var e={start:l.selectionStart,end:l.selectionEnd};else l:{e=(e=l.ownerDocument)&&e.defaultView||window;var a=e.getSelection&&e.getSelection();if(a&&a.rangeCount!==0){e=a.anchorNode;var n=a.anchorOffset,u=a.focusNode;a=a.focusOffset;try{e.nodeType,u.nodeType}catch{e=null;break l}var c=0,s=-1,r=-1,x=0,p=0,A=l,v=null;t:for(;;){for(var b;A!==e||n!==0&&A.nodeType!==3||(s=c+n),A!==u||a!==0&&A.nodeType!==3||(r=c+a),A.nodeType===3&&(c+=A.nodeValue.length),(b=A.firstChild)!==null;)v=A,A=b;for(;;){if(A===l)break t;if(v===e&&++x===n&&(s=c),v===u&&++p===a&&(r=c),(b=A.nextSibling)!==null)break;A=v,v=A.parentNode}A=b}e=s===-1||r===-1?null:{start:s,end:r}}else e=null}e=e||{start:0,end:0}}else e=null;for(ds={focusedElem:l,selectionRange:e},wu=!1,Al=t;Al!==null;)if(t=Al,l=t.child,(t.subtreeFlags&1028)!==0&&l!==null)l.return=t,Al=l;else for(;Al!==null;){switch(t=Al,u=t.alternate,l=t.flags,t.tag){case 0:if((l&4)!==0&&(l=t.updateQueue,l=l!==null?l.events:null,l!==null))for(e=0;e<l.length;e++)n=l[e],n.ref.impl=n.nextImpl;break;case 11:case 15:break;case 1:if((l&1024)!==0&&u!==null){l=void 0,e=t,n=u.memoizedProps,u=u.memoizedState,a=e.stateNode;try{var O=Ye(e.type,n);l=a.getSnapshotBeforeUpdate(O,u),a.__reactInternalSnapshotBeforeUpdate=l}catch(B){tl(e,e.return,B)}}break;case 3:if((l&1024)!==0){if(l=t.stateNode.containerInfo,e=l.nodeType,e===9)ms(l);else if(e===1)switch(l.nodeName){case"HEAD":case"HTML":case"BODY":ms(l);break;default:l.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((l&1024)!==0)throw Error(d(163))}if(l=t.sibling,l!==null){l.return=t.return,Al=l;break}Al=t.return}}function hr(l,t,e){var a=e.flags;switch(e.tag){case 0:case 11:case 15:Gt(l,e),a&4&&sn(5,e);break;case 1:if(Gt(l,e),a&4)if(l=e.stateNode,t===null)try{l.componentDidMount()}catch(c){tl(e,e.return,c)}else{var n=Ye(e.type,t.memoizedProps);t=t.memoizedState;try{l.componentDidUpdate(n,t,l.__reactInternalSnapshotBeforeUpdate)}catch(c){tl(e,e.return,c)}}a&64&&sr(e),a&512&&fn(e,e.return);break;case 3:if(Gt(l,e),a&64&&(l=e.updateQueue,l!==null)){if(t=null,e.child!==null)switch(e.child.tag){case 27:case 5:t=e.child.stateNode;break;case 1:t=e.child.stateNode}try{If(l,t)}catch(c){tl(e,e.return,c)}}break;case 27:t===null&&a&4&&or(e);case 26:case 5:Gt(l,e),t===null&&a&4&&dr(e),a&512&&fn(e,e.return);break;case 12:Gt(l,e);break;case 31:Gt(l,e),a&4&&xr(l,e);break;case 13:Gt(l,e),a&4&&vr(l,e),a&64&&(l=e.memoizedState,l!==null&&(l=l.dehydrated,l!==null&&(e=Tm.bind(null,e),Jm(l,e))));break;case 22:if(a=e.memoizedState!==null||Qt,!a){t=t!==null&&t.memoizedState!==null||pl,n=Qt;var u=pl;Qt=a,(pl=t)&&!u?Lt(l,e,(e.subtreeFlags&8772)!==0):Gt(l,e),Qt=n,pl=u}break;case 30:break;default:Gt(l,e)}}function gr(l){var t=l.alternate;t!==null&&(l.alternate=null,gr(t)),l.child=null,l.deletions=null,l.sibling=null,l.tag===5&&(t=l.stateNode,t!==null&&vi(t)),l.stateNode=null,l.return=null,l.dependencies=null,l.memoizedProps=null,l.memoizedState=null,l.pendingProps=null,l.stateNode=null,l.updateQueue=null}var rl=null,ql=!1;function Xt(l,t,e){for(e=e.child;e!==null;)yr(l,t,e),e=e.sibling}function yr(l,t,e){if(Kl&&typeof Kl.onCommitFiberUnmount=="function")try{Kl.onCommitFiberUnmount(Ua,e)}catch{}switch(e.tag){case 26:pl||Nt(e,t),Xt(l,t,e),e.memoizedState?e.memoizedState.count--:e.stateNode&&(e=e.stateNode,e.parentNode.removeChild(e));break;case 27:pl||Nt(e,t);var a=rl,n=ql;he(e.type)&&(rl=e.stateNode,ql=!1),Xt(l,t,e),vn(e.stateNode),rl=a,ql=n;break;case 5:pl||Nt(e,t);case 6:if(a=rl,n=ql,rl=null,Xt(l,t,e),rl=a,ql=n,rl!==null)if(ql)try{(rl.nodeType===9?rl.body:rl.nodeName==="HTML"?rl.ownerDocument.body:rl).removeChild(e.stateNode)}catch(u){tl(e,t,u)}else try{rl.removeChild(e.stateNode)}catch(u){tl(e,t,u)}break;case 18:rl!==null&&(ql?(l=rl,s0(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,e.stateNode),Ea(l)):s0(rl,e.stateNode));break;case 4:a=rl,n=ql,rl=e.stateNode.containerInfo,ql=!0,Xt(l,t,e),rl=a,ql=n;break;case 0:case 11:case 14:case 15:ce(2,e,t),pl||ce(4,e,t),Xt(l,t,e);break;case 1:pl||(Nt(e,t),a=e.stateNode,typeof a.componentWillUnmount=="function"&&fr(e,t,a)),Xt(l,t,e);break;case 21:Xt(l,t,e);break;case 22:pl=(a=pl)||e.memoizedState!==null,Xt(l,t,e),pl=a;break;default:Xt(l,t,e)}}function xr(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null))){l=l.dehydrated;try{Ea(l)}catch(e){tl(t,t.return,e)}}}function vr(l,t){if(t.memoizedState===null&&(l=t.alternate,l!==null&&(l=l.memoizedState,l!==null&&(l=l.dehydrated,l!==null))))try{Ea(l)}catch(e){tl(t,t.return,e)}}function vm(l){switch(l.tag){case 31:case 13:case 19:var t=l.stateNode;return t===null&&(t=l.stateNode=new mr),t;case 22:return l=l.stateNode,t=l._retryCache,t===null&&(t=l._retryCache=new mr),t;default:throw Error(d(435,l.tag))}}function Mu(l,t){var e=vm(l);t.forEach(function(a){if(!e.has(a)){e.add(a);var n=Em.bind(null,l,a);a.then(n,n)}})}function Yl(l,t){var e=t.deletions;if(e!==null)for(var a=0;a<e.length;a++){var n=e[a],u=l,c=t,s=c;l:for(;s!==null;){switch(s.tag){case 27:if(he(s.type)){rl=s.stateNode,ql=!1;break l}break;case 5:rl=s.stateNode,ql=!1;break l;case 3:case 4:rl=s.stateNode.containerInfo,ql=!0;break l}s=s.return}if(rl===null)throw Error(d(160));yr(u,c,n),rl=null,ql=!1,u=n.alternate,u!==null&&(u.return=null),n.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)br(t,l),t=t.sibling}var yt=null;function br(l,t){var e=l.alternate,a=l.flags;switch(l.tag){case 0:case 11:case 14:case 15:Yl(t,l),Ql(l),a&4&&(ce(3,l,l.return),sn(3,l),ce(5,l,l.return));break;case 1:Yl(t,l),Ql(l),a&512&&(pl||e===null||Nt(e,e.return)),a&64&&Qt&&(l=l.updateQueue,l!==null&&(a=l.callbacks,a!==null&&(e=l.shared.hiddenCallbacks,l.shared.hiddenCallbacks=e===null?a:e.concat(a))));break;case 26:var n=yt;if(Yl(t,l),Ql(l),a&512&&(pl||e===null||Nt(e,e.return)),a&4){var u=e!==null?e.memoizedState:null;if(a=l.memoizedState,e===null)if(a===null)if(l.stateNode===null){l:{a=l.type,e=l.memoizedProps,n=n.ownerDocument||n;t:switch(a){case"title":u=n.getElementsByTagName("title")[0],(!u||u[Ba]||u[El]||u.namespaceURI==="http://www.w3.org/2000/svg"||u.hasAttribute("itemprop"))&&(u=n.createElement(a),n.head.insertBefore(u,n.querySelector("head > title"))),Ol(u,a,e),u[El]=l,zl(u),a=u;break l;case"link":var c=b0("link","href",n).get(a+(e.href||""));if(c){for(var s=0;s<c.length;s++)if(u=c[s],u.getAttribute("href")===(e.href==null||e.href===""?null:e.href)&&u.getAttribute("rel")===(e.rel==null?null:e.rel)&&u.getAttribute("title")===(e.title==null?null:e.title)&&u.getAttribute("crossorigin")===(e.crossOrigin==null?null:e.crossOrigin)){c.splice(s,1);break t}}u=n.createElement(a),Ol(u,a,e),n.head.appendChild(u);break;case"meta":if(c=b0("meta","content",n).get(a+(e.content||""))){for(s=0;s<c.length;s++)if(u=c[s],u.getAttribute("content")===(e.content==null?null:""+e.content)&&u.getAttribute("name")===(e.name==null?null:e.name)&&u.getAttribute("property")===(e.property==null?null:e.property)&&u.getAttribute("http-equiv")===(e.httpEquiv==null?null:e.httpEquiv)&&u.getAttribute("charset")===(e.charSet==null?null:e.charSet)){c.splice(s,1);break t}}u=n.createElement(a),Ol(u,a,e),n.head.appendChild(u);break;default:throw Error(d(468,a))}u[El]=l,zl(u),a=u}l.stateNode=a}else p0(n,l.type,l.stateNode);else l.stateNode=v0(n,a,l.memoizedProps);else u!==a?(u===null?e.stateNode!==null&&(e=e.stateNode,e.parentNode.removeChild(e)):u.count--,a===null?p0(n,l.type,l.stateNode):v0(n,a,l.memoizedProps)):a===null&&l.stateNode!==null&&Qc(l,l.memoizedProps,e.memoizedProps)}break;case 27:Yl(t,l),Ql(l),a&512&&(pl||e===null||Nt(e,e.return)),e!==null&&a&4&&Qc(l,l.memoizedProps,e.memoizedProps);break;case 5:if(Yl(t,l),Ql(l),a&512&&(pl||e===null||Nt(e,e.return)),l.flags&32){n=l.stateNode;try{We(n,"")}catch(O){tl(l,l.return,O)}}a&4&&l.stateNode!=null&&(n=l.memoizedProps,Qc(l,n,e!==null?e.memoizedProps:n)),a&1024&&(Lc=!0);break;case 6:if(Yl(t,l),Ql(l),a&4){if(l.stateNode===null)throw Error(d(162));a=l.memoizedProps,e=l.stateNode;try{e.nodeValue=a}catch(O){tl(l,l.return,O)}}break;case 3:if(Vu=null,n=yt,yt=Lu(t.containerInfo),Yl(t,l),yt=n,Ql(l),a&4&&e!==null&&e.memoizedState.isDehydrated)try{Ea(t.containerInfo)}catch(O){tl(l,l.return,O)}Lc&&(Lc=!1,pr(l));break;case 4:a=yt,yt=Lu(l.stateNode.containerInfo),Yl(t,l),Ql(l),yt=a;break;case 12:Yl(t,l),Ql(l);break;case 31:Yl(t,l),Ql(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,Mu(l,a)));break;case 13:Yl(t,l),Ql(l),l.child.flags&8192&&l.memoizedState!==null!=(e!==null&&e.memoizedState!==null)&&(Du=Vl()),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,Mu(l,a)));break;case 22:n=l.memoizedState!==null;var r=e!==null&&e.memoizedState!==null,x=Qt,p=pl;if(Qt=x||n,pl=p||r,Yl(t,l),pl=p,Qt=x,Ql(l),a&8192)l:for(t=l.stateNode,t._visibility=n?t._visibility&-2:t._visibility|1,n&&(e===null||r||Qt||pl||Qe(l)),e=null,t=l;;){if(t.tag===5||t.tag===26){if(e===null){r=e=t;try{if(u=r.stateNode,n)c=u.style,typeof c.setProperty=="function"?c.setProperty("display","none","important"):c.display="none";else{s=r.stateNode;var A=r.memoizedProps.style,v=A!=null&&A.hasOwnProperty("display")?A.display:null;s.style.display=v==null||typeof v=="boolean"?"":(""+v).trim()}}catch(O){tl(r,r.return,O)}}}else if(t.tag===6){if(e===null){r=t;try{r.stateNode.nodeValue=n?"":r.memoizedProps}catch(O){tl(r,r.return,O)}}}else if(t.tag===18){if(e===null){r=t;try{var b=r.stateNode;n?f0(b,!0):f0(r.stateNode,!1)}catch(O){tl(r,r.return,O)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===l)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===l)break l;for(;t.sibling===null;){if(t.return===null||t.return===l)break l;e===t&&(e=null),t=t.return}e===t&&(e=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=l.updateQueue,a!==null&&(e=a.retryQueue,e!==null&&(a.retryQueue=null,Mu(l,e))));break;case 19:Yl(t,l),Ql(l),a&4&&(a=l.updateQueue,a!==null&&(l.updateQueue=null,Mu(l,a)));break;case 30:break;case 21:break;default:Yl(t,l),Ql(l)}}function Ql(l){var t=l.flags;if(t&2){try{for(var e,a=l.return;a!==null;){if(rr(a)){e=a;break}a=a.return}if(e==null)throw Error(d(160));switch(e.tag){case 27:var n=e.stateNode,u=Xc(l);Eu(l,u,n);break;case 5:var c=e.stateNode;e.flags&32&&(We(c,""),e.flags&=-33);var s=Xc(l);Eu(l,s,c);break;case 3:case 4:var r=e.stateNode.containerInfo,x=Xc(l);Gc(l,x,r);break;default:throw Error(d(161))}}catch(p){tl(l,l.return,p)}l.flags&=-3}t&4096&&(l.flags&=-4097)}function pr(l){if(l.subtreeFlags&1024)for(l=l.child;l!==null;){var t=l;pr(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),l=l.sibling}}function Gt(l,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)hr(l,t.alternate,t),t=t.sibling}function Qe(l){for(l=l.child;l!==null;){var t=l;switch(t.tag){case 0:case 11:case 14:case 15:ce(4,t,t.return),Qe(t);break;case 1:Nt(t,t.return);var e=t.stateNode;typeof e.componentWillUnmount=="function"&&fr(t,t.return,e),Qe(t);break;case 27:vn(t.stateNode);case 26:case 5:Nt(t,t.return),Qe(t);break;case 22:t.memoizedState===null&&Qe(t);break;case 30:Qe(t);break;default:Qe(t)}l=l.sibling}}function Lt(l,t,e){for(e=e&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,n=l,u=t,c=u.flags;switch(u.tag){case 0:case 11:case 15:Lt(n,u,e),sn(4,u);break;case 1:if(Lt(n,u,e),a=u,n=a.stateNode,typeof n.componentDidMount=="function")try{n.componentDidMount()}catch(x){tl(a,a.return,x)}if(a=u,n=a.updateQueue,n!==null){var s=a.stateNode;try{var r=n.shared.hiddenCallbacks;if(r!==null)for(n.shared.hiddenCallbacks=null,n=0;n<r.length;n++)Ff(r[n],s)}catch(x){tl(a,a.return,x)}}e&&c&64&&sr(u),fn(u,u.return);break;case 27:or(u);case 26:case 5:Lt(n,u,e),e&&a===null&&c&4&&dr(u),fn(u,u.return);break;case 12:Lt(n,u,e);break;case 31:Lt(n,u,e),e&&c&4&&xr(n,u);break;case 13:Lt(n,u,e),e&&c&4&&vr(n,u);break;case 22:u.memoizedState===null&&Lt(n,u,e),fn(u,u.return);break;case 30:break;default:Lt(n,u,e)}t=t.sibling}}function Zc(l,t){var e=null;l!==null&&l.memoizedState!==null&&l.memoizedState.cachePool!==null&&(e=l.memoizedState.cachePool.pool),l=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(l=t.memoizedState.cachePool.pool),l!==e&&(l!=null&&l.refCount++,e!=null&&wa(e))}function Vc(l,t){l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wa(l))}function xt(l,t,e,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)jr(l,t,e,a),t=t.sibling}function jr(l,t,e,a){var n=t.flags;switch(t.tag){case 0:case 11:case 15:xt(l,t,e,a),n&2048&&sn(9,t);break;case 1:xt(l,t,e,a);break;case 3:xt(l,t,e,a),n&2048&&(l=null,t.alternate!==null&&(l=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==l&&(t.refCount++,l!=null&&wa(l)));break;case 12:if(n&2048){xt(l,t,e,a),l=t.stateNode;try{var u=t.memoizedProps,c=u.id,s=u.onPostCommit;typeof s=="function"&&s(c,t.alternate===null?"mount":"update",l.passiveEffectDuration,-0)}catch(r){tl(t,t.return,r)}}else xt(l,t,e,a);break;case 31:xt(l,t,e,a);break;case 13:xt(l,t,e,a);break;case 23:break;case 22:u=t.stateNode,c=t.alternate,t.memoizedState!==null?u._visibility&2?xt(l,t,e,a):dn(l,t):u._visibility&2?xt(l,t,e,a):(u._visibility|=2,ya(l,t,e,a,(t.subtreeFlags&10256)!==0||!1)),n&2048&&Zc(c,t);break;case 24:xt(l,t,e,a),n&2048&&Vc(t.alternate,t);break;default:xt(l,t,e,a)}}function ya(l,t,e,a,n){for(n=n&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var u=l,c=t,s=e,r=a,x=c.flags;switch(c.tag){case 0:case 11:case 15:ya(u,c,s,r,n),sn(8,c);break;case 23:break;case 22:var p=c.stateNode;c.memoizedState!==null?p._visibility&2?ya(u,c,s,r,n):dn(u,c):(p._visibility|=2,ya(u,c,s,r,n)),n&&x&2048&&Zc(c.alternate,c);break;case 24:ya(u,c,s,r,n),n&&x&2048&&Vc(c.alternate,c);break;default:ya(u,c,s,r,n)}t=t.sibling}}function dn(l,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var e=l,a=t,n=a.flags;switch(a.tag){case 22:dn(e,a),n&2048&&Zc(a.alternate,a);break;case 24:dn(e,a),n&2048&&Vc(a.alternate,a);break;default:dn(e,a)}t=t.sibling}}var rn=8192;function xa(l,t,e){if(l.subtreeFlags&rn)for(l=l.child;l!==null;)Sr(l,t,e),l=l.sibling}function Sr(l,t,e){switch(l.tag){case 26:xa(l,t,e),l.flags&rn&&l.memoizedState!==null&&nh(e,yt,l.memoizedState,l.memoizedProps);break;case 5:xa(l,t,e);break;case 3:case 4:var a=yt;yt=Lu(l.stateNode.containerInfo),xa(l,t,e),yt=a;break;case 22:l.memoizedState===null&&(a=l.alternate,a!==null&&a.memoizedState!==null?(a=rn,rn=16777216,xa(l,t,e),rn=a):xa(l,t,e));break;default:xa(l,t,e)}}function Nr(l){var t=l.alternate;if(t!==null&&(l=t.child,l!==null)){t.child=null;do t=l.sibling,l.sibling=null,l=t;while(l!==null)}}function on(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var e=0;e<t.length;e++){var a=t[e];Al=a,Ar(a,l)}Nr(l)}if(l.subtreeFlags&10256)for(l=l.child;l!==null;)zr(l),l=l.sibling}function zr(l){switch(l.tag){case 0:case 11:case 15:on(l),l.flags&2048&&ce(9,l,l.return);break;case 3:on(l);break;case 12:on(l);break;case 22:var t=l.stateNode;l.memoizedState!==null&&t._visibility&2&&(l.return===null||l.return.tag!==13)?(t._visibility&=-3,_u(l)):on(l);break;default:on(l)}}function _u(l){var t=l.deletions;if((l.flags&16)!==0){if(t!==null)for(var e=0;e<t.length;e++){var a=t[e];Al=a,Ar(a,l)}Nr(l)}for(l=l.child;l!==null;){switch(t=l,t.tag){case 0:case 11:case 15:ce(8,t,t.return),_u(t);break;case 22:e=t.stateNode,e._visibility&2&&(e._visibility&=-3,_u(t));break;default:_u(t)}l=l.sibling}}function Ar(l,t){for(;Al!==null;){var e=Al;switch(e.tag){case 0:case 11:case 15:ce(8,e,t);break;case 23:case 22:if(e.memoizedState!==null&&e.memoizedState.cachePool!==null){var a=e.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:wa(e.memoizedState.cache)}if(a=e.child,a!==null)a.return=e,Al=a;else l:for(e=l;Al!==null;){a=Al;var n=a.sibling,u=a.return;if(gr(a),a===e){Al=null;break l}if(n!==null){n.return=u,Al=n;break l}Al=u}}}var bm={getCacheForType:function(l){var t=_l(xl),e=t.data.get(l);return e===void 0&&(e=l(),t.data.set(l,e)),e},cacheSignal:function(){return _l(xl).controller.signal}},pm=typeof WeakMap=="function"?WeakMap:Map,I=0,ul=null,K=null,k=0,ll=0,Fl=null,se=!1,va=!1,Kc=!1,Zt=0,hl=0,fe=0,Xe=0,Jc=0,Il=0,ba=0,mn=null,Xl=null,kc=!1,Du=0,Tr=0,Ou=1/0,Uu=null,de=null,Sl=0,re=null,pa=null,Vt=0,wc=0,$c=null,Er=null,hn=0,Wc=null;function Pl(){return(I&2)!==0&&k!==0?k&-k:z.T!==null?es():Ls()}function Mr(){if(Il===0)if((k&536870912)===0||$){var l=Xn;Xn<<=1,(Xn&3932160)===0&&(Xn=262144),Il=l}else Il=536870912;return l=$l.current,l!==null&&(l.flags|=32),Il}function Gl(l,t,e){(l===ul&&(ll===2||ll===9)||l.cancelPendingCommit!==null)&&(ja(l,0),oe(l,k,Il,!1)),Ha(l,e),((I&2)===0||l!==ul)&&(l===ul&&((I&2)===0&&(Xe|=e),hl===4&&oe(l,k,Il,!1)),zt(l))}function _r(l,t,e){if((I&6)!==0)throw Error(d(327));var a=!e&&(t&127)===0&&(t&l.expiredLanes)===0||Ca(l,t),n=a?Nm(l,t):Ic(l,t,!0),u=a;do{if(n===0){va&&!a&&oe(l,t,0,!1);break}else{if(e=l.current.alternate,u&&!jm(e)){n=Ic(l,t,!1),u=!1;continue}if(n===2){if(u=t,l.errorRecoveryDisabledLanes&u)var c=0;else c=l.pendingLanes&-536870913,c=c!==0?c:c&536870912?536870912:0;if(c!==0){t=c;l:{var s=l;n=mn;var r=s.current.memoizedState.isDehydrated;if(r&&(ja(s,c).flags|=256),c=Ic(s,c,!1),c!==2){if(Kc&&!r){s.errorRecoveryDisabledLanes|=u,Xe|=u,n=4;break l}u=Xl,Xl=n,u!==null&&(Xl===null?Xl=u:Xl.push.apply(Xl,u))}n=c}if(u=!1,n!==2)continue}}if(n===1){ja(l,0),oe(l,t,0,!0);break}l:{switch(a=l,u=n,u){case 0:case 1:throw Error(d(345));case 4:if((t&4194048)!==t)break;case 6:oe(a,t,Il,!se);break l;case 2:Xl=null;break;case 3:case 5:break;default:throw Error(d(329))}if((t&62914560)===t&&(n=Du+300-Vl(),10<n)){if(oe(a,t,Il,!se),Ln(a,0,!0)!==0)break l;Vt=t,a.timeoutHandle=i0(Dr.bind(null,a,e,Xl,Uu,kc,t,Il,Xe,ba,se,u,"Throttled",-0,0),n);break l}Dr(a,e,Xl,Uu,kc,t,Il,Xe,ba,se,u,null,-0,0)}}break}while(!0);zt(l)}function Dr(l,t,e,a,n,u,c,s,r,x,p,A,v,b){if(l.timeoutHandle=-1,A=t.subtreeFlags,A&8192||(A&16785408)===16785408){A={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:_t},Sr(t,u,A);var O=(u&62914560)===u?Du-Vl():(u&4194048)===u?Tr-Vl():0;if(O=uh(A,O),O!==null){Vt=u,l.cancelPendingCommit=O(Yr.bind(null,l,t,u,e,a,n,c,s,r,p,A,null,v,b)),oe(l,u,c,!x);return}}Yr(l,t,u,e,a,n,c,s,r)}function jm(l){for(var t=l;;){var e=t.tag;if((e===0||e===11||e===15)&&t.flags&16384&&(e=t.updateQueue,e!==null&&(e=e.stores,e!==null)))for(var a=0;a<e.length;a++){var n=e[a],u=n.getSnapshot;n=n.value;try{if(!kl(u(),n))return!1}catch{return!1}}if(e=t.child,t.subtreeFlags&16384&&e!==null)e.return=t,t=e;else{if(t===l)break;for(;t.sibling===null;){if(t.return===null||t.return===l)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function oe(l,t,e,a){t&=~Jc,t&=~Xe,l.suspendedLanes|=t,l.pingedLanes&=~t,a&&(l.warmLanes|=t),a=l.expirationTimes;for(var n=t;0<n;){var u=31-Jl(n),c=1<<u;a[u]=-1,n&=~c}e!==0&&Qs(l,e,t)}function Cu(){return(I&6)===0?(gn(0),!1):!0}function Fc(){if(K!==null){if(ll===0)var l=K.return;else l=K,Ct=Oe=null,mc(l),ra=null,Wa=0,l=K;for(;l!==null;)cr(l.alternate,l),l=l.return;K=null}}function ja(l,t){var e=l.timeoutHandle;e!==-1&&(l.timeoutHandle=-1,Gm(e)),e=l.cancelPendingCommit,e!==null&&(l.cancelPendingCommit=null,e()),Vt=0,Fc(),ul=l,K=e=Ot(l.current,null),k=t,ll=0,Fl=null,se=!1,va=Ca(l,t),Kc=!1,ba=Il=Jc=Xe=fe=hl=0,Xl=mn=null,kc=!1,(t&8)!==0&&(t|=t&32);var a=l.entangledLanes;if(a!==0)for(l=l.entanglements,a&=t;0<a;){var n=31-Jl(a),u=1<<n;t|=l[n],a&=~u}return Zt=t,lu(),e}function Or(l,t){Q=null,z.H=nn,t===da||t===su?(t=kf(),ll=3):t===tc?(t=kf(),ll=4):ll=t===_c?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,Fl=t,K===null&&(hl=1,Su(l,it(t,l.current)))}function Ur(){var l=$l.current;return l===null?!0:(k&4194048)===k?dt===null:(k&62914560)===k||(k&536870912)!==0?l===dt:!1}function Cr(){var l=z.H;return z.H=nn,l===null?nn:l}function Hr(){var l=z.A;return z.A=bm,l}function Hu(){hl=4,se||(k&4194048)!==k&&$l.current!==null||(va=!0),(fe&134217727)===0&&(Xe&134217727)===0||ul===null||oe(ul,k,Il,!1)}function Ic(l,t,e){var a=I;I|=2;var n=Cr(),u=Hr();(ul!==l||k!==t)&&(Uu=null,ja(l,t)),t=!1;var c=hl;l:do try{if(ll!==0&&K!==null){var s=K,r=Fl;switch(ll){case 8:Fc(),c=6;break l;case 3:case 2:case 9:case 6:$l.current===null&&(t=!0);var x=ll;if(ll=0,Fl=null,Sa(l,s,r,x),e&&va){c=0;break l}break;default:x=ll,ll=0,Fl=null,Sa(l,s,r,x)}}Sm(),c=hl;break}catch(p){Or(l,p)}while(!0);return t&&l.shellSuspendCounter++,Ct=Oe=null,I=a,z.H=n,z.A=u,K===null&&(ul=null,k=0,lu()),c}function Sm(){for(;K!==null;)Br(K)}function Nm(l,t){var e=I;I|=2;var a=Cr(),n=Hr();ul!==l||k!==t?(Uu=null,Ou=Vl()+500,ja(l,t)):va=Ca(l,t);l:do try{if(ll!==0&&K!==null){t=K;var u=Fl;t:switch(ll){case 1:ll=0,Fl=null,Sa(l,t,u,1);break;case 2:case 9:if(Kf(u)){ll=0,Fl=null,Rr(t);break}t=function(){ll!==2&&ll!==9||ul!==l||(ll=7),zt(l)},u.then(t,t);break l;case 3:ll=7;break l;case 4:ll=5;break l;case 7:Kf(u)?(ll=0,Fl=null,Rr(t)):(ll=0,Fl=null,Sa(l,t,u,7));break;case 5:var c=null;switch(K.tag){case 26:c=K.memoizedState;case 5:case 27:var s=K;if(c?j0(c):s.stateNode.complete){ll=0,Fl=null;var r=s.sibling;if(r!==null)K=r;else{var x=s.return;x!==null?(K=x,Bu(x)):K=null}break t}}ll=0,Fl=null,Sa(l,t,u,5);break;case 6:ll=0,Fl=null,Sa(l,t,u,6);break;case 8:Fc(),hl=6;break l;default:throw Error(d(462))}}zm();break}catch(p){Or(l,p)}while(!0);return Ct=Oe=null,z.H=a,z.A=n,I=e,K!==null?0:(ul=null,k=0,lu(),hl)}function zm(){for(;K!==null&&!J0();)Br(K)}function Br(l){var t=ur(l.alternate,l,Zt);l.memoizedProps=l.pendingProps,t===null?Bu(l):K=t}function Rr(l){var t=l,e=t.alternate;switch(t.tag){case 15:case 0:t=Pd(e,t,t.pendingProps,t.type,void 0,k);break;case 11:t=Pd(e,t,t.pendingProps,t.type.render,t.ref,k);break;case 5:mc(t);default:cr(e,t),t=K=Hf(t,Zt),t=ur(e,t,Zt)}l.memoizedProps=l.pendingProps,t===null?Bu(l):K=t}function Sa(l,t,e,a){Ct=Oe=null,mc(t),ra=null,Wa=0;var n=t.return;try{if(om(l,n,t,e,k)){hl=1,Su(l,it(e,l.current)),K=null;return}}catch(u){if(n!==null)throw K=n,u;hl=1,Su(l,it(e,l.current)),K=null;return}t.flags&32768?($||a===1?l=!0:va||(k&536870912)!==0?l=!1:(se=l=!0,(a===2||a===9||a===3||a===6)&&(a=$l.current,a!==null&&a.tag===13&&(a.flags|=16384))),qr(t,l)):Bu(t)}function Bu(l){var t=l;do{if((t.flags&32768)!==0){qr(t,se);return}l=t.return;var e=gm(t.alternate,t,Zt);if(e!==null){K=e;return}if(t=t.sibling,t!==null){K=t;return}K=t=l}while(t!==null);hl===0&&(hl=5)}function qr(l,t){do{var e=ym(l.alternate,l);if(e!==null){e.flags&=32767,K=e;return}if(e=l.return,e!==null&&(e.flags|=32768,e.subtreeFlags=0,e.deletions=null),!t&&(l=l.sibling,l!==null)){K=l;return}K=l=e}while(l!==null);hl=6,K=null}function Yr(l,t,e,a,n,u,c,s,r){l.cancelPendingCommit=null;do Ru();while(Sl!==0);if((I&6)!==0)throw Error(d(327));if(t!==null){if(t===l.current)throw Error(d(177));if(u=t.lanes|t.childLanes,u|=Xi,eo(l,e,u,c,s,r),l===ul&&(K=ul=null,k=0),pa=t,re=l,Vt=e,wc=u,$c=n,Er=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(l.callbackNode=null,l.callbackPriority=0,Mm(Yn,function(){return Zr(),null})):(l.callbackNode=null,l.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=z.T,z.T=null,n=_.p,_.p=2,c=I,I|=4;try{xm(l,t,e)}finally{I=c,_.p=n,z.T=a}}Sl=1,Qr(),Xr(),Gr()}}function Qr(){if(Sl===1){Sl=0;var l=re,t=pa,e=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||e){e=z.T,z.T=null;var a=_.p;_.p=2;var n=I;I|=4;try{br(t,l);var u=ds,c=Af(l.containerInfo),s=u.focusedElem,r=u.selectionRange;if(c!==s&&s&&s.ownerDocument&&zf(s.ownerDocument.documentElement,s)){if(r!==null&&Bi(s)){var x=r.start,p=r.end;if(p===void 0&&(p=x),"selectionStart"in s)s.selectionStart=x,s.selectionEnd=Math.min(p,s.value.length);else{var A=s.ownerDocument||document,v=A&&A.defaultView||window;if(v.getSelection){var b=v.getSelection(),O=s.textContent.length,B=Math.min(r.start,O),nl=r.end===void 0?B:Math.min(r.end,O);!b.extend&&B>nl&&(c=nl,nl=B,B=c);var h=Nf(s,B),o=Nf(s,nl);if(h&&o&&(b.rangeCount!==1||b.anchorNode!==h.node||b.anchorOffset!==h.offset||b.focusNode!==o.node||b.focusOffset!==o.offset)){var y=A.createRange();y.setStart(h.node,h.offset),b.removeAllRanges(),B>nl?(b.addRange(y),b.extend(o.node,o.offset)):(y.setEnd(o.node,o.offset),b.addRange(y))}}}}for(A=[],b=s;b=b.parentNode;)b.nodeType===1&&A.push({element:b,left:b.scrollLeft,top:b.scrollTop});for(typeof s.focus=="function"&&s.focus(),s=0;s<A.length;s++){var S=A[s];S.element.scrollLeft=S.left,S.element.scrollTop=S.top}}wu=!!fs,ds=fs=null}finally{I=n,_.p=a,z.T=e}}l.current=t,Sl=2}}function Xr(){if(Sl===2){Sl=0;var l=re,t=pa,e=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||e){e=z.T,z.T=null;var a=_.p;_.p=2;var n=I;I|=4;try{hr(l,t.alternate,t)}finally{I=n,_.p=a,z.T=e}}Sl=3}}function Gr(){if(Sl===4||Sl===3){Sl=0,k0();var l=re,t=pa,e=Vt,a=Er;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Sl=5:(Sl=0,pa=re=null,Lr(l,l.pendingLanes));var n=l.pendingLanes;if(n===0&&(de=null),yi(e),t=t.stateNode,Kl&&typeof Kl.onCommitFiberRoot=="function")try{Kl.onCommitFiberRoot(Ua,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=z.T,n=_.p,_.p=2,z.T=null;try{for(var u=l.onRecoverableError,c=0;c<a.length;c++){var s=a[c];u(s.value,{componentStack:s.stack})}}finally{z.T=t,_.p=n}}(Vt&3)!==0&&Ru(),zt(l),n=l.pendingLanes,(e&261930)!==0&&(n&42)!==0?l===Wc?hn++:(hn=0,Wc=l):hn=0,gn(0)}}function Lr(l,t){(l.pooledCacheLanes&=t)===0&&(t=l.pooledCache,t!=null&&(l.pooledCache=null,wa(t)))}function Ru(){return Qr(),Xr(),Gr(),Zr()}function Zr(){if(Sl!==5)return!1;var l=re,t=wc;wc=0;var e=yi(Vt),a=z.T,n=_.p;try{_.p=32>e?32:e,z.T=null,e=$c,$c=null;var u=re,c=Vt;if(Sl=0,pa=re=null,Vt=0,(I&6)!==0)throw Error(d(331));var s=I;if(I|=4,zr(u.current),jr(u,u.current,c,e),I=s,gn(0,!1),Kl&&typeof Kl.onPostCommitFiberRoot=="function")try{Kl.onPostCommitFiberRoot(Ua,u)}catch{}return!0}finally{_.p=n,z.T=a,Lr(l,t)}}function Vr(l,t,e){t=it(e,t),t=Mc(l.stateNode,t,2),l=ne(l,t,2),l!==null&&(Ha(l,2),zt(l))}function tl(l,t,e){if(l.tag===3)Vr(l,l,e);else for(;t!==null;){if(t.tag===3){Vr(t,l,e);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(de===null||!de.has(a))){l=it(e,l),e=Kd(2),a=ne(t,e,2),a!==null&&(Jd(e,a,t,l),Ha(a,2),zt(a));break}}t=t.return}}function Pc(l,t,e){var a=l.pingCache;if(a===null){a=l.pingCache=new pm;var n=new Set;a.set(t,n)}else n=a.get(t),n===void 0&&(n=new Set,a.set(t,n));n.has(e)||(Kc=!0,n.add(e),l=Am.bind(null,l,t,e),t.then(l,l))}function Am(l,t,e){var a=l.pingCache;a!==null&&a.delete(t),l.pingedLanes|=l.suspendedLanes&e,l.warmLanes&=~e,ul===l&&(k&e)===e&&(hl===4||hl===3&&(k&62914560)===k&&300>Vl()-Du?(I&2)===0&&ja(l,0):Jc|=e,ba===k&&(ba=0)),zt(l)}function Kr(l,t){t===0&&(t=Ys()),l=Me(l,t),l!==null&&(Ha(l,t),zt(l))}function Tm(l){var t=l.memoizedState,e=0;t!==null&&(e=t.retryLane),Kr(l,e)}function Em(l,t){var e=0;switch(l.tag){case 31:case 13:var a=l.stateNode,n=l.memoizedState;n!==null&&(e=n.retryLane);break;case 19:a=l.stateNode;break;case 22:a=l.stateNode._retryCache;break;default:throw Error(d(314))}a!==null&&a.delete(t),Kr(l,e)}function Mm(l,t){return oi(l,t)}var qu=null,Na=null,ls=!1,Yu=!1,ts=!1,me=0;function zt(l){l!==Na&&l.next===null&&(Na===null?qu=Na=l:Na=Na.next=l),Yu=!0,ls||(ls=!0,Dm())}function gn(l,t){if(!ts&&Yu){ts=!0;do for(var e=!1,a=qu;a!==null;){if(l!==0){var n=a.pendingLanes;if(n===0)var u=0;else{var c=a.suspendedLanes,s=a.pingedLanes;u=(1<<31-Jl(42|l)+1)-1,u&=n&~(c&~s),u=u&201326741?u&201326741|1:u?u|2:0}u!==0&&(e=!0,$r(a,u))}else u=k,u=Ln(a,a===ul?u:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(u&3)===0||Ca(a,u)||(e=!0,$r(a,u));a=a.next}while(e);ts=!1}}function _m(){Jr()}function Jr(){Yu=ls=!1;var l=0;me!==0&&Xm()&&(l=me);for(var t=Vl(),e=null,a=qu;a!==null;){var n=a.next,u=kr(a,t);u===0?(a.next=null,e===null?qu=n:e.next=n,n===null&&(Na=e)):(e=a,(l!==0||(u&3)!==0)&&(Yu=!0)),a=n}Sl!==0&&Sl!==5||gn(l),me!==0&&(me=0)}function kr(l,t){for(var e=l.suspendedLanes,a=l.pingedLanes,n=l.expirationTimes,u=l.pendingLanes&-62914561;0<u;){var c=31-Jl(u),s=1<<c,r=n[c];r===-1?((s&e)===0||(s&a)!==0)&&(n[c]=to(s,t)):r<=t&&(l.expiredLanes|=s),u&=~s}if(t=ul,e=k,e=Ln(l,l===t?e:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a=l.callbackNode,e===0||l===t&&(ll===2||ll===9)||l.cancelPendingCommit!==null)return a!==null&&a!==null&&mi(a),l.callbackNode=null,l.callbackPriority=0;if((e&3)===0||Ca(l,e)){if(t=e&-e,t===l.callbackPriority)return t;switch(a!==null&&mi(a),yi(e)){case 2:case 8:e=Rs;break;case 32:e=Yn;break;case 268435456:e=qs;break;default:e=Yn}return a=wr.bind(null,l),e=oi(e,a),l.callbackPriority=t,l.callbackNode=e,t}return a!==null&&a!==null&&mi(a),l.callbackPriority=2,l.callbackNode=null,2}function wr(l,t){if(Sl!==0&&Sl!==5)return l.callbackNode=null,l.callbackPriority=0,null;var e=l.callbackNode;if(Ru()&&l.callbackNode!==e)return null;var a=k;return a=Ln(l,l===ul?a:0,l.cancelPendingCommit!==null||l.timeoutHandle!==-1),a===0?null:(_r(l,a,t),kr(l,Vl()),l.callbackNode!=null&&l.callbackNode===e?wr.bind(null,l):null)}function $r(l,t){if(Ru())return null;_r(l,t,!0)}function Dm(){Lm(function(){(I&6)!==0?oi(Bs,_m):Jr()})}function es(){if(me===0){var l=sa;l===0&&(l=Qn,Qn<<=1,(Qn&261888)===0&&(Qn=256)),me=l}return me}function Wr(l){return l==null||typeof l=="symbol"||typeof l=="boolean"?null:typeof l=="function"?l:Jn(""+l)}function Fr(l,t){var e=t.ownerDocument.createElement("input");return e.name=t.name,e.value=t.value,l.id&&e.setAttribute("form",l.id),t.parentNode.insertBefore(e,t),l=new FormData(l),e.parentNode.removeChild(e),l}function Om(l,t,e,a,n){if(t==="submit"&&e&&e.stateNode===n){var u=Wr((n[Bl]||null).action),c=a.submitter;c&&(t=(t=c[Bl]||null)?Wr(t.formAction):c.getAttribute("formAction"),t!==null&&(u=t,c=null));var s=new Wn("action","action",null,a,n);l.push({event:s,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(me!==0){var r=c?Fr(n,c):new FormData(n);Sc(e,{pending:!0,data:r,method:n.method,action:u},null,r)}}else typeof u=="function"&&(s.preventDefault(),r=c?Fr(n,c):new FormData(n),Sc(e,{pending:!0,data:r,method:n.method,action:u},u,r))},currentTarget:n}]})}}for(var as=0;as<Qi.length;as++){var ns=Qi[as],Um=ns.toLowerCase(),Cm=ns[0].toUpperCase()+ns.slice(1);gt(Um,"on"+Cm)}gt(Mf,"onAnimationEnd"),gt(_f,"onAnimationIteration"),gt(Df,"onAnimationStart"),gt("dblclick","onDoubleClick"),gt("focusin","onFocus"),gt("focusout","onBlur"),gt($o,"onTransitionRun"),gt(Wo,"onTransitionStart"),gt(Fo,"onTransitionCancel"),gt(Of,"onTransitionEnd"),we("onMouseEnter",["mouseout","mouseover"]),we("onMouseLeave",["mouseout","mouseover"]),we("onPointerEnter",["pointerout","pointerover"]),we("onPointerLeave",["pointerout","pointerover"]),ze("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),ze("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),ze("onBeforeInput",["compositionend","keypress","textInput","paste"]),ze("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),ze("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),ze("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var yn="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Hm=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(yn));function Ir(l,t){t=(t&4)!==0;for(var e=0;e<l.length;e++){var a=l[e],n=a.event;a=a.listeners;l:{var u=void 0;if(t)for(var c=a.length-1;0<=c;c--){var s=a[c],r=s.instance,x=s.currentTarget;if(s=s.listener,r!==u&&n.isPropagationStopped())break l;u=s,n.currentTarget=x;try{u(n)}catch(p){Pn(p)}n.currentTarget=null,u=r}else for(c=0;c<a.length;c++){if(s=a[c],r=s.instance,x=s.currentTarget,s=s.listener,r!==u&&n.isPropagationStopped())break l;u=s,n.currentTarget=x;try{u(n)}catch(p){Pn(p)}n.currentTarget=null,u=r}}}}function J(l,t){var e=t[xi];e===void 0&&(e=t[xi]=new Set);var a=l+"__bubble";e.has(a)||(Pr(t,l,2,!1),e.add(a))}function us(l,t,e){var a=0;t&&(a|=4),Pr(e,l,a,t)}var Qu="_reactListening"+Math.random().toString(36).slice(2);function is(l){if(!l[Qu]){l[Qu]=!0,Ks.forEach(function(e){e!=="selectionchange"&&(Hm.has(e)||us(e,!1,l),us(e,!0,l))});var t=l.nodeType===9?l:l.ownerDocument;t===null||t[Qu]||(t[Qu]=!0,us("selectionchange",!1,t))}}function Pr(l,t,e,a){switch(M0(t)){case 2:var n=sh;break;case 8:n=fh;break;default:n=js}e=n.bind(null,t,e,l),n=void 0,!Ti||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(n=!0),a?n!==void 0?l.addEventListener(t,e,{capture:!0,passive:n}):l.addEventListener(t,e,!0):n!==void 0?l.addEventListener(t,e,{passive:n}):l.addEventListener(t,e,!1)}function cs(l,t,e,a,n){var u=a;if((t&1)===0&&(t&2)===0&&a!==null)l:for(;;){if(a===null)return;var c=a.tag;if(c===3||c===4){var s=a.stateNode.containerInfo;if(s===n)break;if(c===4)for(c=a.return;c!==null;){var r=c.tag;if((r===3||r===4)&&c.stateNode.containerInfo===n)return;c=c.return}for(;s!==null;){if(c=Ke(s),c===null)return;if(r=c.tag,r===5||r===6||r===26||r===27){a=u=c;continue l}s=s.parentNode}}a=a.return}af(function(){var x=u,p=zi(e),A=[];l:{var v=Uf.get(l);if(v!==void 0){var b=Wn,O=l;switch(l){case"keypress":if(wn(e)===0)break l;case"keydown":case"keyup":b=Eo;break;case"focusin":O="focus",b=Di;break;case"focusout":O="blur",b=Di;break;case"beforeblur":case"afterblur":b=Di;break;case"click":if(e.button===2)break l;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":b=cf;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":b=go;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":b=Do;break;case Mf:case _f:case Df:b=vo;break;case Of:b=Uo;break;case"scroll":case"scrollend":b=mo;break;case"wheel":b=Ho;break;case"copy":case"cut":case"paste":b=po;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":b=ff;break;case"toggle":case"beforetoggle":b=Ro}var B=(t&4)!==0,nl=!B&&(l==="scroll"||l==="scrollend"),h=B?v!==null?v+"Capture":null:v;B=[];for(var o=x,y;o!==null;){var S=o;if(y=S.stateNode,S=S.tag,S!==5&&S!==26&&S!==27||y===null||h===null||(S=qa(o,h),S!=null&&B.push(xn(o,S,y))),nl)break;o=o.return}0<B.length&&(v=new b(v,O,null,e,p),A.push({event:v,listeners:B}))}}if((t&7)===0){l:{if(v=l==="mouseover"||l==="pointerover",b=l==="mouseout"||l==="pointerout",v&&e!==Ni&&(O=e.relatedTarget||e.fromElement)&&(Ke(O)||O[Ve]))break l;if((b||v)&&(v=p.window===p?p:(v=p.ownerDocument)?v.defaultView||v.parentWindow:window,b?(O=e.relatedTarget||e.toElement,b=x,O=O?Ke(O):null,O!==null&&(nl=T(O),B=O.tag,O!==nl||B!==5&&B!==27&&B!==6)&&(O=null)):(b=null,O=x),b!==O)){if(B=cf,S="onMouseLeave",h="onMouseEnter",o="mouse",(l==="pointerout"||l==="pointerover")&&(B=ff,S="onPointerLeave",h="onPointerEnter",o="pointer"),nl=b==null?v:Ra(b),y=O==null?v:Ra(O),v=new B(S,o+"leave",b,e,p),v.target=nl,v.relatedTarget=y,S=null,Ke(p)===x&&(B=new B(h,o+"enter",O,e,p),B.target=y,B.relatedTarget=nl,S=B),nl=S,b&&O)t:{for(B=Bm,h=b,o=O,y=0,S=h;S;S=B(S))y++;S=0;for(var H=o;H;H=B(H))S++;for(;0<y-S;)h=B(h),y--;for(;0<S-y;)o=B(o),S--;for(;y--;){if(h===o||o!==null&&h===o.alternate){B=h;break t}h=B(h),o=B(o)}B=null}else B=null;b!==null&&l0(A,v,b,B,!1),O!==null&&nl!==null&&l0(A,nl,O,B,!0)}}l:{if(v=x?Ra(x):window,b=v.nodeName&&v.nodeName.toLowerCase(),b==="select"||b==="input"&&v.type==="file")var W=xf;else if(gf(v))if(vf)W=Jo;else{W=Vo;var U=Zo}else b=v.nodeName,!b||b.toLowerCase()!=="input"||v.type!=="checkbox"&&v.type!=="radio"?x&&Si(x.elementType)&&(W=xf):W=Ko;if(W&&(W=W(l,x))){yf(A,W,e,p);break l}U&&U(l,v,x),l==="focusout"&&x&&v.type==="number"&&x.memoizedProps.value!=null&&ji(v,"number",v.value)}switch(U=x?Ra(x):window,l){case"focusin":(gf(U)||U.contentEditable==="true")&&(la=U,Ri=x,Ka=null);break;case"focusout":Ka=Ri=la=null;break;case"mousedown":qi=!0;break;case"contextmenu":case"mouseup":case"dragend":qi=!1,Tf(A,e,p);break;case"selectionchange":if(wo)break;case"keydown":case"keyup":Tf(A,e,p)}var X;if(Ui)l:{switch(l){case"compositionstart":var w="onCompositionStart";break l;case"compositionend":w="onCompositionEnd";break l;case"compositionupdate":w="onCompositionUpdate";break l}w=void 0}else Pe?mf(l,e)&&(w="onCompositionEnd"):l==="keydown"&&e.keyCode===229&&(w="onCompositionStart");w&&(df&&e.locale!=="ko"&&(Pe||w!=="onCompositionStart"?w==="onCompositionEnd"&&Pe&&(X=nf()):(Ft=p,Ei="value"in Ft?Ft.value:Ft.textContent,Pe=!0)),U=Xu(x,w),0<U.length&&(w=new sf(w,l,null,e,p),A.push({event:w,listeners:U}),X?w.data=X:(X=hf(e),X!==null&&(w.data=X)))),(X=Yo?Qo(l,e):Xo(l,e))&&(w=Xu(x,"onBeforeInput"),0<w.length&&(U=new sf("onBeforeInput","beforeinput",null,e,p),A.push({event:U,listeners:w}),U.data=X)),Om(A,l,x,e,p)}Ir(A,t)})}function xn(l,t,e){return{instance:l,listener:t,currentTarget:e}}function Xu(l,t){for(var e=t+"Capture",a=[];l!==null;){var n=l,u=n.stateNode;if(n=n.tag,n!==5&&n!==26&&n!==27||u===null||(n=qa(l,e),n!=null&&a.unshift(xn(l,n,u)),n=qa(l,t),n!=null&&a.push(xn(l,n,u))),l.tag===3)return a;l=l.return}return[]}function Bm(l){if(l===null)return null;do l=l.return;while(l&&l.tag!==5&&l.tag!==27);return l||null}function l0(l,t,e,a,n){for(var u=t._reactName,c=[];e!==null&&e!==a;){var s=e,r=s.alternate,x=s.stateNode;if(s=s.tag,r!==null&&r===a)break;s!==5&&s!==26&&s!==27||x===null||(r=x,n?(x=qa(e,u),x!=null&&c.unshift(xn(e,x,r))):n||(x=qa(e,u),x!=null&&c.push(xn(e,x,r)))),e=e.return}c.length!==0&&l.push({event:t,listeners:c})}var Rm=/\r\n?/g,qm=/\u0000|\uFFFD/g;function t0(l){return(typeof l=="string"?l:""+l).replace(Rm,`
`).replace(qm,"")}function e0(l,t){return t=t0(t),t0(l)===t}function al(l,t,e,a,n,u){switch(e){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||We(l,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&We(l,""+a);break;case"className":Vn(l,"class",a);break;case"tabIndex":Vn(l,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":Vn(l,e,a);break;case"style":tf(l,a,u);break;case"data":if(t!=="object"){Vn(l,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||e!=="href")){l.removeAttribute(e);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(e);break}a=Jn(""+a),l.setAttribute(e,a);break;case"action":case"formAction":if(typeof a=="function"){l.setAttribute(e,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof u=="function"&&(e==="formAction"?(t!=="input"&&al(l,t,"name",n.name,n,null),al(l,t,"formEncType",n.formEncType,n,null),al(l,t,"formMethod",n.formMethod,n,null),al(l,t,"formTarget",n.formTarget,n,null)):(al(l,t,"encType",n.encType,n,null),al(l,t,"method",n.method,n,null),al(l,t,"target",n.target,n,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){l.removeAttribute(e);break}a=Jn(""+a),l.setAttribute(e,a);break;case"onClick":a!=null&&(l.onclick=_t);break;case"onScroll":a!=null&&J("scroll",l);break;case"onScrollEnd":a!=null&&J("scrollend",l);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(d(61));if(e=a.__html,e!=null){if(n.children!=null)throw Error(d(60));l.innerHTML=e}}break;case"multiple":l.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":l.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){l.removeAttribute("xlink:href");break}e=Jn(""+a),l.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",e);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(e,""+a):l.removeAttribute(e);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(e,""):l.removeAttribute(e);break;case"capture":case"download":a===!0?l.setAttribute(e,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?l.setAttribute(e,a):l.removeAttribute(e);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?l.setAttribute(e,a):l.removeAttribute(e);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?l.removeAttribute(e):l.setAttribute(e,a);break;case"popover":J("beforetoggle",l),J("toggle",l),Zn(l,"popover",a);break;case"xlinkActuate":Mt(l,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Mt(l,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Mt(l,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Mt(l,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Mt(l,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Mt(l,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Mt(l,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Mt(l,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Mt(l,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":Zn(l,"is",a);break;case"innerText":case"textContent":break;default:(!(2<e.length)||e[0]!=="o"&&e[0]!=="O"||e[1]!=="n"&&e[1]!=="N")&&(e=ro.get(e)||e,Zn(l,e,a))}}function ss(l,t,e,a,n,u){switch(e){case"style":tf(l,a,u);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(d(61));if(e=a.__html,e!=null){if(n.children!=null)throw Error(d(60));l.innerHTML=e}}break;case"children":typeof a=="string"?We(l,a):(typeof a=="number"||typeof a=="bigint")&&We(l,""+a);break;case"onScroll":a!=null&&J("scroll",l);break;case"onScrollEnd":a!=null&&J("scrollend",l);break;case"onClick":a!=null&&(l.onclick=_t);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Js.hasOwnProperty(e))l:{if(e[0]==="o"&&e[1]==="n"&&(n=e.endsWith("Capture"),t=e.slice(2,n?e.length-7:void 0),u=l[Bl]||null,u=u!=null?u[e]:null,typeof u=="function"&&l.removeEventListener(t,u,n),typeof a=="function")){typeof u!="function"&&u!==null&&(e in l?l[e]=null:l.hasAttribute(e)&&l.removeAttribute(e)),l.addEventListener(t,a,n);break l}e in l?l[e]=a:a===!0?l.setAttribute(e,""):Zn(l,e,a)}}}function Ol(l,t,e){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":J("error",l),J("load",l);var a=!1,n=!1,u;for(u in e)if(e.hasOwnProperty(u)){var c=e[u];if(c!=null)switch(u){case"src":a=!0;break;case"srcSet":n=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(d(137,t));default:al(l,t,u,c,e,null)}}n&&al(l,t,"srcSet",e.srcSet,e,null),a&&al(l,t,"src",e.src,e,null);return;case"input":J("invalid",l);var s=u=c=n=null,r=null,x=null;for(a in e)if(e.hasOwnProperty(a)){var p=e[a];if(p!=null)switch(a){case"name":n=p;break;case"type":c=p;break;case"checked":r=p;break;case"defaultChecked":x=p;break;case"value":u=p;break;case"defaultValue":s=p;break;case"children":case"dangerouslySetInnerHTML":if(p!=null)throw Error(d(137,t));break;default:al(l,t,a,p,e,null)}}Fs(l,u,s,r,x,c,n,!1);return;case"select":J("invalid",l),a=c=u=null;for(n in e)if(e.hasOwnProperty(n)&&(s=e[n],s!=null))switch(n){case"value":u=s;break;case"defaultValue":c=s;break;case"multiple":a=s;default:al(l,t,n,s,e,null)}t=u,e=c,l.multiple=!!a,t!=null?$e(l,!!a,t,!1):e!=null&&$e(l,!!a,e,!0);return;case"textarea":J("invalid",l),u=n=a=null;for(c in e)if(e.hasOwnProperty(c)&&(s=e[c],s!=null))switch(c){case"value":a=s;break;case"defaultValue":n=s;break;case"children":u=s;break;case"dangerouslySetInnerHTML":if(s!=null)throw Error(d(91));break;default:al(l,t,c,s,e,null)}Ps(l,a,n,u);return;case"option":for(r in e)if(e.hasOwnProperty(r)&&(a=e[r],a!=null))switch(r){case"selected":l.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:al(l,t,r,a,e,null)}return;case"dialog":J("beforetoggle",l),J("toggle",l),J("cancel",l),J("close",l);break;case"iframe":case"object":J("load",l);break;case"video":case"audio":for(a=0;a<yn.length;a++)J(yn[a],l);break;case"image":J("error",l),J("load",l);break;case"details":J("toggle",l);break;case"embed":case"source":case"link":J("error",l),J("load",l);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(x in e)if(e.hasOwnProperty(x)&&(a=e[x],a!=null))switch(x){case"children":case"dangerouslySetInnerHTML":throw Error(d(137,t));default:al(l,t,x,a,e,null)}return;default:if(Si(t)){for(p in e)e.hasOwnProperty(p)&&(a=e[p],a!==void 0&&ss(l,t,p,a,e,void 0));return}}for(s in e)e.hasOwnProperty(s)&&(a=e[s],a!=null&&al(l,t,s,a,e,null))}function Ym(l,t,e,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var n=null,u=null,c=null,s=null,r=null,x=null,p=null;for(b in e){var A=e[b];if(e.hasOwnProperty(b)&&A!=null)switch(b){case"checked":break;case"value":break;case"defaultValue":r=A;default:a.hasOwnProperty(b)||al(l,t,b,null,a,A)}}for(var v in a){var b=a[v];if(A=e[v],a.hasOwnProperty(v)&&(b!=null||A!=null))switch(v){case"type":u=b;break;case"name":n=b;break;case"checked":x=b;break;case"defaultChecked":p=b;break;case"value":c=b;break;case"defaultValue":s=b;break;case"children":case"dangerouslySetInnerHTML":if(b!=null)throw Error(d(137,t));break;default:b!==A&&al(l,t,v,b,a,A)}}pi(l,c,s,r,x,p,u,n);return;case"select":b=c=s=v=null;for(u in e)if(r=e[u],e.hasOwnProperty(u)&&r!=null)switch(u){case"value":break;case"multiple":b=r;default:a.hasOwnProperty(u)||al(l,t,u,null,a,r)}for(n in a)if(u=a[n],r=e[n],a.hasOwnProperty(n)&&(u!=null||r!=null))switch(n){case"value":v=u;break;case"defaultValue":s=u;break;case"multiple":c=u;default:u!==r&&al(l,t,n,u,a,r)}t=s,e=c,a=b,v!=null?$e(l,!!e,v,!1):!!a!=!!e&&(t!=null?$e(l,!!e,t,!0):$e(l,!!e,e?[]:"",!1));return;case"textarea":b=v=null;for(s in e)if(n=e[s],e.hasOwnProperty(s)&&n!=null&&!a.hasOwnProperty(s))switch(s){case"value":break;case"children":break;default:al(l,t,s,null,a,n)}for(c in a)if(n=a[c],u=e[c],a.hasOwnProperty(c)&&(n!=null||u!=null))switch(c){case"value":v=n;break;case"defaultValue":b=n;break;case"children":break;case"dangerouslySetInnerHTML":if(n!=null)throw Error(d(91));break;default:n!==u&&al(l,t,c,n,a,u)}Is(l,v,b);return;case"option":for(var O in e)if(v=e[O],e.hasOwnProperty(O)&&v!=null&&!a.hasOwnProperty(O))switch(O){case"selected":l.selected=!1;break;default:al(l,t,O,null,a,v)}for(r in a)if(v=a[r],b=e[r],a.hasOwnProperty(r)&&v!==b&&(v!=null||b!=null))switch(r){case"selected":l.selected=v&&typeof v!="function"&&typeof v!="symbol";break;default:al(l,t,r,v,a,b)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var B in e)v=e[B],e.hasOwnProperty(B)&&v!=null&&!a.hasOwnProperty(B)&&al(l,t,B,null,a,v);for(x in a)if(v=a[x],b=e[x],a.hasOwnProperty(x)&&v!==b&&(v!=null||b!=null))switch(x){case"children":case"dangerouslySetInnerHTML":if(v!=null)throw Error(d(137,t));break;default:al(l,t,x,v,a,b)}return;default:if(Si(t)){for(var nl in e)v=e[nl],e.hasOwnProperty(nl)&&v!==void 0&&!a.hasOwnProperty(nl)&&ss(l,t,nl,void 0,a,v);for(p in a)v=a[p],b=e[p],!a.hasOwnProperty(p)||v===b||v===void 0&&b===void 0||ss(l,t,p,v,a,b);return}}for(var h in e)v=e[h],e.hasOwnProperty(h)&&v!=null&&!a.hasOwnProperty(h)&&al(l,t,h,null,a,v);for(A in a)v=a[A],b=e[A],!a.hasOwnProperty(A)||v===b||v==null&&b==null||al(l,t,A,v,a,b)}function a0(l){switch(l){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Qm(){if(typeof performance.getEntriesByType=="function"){for(var l=0,t=0,e=performance.getEntriesByType("resource"),a=0;a<e.length;a++){var n=e[a],u=n.transferSize,c=n.initiatorType,s=n.duration;if(u&&s&&a0(c)){for(c=0,s=n.responseEnd,a+=1;a<e.length;a++){var r=e[a],x=r.startTime;if(x>s)break;var p=r.transferSize,A=r.initiatorType;p&&a0(A)&&(r=r.responseEnd,c+=p*(r<s?1:(s-x)/(r-x)))}if(--a,t+=8*(u+c)/(n.duration/1e3),l++,10<l)break}}if(0<l)return t/l/1e6}return navigator.connection&&(l=navigator.connection.downlink,typeof l=="number")?l:5}var fs=null,ds=null;function Gu(l){return l.nodeType===9?l:l.ownerDocument}function n0(l){switch(l){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function u0(l,t){if(l===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return l===1&&t==="foreignObject"?0:l}function rs(l,t){return l==="textarea"||l==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var os=null;function Xm(){var l=window.event;return l&&l.type==="popstate"?l===os?!1:(os=l,!0):(os=null,!1)}var i0=typeof setTimeout=="function"?setTimeout:void 0,Gm=typeof clearTimeout=="function"?clearTimeout:void 0,c0=typeof Promise=="function"?Promise:void 0,Lm=typeof queueMicrotask=="function"?queueMicrotask:typeof c0<"u"?function(l){return c0.resolve(null).then(l).catch(Zm)}:i0;function Zm(l){setTimeout(function(){throw l})}function he(l){return l==="head"}function s0(l,t){var e=t,a=0;do{var n=e.nextSibling;if(l.removeChild(e),n&&n.nodeType===8)if(e=n.data,e==="/$"||e==="/&"){if(a===0){l.removeChild(n),Ea(t);return}a--}else if(e==="$"||e==="$?"||e==="$~"||e==="$!"||e==="&")a++;else if(e==="html")vn(l.ownerDocument.documentElement);else if(e==="head"){e=l.ownerDocument.head,vn(e);for(var u=e.firstChild;u;){var c=u.nextSibling,s=u.nodeName;u[Ba]||s==="SCRIPT"||s==="STYLE"||s==="LINK"&&u.rel.toLowerCase()==="stylesheet"||e.removeChild(u),u=c}}else e==="body"&&vn(l.ownerDocument.body);e=n}while(e);Ea(t)}function f0(l,t){var e=l;l=0;do{var a=e.nextSibling;if(e.nodeType===1?t?(e._stashedDisplay=e.style.display,e.style.display="none"):(e.style.display=e._stashedDisplay||"",e.getAttribute("style")===""&&e.removeAttribute("style")):e.nodeType===3&&(t?(e._stashedText=e.nodeValue,e.nodeValue=""):e.nodeValue=e._stashedText||""),a&&a.nodeType===8)if(e=a.data,e==="/$"){if(l===0)break;l--}else e!=="$"&&e!=="$?"&&e!=="$~"&&e!=="$!"||l++;e=a}while(e)}function ms(l){var t=l.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var e=t;switch(t=t.nextSibling,e.nodeName){case"HTML":case"HEAD":case"BODY":ms(e),vi(e);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(e.rel.toLowerCase()==="stylesheet")continue}l.removeChild(e)}}function Vm(l,t,e,a){for(;l.nodeType===1;){var n=e;if(l.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(l.nodeName!=="INPUT"||l.type!=="hidden"))break}else if(a){if(!l[Ba])switch(t){case"meta":if(!l.hasAttribute("itemprop"))break;return l;case"link":if(u=l.getAttribute("rel"),u==="stylesheet"&&l.hasAttribute("data-precedence"))break;if(u!==n.rel||l.getAttribute("href")!==(n.href==null||n.href===""?null:n.href)||l.getAttribute("crossorigin")!==(n.crossOrigin==null?null:n.crossOrigin)||l.getAttribute("title")!==(n.title==null?null:n.title))break;return l;case"style":if(l.hasAttribute("data-precedence"))break;return l;case"script":if(u=l.getAttribute("src"),(u!==(n.src==null?null:n.src)||l.getAttribute("type")!==(n.type==null?null:n.type)||l.getAttribute("crossorigin")!==(n.crossOrigin==null?null:n.crossOrigin))&&u&&l.hasAttribute("async")&&!l.hasAttribute("itemprop"))break;return l;default:return l}}else if(t==="input"&&l.type==="hidden"){var u=n.name==null?null:""+n.name;if(n.type==="hidden"&&l.getAttribute("name")===u)return l}else return l;if(l=rt(l.nextSibling),l===null)break}return null}function Km(l,t,e){if(t==="")return null;for(;l.nodeType!==3;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!e||(l=rt(l.nextSibling),l===null))return null;return l}function d0(l,t){for(;l.nodeType!==8;)if((l.nodeType!==1||l.nodeName!=="INPUT"||l.type!=="hidden")&&!t||(l=rt(l.nextSibling),l===null))return null;return l}function hs(l){return l.data==="$?"||l.data==="$~"}function gs(l){return l.data==="$!"||l.data==="$?"&&l.ownerDocument.readyState!=="loading"}function Jm(l,t){var e=l.ownerDocument;if(l.data==="$~")l._reactRetry=t;else if(l.data!=="$?"||e.readyState!=="loading")t();else{var a=function(){t(),e.removeEventListener("DOMContentLoaded",a)};e.addEventListener("DOMContentLoaded",a),l._reactRetry=a}}function rt(l){for(;l!=null;l=l.nextSibling){var t=l.nodeType;if(t===1||t===3)break;if(t===8){if(t=l.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return l}var ys=null;function r0(l){l=l.nextSibling;for(var t=0;l;){if(l.nodeType===8){var e=l.data;if(e==="/$"||e==="/&"){if(t===0)return rt(l.nextSibling);t--}else e!=="$"&&e!=="$!"&&e!=="$?"&&e!=="$~"&&e!=="&"||t++}l=l.nextSibling}return null}function o0(l){l=l.previousSibling;for(var t=0;l;){if(l.nodeType===8){var e=l.data;if(e==="$"||e==="$!"||e==="$?"||e==="$~"||e==="&"){if(t===0)return l;t--}else e!=="/$"&&e!=="/&"||t++}l=l.previousSibling}return null}function m0(l,t,e){switch(t=Gu(e),l){case"html":if(l=t.documentElement,!l)throw Error(d(452));return l;case"head":if(l=t.head,!l)throw Error(d(453));return l;case"body":if(l=t.body,!l)throw Error(d(454));return l;default:throw Error(d(451))}}function vn(l){for(var t=l.attributes;t.length;)l.removeAttributeNode(t[0]);vi(l)}var ot=new Map,h0=new Set;function Lu(l){return typeof l.getRootNode=="function"?l.getRootNode():l.nodeType===9?l:l.ownerDocument}var Kt=_.d;_.d={f:km,r:wm,D:$m,C:Wm,L:Fm,m:Im,X:lh,S:Pm,M:th};function km(){var l=Kt.f(),t=Cu();return l||t}function wm(l){var t=Je(l);t!==null&&t.tag===5&&t.type==="form"?Od(t):Kt.r(l)}var za=typeof document>"u"?null:document;function g0(l,t,e){var a=za;if(a&&typeof t=="string"&&t){var n=nt(t);n='link[rel="'+l+'"][href="'+n+'"]',typeof e=="string"&&(n+='[crossorigin="'+e+'"]'),h0.has(n)||(h0.add(n),l={rel:l,crossOrigin:e,href:t},a.querySelector(n)===null&&(t=a.createElement("link"),Ol(t,"link",l),zl(t),a.head.appendChild(t)))}}function $m(l){Kt.D(l),g0("dns-prefetch",l,null)}function Wm(l,t){Kt.C(l,t),g0("preconnect",l,t)}function Fm(l,t,e){Kt.L(l,t,e);var a=za;if(a&&l&&t){var n='link[rel="preload"][as="'+nt(t)+'"]';t==="image"&&e&&e.imageSrcSet?(n+='[imagesrcset="'+nt(e.imageSrcSet)+'"]',typeof e.imageSizes=="string"&&(n+='[imagesizes="'+nt(e.imageSizes)+'"]')):n+='[href="'+nt(l)+'"]';var u=n;switch(t){case"style":u=Aa(l);break;case"script":u=Ta(l)}ot.has(u)||(l=j({rel:"preload",href:t==="image"&&e&&e.imageSrcSet?void 0:l,as:t},e),ot.set(u,l),a.querySelector(n)!==null||t==="style"&&a.querySelector(bn(u))||t==="script"&&a.querySelector(pn(u))||(t=a.createElement("link"),Ol(t,"link",l),zl(t),a.head.appendChild(t)))}}function Im(l,t){Kt.m(l,t);var e=za;if(e&&l){var a=t&&typeof t.as=="string"?t.as:"script",n='link[rel="modulepreload"][as="'+nt(a)+'"][href="'+nt(l)+'"]',u=n;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":u=Ta(l)}if(!ot.has(u)&&(l=j({rel:"modulepreload",href:l},t),ot.set(u,l),e.querySelector(n)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(e.querySelector(pn(u)))return}a=e.createElement("link"),Ol(a,"link",l),zl(a),e.head.appendChild(a)}}}function Pm(l,t,e){Kt.S(l,t,e);var a=za;if(a&&l){var n=ke(a).hoistableStyles,u=Aa(l);t=t||"default";var c=n.get(u);if(!c){var s={loading:0,preload:null};if(c=a.querySelector(bn(u)))s.loading=5;else{l=j({rel:"stylesheet",href:l,"data-precedence":t},e),(e=ot.get(u))&&xs(l,e);var r=c=a.createElement("link");zl(r),Ol(r,"link",l),r._p=new Promise(function(x,p){r.onload=x,r.onerror=p}),r.addEventListener("load",function(){s.loading|=1}),r.addEventListener("error",function(){s.loading|=2}),s.loading|=4,Zu(c,t,a)}c={type:"stylesheet",instance:c,count:1,state:s},n.set(u,c)}}}function lh(l,t){Kt.X(l,t);var e=za;if(e&&l){var a=ke(e).hoistableScripts,n=Ta(l),u=a.get(n);u||(u=e.querySelector(pn(n)),u||(l=j({src:l,async:!0},t),(t=ot.get(n))&&vs(l,t),u=e.createElement("script"),zl(u),Ol(u,"link",l),e.head.appendChild(u)),u={type:"script",instance:u,count:1,state:null},a.set(n,u))}}function th(l,t){Kt.M(l,t);var e=za;if(e&&l){var a=ke(e).hoistableScripts,n=Ta(l),u=a.get(n);u||(u=e.querySelector(pn(n)),u||(l=j({src:l,async:!0,type:"module"},t),(t=ot.get(n))&&vs(l,t),u=e.createElement("script"),zl(u),Ol(u,"link",l),e.head.appendChild(u)),u={type:"script",instance:u,count:1,state:null},a.set(n,u))}}function y0(l,t,e,a){var n=(n=wt.current)?Lu(n):null;if(!n)throw Error(d(446));switch(l){case"meta":case"title":return null;case"style":return typeof e.precedence=="string"&&typeof e.href=="string"?(t=Aa(e.href),e=ke(n).hoistableStyles,a=e.get(t),a||(a={type:"style",instance:null,count:0,state:null},e.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(e.rel==="stylesheet"&&typeof e.href=="string"&&typeof e.precedence=="string"){l=Aa(e.href);var u=ke(n).hoistableStyles,c=u.get(l);if(c||(n=n.ownerDocument||n,c={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},u.set(l,c),(u=n.querySelector(bn(l)))&&!u._p&&(c.instance=u,c.state.loading=5),ot.has(l)||(e={rel:"preload",as:"style",href:e.href,crossOrigin:e.crossOrigin,integrity:e.integrity,media:e.media,hrefLang:e.hrefLang,referrerPolicy:e.referrerPolicy},ot.set(l,e),u||eh(n,l,e,c.state))),t&&a===null)throw Error(d(528,""));return c}if(t&&a!==null)throw Error(d(529,""));return null;case"script":return t=e.async,e=e.src,typeof e=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Ta(e),e=ke(n).hoistableScripts,a=e.get(t),a||(a={type:"script",instance:null,count:0,state:null},e.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(d(444,l))}}function Aa(l){return'href="'+nt(l)+'"'}function bn(l){return'link[rel="stylesheet"]['+l+"]"}function x0(l){return j({},l,{"data-precedence":l.precedence,precedence:null})}function eh(l,t,e,a){l.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=l.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),Ol(t,"link",e),zl(t),l.head.appendChild(t))}function Ta(l){return'[src="'+nt(l)+'"]'}function pn(l){return"script[async]"+l}function v0(l,t,e){if(t.count++,t.instance===null)switch(t.type){case"style":var a=l.querySelector('style[data-href~="'+nt(e.href)+'"]');if(a)return t.instance=a,zl(a),a;var n=j({},e,{"data-href":e.href,"data-precedence":e.precedence,href:null,precedence:null});return a=(l.ownerDocument||l).createElement("style"),zl(a),Ol(a,"style",n),Zu(a,e.precedence,l),t.instance=a;case"stylesheet":n=Aa(e.href);var u=l.querySelector(bn(n));if(u)return t.state.loading|=4,t.instance=u,zl(u),u;a=x0(e),(n=ot.get(n))&&xs(a,n),u=(l.ownerDocument||l).createElement("link"),zl(u);var c=u;return c._p=new Promise(function(s,r){c.onload=s,c.onerror=r}),Ol(u,"link",a),t.state.loading|=4,Zu(u,e.precedence,l),t.instance=u;case"script":return u=Ta(e.src),(n=l.querySelector(pn(u)))?(t.instance=n,zl(n),n):(a=e,(n=ot.get(u))&&(a=j({},e),vs(a,n)),l=l.ownerDocument||l,n=l.createElement("script"),zl(n),Ol(n,"link",a),l.head.appendChild(n),t.instance=n);case"void":return null;default:throw Error(d(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,Zu(a,e.precedence,l));return t.instance}function Zu(l,t,e){for(var a=e.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),n=a.length?a[a.length-1]:null,u=n,c=0;c<a.length;c++){var s=a[c];if(s.dataset.precedence===t)u=s;else if(u!==n)break}u?u.parentNode.insertBefore(l,u.nextSibling):(t=e.nodeType===9?e.head:e,t.insertBefore(l,t.firstChild))}function xs(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.title==null&&(l.title=t.title)}function vs(l,t){l.crossOrigin==null&&(l.crossOrigin=t.crossOrigin),l.referrerPolicy==null&&(l.referrerPolicy=t.referrerPolicy),l.integrity==null&&(l.integrity=t.integrity)}var Vu=null;function b0(l,t,e){if(Vu===null){var a=new Map,n=Vu=new Map;n.set(e,a)}else n=Vu,a=n.get(e),a||(a=new Map,n.set(e,a));if(a.has(l))return a;for(a.set(l,null),e=e.getElementsByTagName(l),n=0;n<e.length;n++){var u=e[n];if(!(u[Ba]||u[El]||l==="link"&&u.getAttribute("rel")==="stylesheet")&&u.namespaceURI!=="http://www.w3.org/2000/svg"){var c=u.getAttribute(t)||"";c=l+c;var s=a.get(c);s?s.push(u):a.set(c,[u])}}return a}function p0(l,t,e){l=l.ownerDocument||l,l.head.insertBefore(e,t==="title"?l.querySelector("head > title"):null)}function ah(l,t,e){if(e===1||t.itemProp!=null)return!1;switch(l){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return l=t.disabled,typeof t.precedence=="string"&&l==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function j0(l){return!(l.type==="stylesheet"&&(l.state.loading&3)===0)}function nh(l,t,e,a){if(e.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&(e.state.loading&4)===0){if(e.instance===null){var n=Aa(a.href),u=t.querySelector(bn(n));if(u){t=u._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(l.count++,l=Ku.bind(l),t.then(l,l)),e.state.loading|=4,e.instance=u,zl(u);return}u=t.ownerDocument||t,a=x0(a),(n=ot.get(n))&&xs(a,n),u=u.createElement("link"),zl(u);var c=u;c._p=new Promise(function(s,r){c.onload=s,c.onerror=r}),Ol(u,"link",a),e.instance=u}l.stylesheets===null&&(l.stylesheets=new Map),l.stylesheets.set(e,t),(t=e.state.preload)&&(e.state.loading&3)===0&&(l.count++,e=Ku.bind(l),t.addEventListener("load",e),t.addEventListener("error",e))}}var bs=0;function uh(l,t){return l.stylesheets&&l.count===0&&ku(l,l.stylesheets),0<l.count||0<l.imgCount?function(e){var a=setTimeout(function(){if(l.stylesheets&&ku(l,l.stylesheets),l.unsuspend){var u=l.unsuspend;l.unsuspend=null,u()}},6e4+t);0<l.imgBytes&&bs===0&&(bs=62500*Qm());var n=setTimeout(function(){if(l.waitingForImages=!1,l.count===0&&(l.stylesheets&&ku(l,l.stylesheets),l.unsuspend)){var u=l.unsuspend;l.unsuspend=null,u()}},(l.imgBytes>bs?50:800)+t);return l.unsuspend=e,function(){l.unsuspend=null,clearTimeout(a),clearTimeout(n)}}:null}function Ku(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)ku(this,this.stylesheets);else if(this.unsuspend){var l=this.unsuspend;this.unsuspend=null,l()}}}var Ju=null;function ku(l,t){l.stylesheets=null,l.unsuspend!==null&&(l.count++,Ju=new Map,t.forEach(ih,l),Ju=null,Ku.call(l))}function ih(l,t){if(!(t.state.loading&4)){var e=Ju.get(l);if(e)var a=e.get(null);else{e=new Map,Ju.set(l,e);for(var n=l.querySelectorAll("link[data-precedence],style[data-precedence]"),u=0;u<n.length;u++){var c=n[u];(c.nodeName==="LINK"||c.getAttribute("media")!=="not all")&&(e.set(c.dataset.precedence,c),a=c)}a&&e.set(null,a)}n=t.instance,c=n.getAttribute("data-precedence"),u=e.get(c)||a,u===a&&e.set(null,n),e.set(c,n),this.count++,a=Ku.bind(this),n.addEventListener("load",a),n.addEventListener("error",a),u?u.parentNode.insertBefore(n,u.nextSibling):(l=l.nodeType===9?l.head:l,l.insertBefore(n,l.firstChild)),t.state.loading|=4}}var jn={$$typeof:Hl,Provider:null,Consumer:null,_currentValue:q,_currentValue2:q,_threadCount:0};function ch(l,t,e,a,n,u,c,s,r){this.tag=1,this.containerInfo=l,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=hi(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=hi(0),this.hiddenUpdates=hi(null),this.identifierPrefix=a,this.onUncaughtError=n,this.onCaughtError=u,this.onRecoverableError=c,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=r,this.incompleteTransitions=new Map}function S0(l,t,e,a,n,u,c,s,r,x,p,A){return l=new ch(l,t,e,c,r,x,p,A,s),t=1,u===!0&&(t|=24),u=wl(3,null,null,t),l.current=u,u.stateNode=l,t=Ii(),t.refCount++,l.pooledCache=t,t.refCount++,u.memoizedState={element:a,isDehydrated:e,cache:t},ec(u),l}function N0(l){return l?(l=aa,l):aa}function z0(l,t,e,a,n,u){n=N0(n),a.context===null?a.context=n:a.pendingContext=n,a=ae(t),a.payload={element:e},u=u===void 0?null:u,u!==null&&(a.callback=u),e=ne(l,a,t),e!==null&&(Gl(e,l,t),Ia(e,l,t))}function A0(l,t){if(l=l.memoizedState,l!==null&&l.dehydrated!==null){var e=l.retryLane;l.retryLane=e!==0&&e<t?e:t}}function ps(l,t){A0(l,t),(l=l.alternate)&&A0(l,t)}function T0(l){if(l.tag===13||l.tag===31){var t=Me(l,67108864);t!==null&&Gl(t,l,67108864),ps(l,67108864)}}function E0(l){if(l.tag===13||l.tag===31){var t=Pl();t=gi(t);var e=Me(l,t);e!==null&&Gl(e,l,t),ps(l,t)}}var wu=!0;function sh(l,t,e,a){var n=z.T;z.T=null;var u=_.p;try{_.p=2,js(l,t,e,a)}finally{_.p=u,z.T=n}}function fh(l,t,e,a){var n=z.T;z.T=null;var u=_.p;try{_.p=8,js(l,t,e,a)}finally{_.p=u,z.T=n}}function js(l,t,e,a){if(wu){var n=Ss(a);if(n===null)cs(l,t,a,$u,e),_0(l,a);else if(rh(n,l,t,e,a))a.stopPropagation();else if(_0(l,a),t&4&&-1<dh.indexOf(l)){for(;n!==null;){var u=Je(n);if(u!==null)switch(u.tag){case 3:if(u=u.stateNode,u.current.memoizedState.isDehydrated){var c=Ne(u.pendingLanes);if(c!==0){var s=u;for(s.pendingLanes|=2,s.entangledLanes|=2;c;){var r=1<<31-Jl(c);s.entanglements[1]|=r,c&=~r}zt(u),(I&6)===0&&(Ou=Vl()+500,gn(0))}}break;case 31:case 13:s=Me(u,2),s!==null&&Gl(s,u,2),Cu(),ps(u,2)}if(u=Ss(a),u===null&&cs(l,t,a,$u,e),u===n)break;n=u}n!==null&&a.stopPropagation()}else cs(l,t,a,null,e)}}function Ss(l){return l=zi(l),Ns(l)}var $u=null;function Ns(l){if($u=null,l=Ke(l),l!==null){var t=T(l);if(t===null)l=null;else{var e=t.tag;if(e===13){if(l=E(t),l!==null)return l;l=null}else if(e===31){if(l=C(t),l!==null)return l;l=null}else if(e===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;l=null}else t!==l&&(l=null)}}return $u=l,null}function M0(l){switch(l){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(w0()){case Bs:return 2;case Rs:return 8;case Yn:case $0:return 32;case qs:return 268435456;default:return 32}default:return 32}}var zs=!1,ge=null,ye=null,xe=null,Sn=new Map,Nn=new Map,ve=[],dh="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function _0(l,t){switch(l){case"focusin":case"focusout":ge=null;break;case"dragenter":case"dragleave":ye=null;break;case"mouseover":case"mouseout":xe=null;break;case"pointerover":case"pointerout":Sn.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Nn.delete(t.pointerId)}}function zn(l,t,e,a,n,u){return l===null||l.nativeEvent!==u?(l={blockedOn:t,domEventName:e,eventSystemFlags:a,nativeEvent:u,targetContainers:[n]},t!==null&&(t=Je(t),t!==null&&T0(t)),l):(l.eventSystemFlags|=a,t=l.targetContainers,n!==null&&t.indexOf(n)===-1&&t.push(n),l)}function rh(l,t,e,a,n){switch(t){case"focusin":return ge=zn(ge,l,t,e,a,n),!0;case"dragenter":return ye=zn(ye,l,t,e,a,n),!0;case"mouseover":return xe=zn(xe,l,t,e,a,n),!0;case"pointerover":var u=n.pointerId;return Sn.set(u,zn(Sn.get(u)||null,l,t,e,a,n)),!0;case"gotpointercapture":return u=n.pointerId,Nn.set(u,zn(Nn.get(u)||null,l,t,e,a,n)),!0}return!1}function D0(l){var t=Ke(l.target);if(t!==null){var e=T(t);if(e!==null){if(t=e.tag,t===13){if(t=E(e),t!==null){l.blockedOn=t,Zs(l.priority,function(){E0(e)});return}}else if(t===31){if(t=C(e),t!==null){l.blockedOn=t,Zs(l.priority,function(){E0(e)});return}}else if(t===3&&e.stateNode.current.memoizedState.isDehydrated){l.blockedOn=e.tag===3?e.stateNode.containerInfo:null;return}}}l.blockedOn=null}function Wu(l){if(l.blockedOn!==null)return!1;for(var t=l.targetContainers;0<t.length;){var e=Ss(l.nativeEvent);if(e===null){e=l.nativeEvent;var a=new e.constructor(e.type,e);Ni=a,e.target.dispatchEvent(a),Ni=null}else return t=Je(e),t!==null&&T0(t),l.blockedOn=e,!1;t.shift()}return!0}function O0(l,t,e){Wu(l)&&e.delete(t)}function oh(){zs=!1,ge!==null&&Wu(ge)&&(ge=null),ye!==null&&Wu(ye)&&(ye=null),xe!==null&&Wu(xe)&&(xe=null),Sn.forEach(O0),Nn.forEach(O0)}function Fu(l,t){l.blockedOn===t&&(l.blockedOn=null,zs||(zs=!0,f.unstable_scheduleCallback(f.unstable_NormalPriority,oh)))}var Iu=null;function U0(l){Iu!==l&&(Iu=l,f.unstable_scheduleCallback(f.unstable_NormalPriority,function(){Iu===l&&(Iu=null);for(var t=0;t<l.length;t+=3){var e=l[t],a=l[t+1],n=l[t+2];if(typeof a!="function"){if(Ns(a||e)===null)continue;break}var u=Je(e);u!==null&&(l.splice(t,3),t-=3,Sc(u,{pending:!0,data:n,method:e.method,action:a},a,n))}}))}function Ea(l){function t(r){return Fu(r,l)}ge!==null&&Fu(ge,l),ye!==null&&Fu(ye,l),xe!==null&&Fu(xe,l),Sn.forEach(t),Nn.forEach(t);for(var e=0;e<ve.length;e++){var a=ve[e];a.blockedOn===l&&(a.blockedOn=null)}for(;0<ve.length&&(e=ve[0],e.blockedOn===null);)D0(e),e.blockedOn===null&&ve.shift();if(e=(l.ownerDocument||l).$$reactFormReplay,e!=null)for(a=0;a<e.length;a+=3){var n=e[a],u=e[a+1],c=n[Bl]||null;if(typeof u=="function")c||U0(e);else if(c){var s=null;if(u&&u.hasAttribute("formAction")){if(n=u,c=u[Bl]||null)s=c.formAction;else if(Ns(n)!==null)continue}else s=c.action;typeof s=="function"?e[a+1]=s:(e.splice(a,3),a-=3),U0(e)}}}function C0(){function l(u){u.canIntercept&&u.info==="react-transition"&&u.intercept({handler:function(){return new Promise(function(c){return n=c})},focusReset:"manual",scroll:"manual"})}function t(){n!==null&&(n(),n=null),a||setTimeout(e,20)}function e(){if(!a&&!navigation.transition){var u=navigation.currentEntry;u&&u.url!=null&&navigation.navigate(u.url,{state:u.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var a=!1,n=null;return navigation.addEventListener("navigate",l),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(e,100),function(){a=!0,navigation.removeEventListener("navigate",l),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),n!==null&&(n(),n=null)}}}function As(l){this._internalRoot=l}Pu.prototype.render=As.prototype.render=function(l){var t=this._internalRoot;if(t===null)throw Error(d(409));var e=t.current,a=Pl();z0(e,a,l,t,null,null)},Pu.prototype.unmount=As.prototype.unmount=function(){var l=this._internalRoot;if(l!==null){this._internalRoot=null;var t=l.containerInfo;z0(l.current,2,null,l,null,null),Cu(),t[Ve]=null}};function Pu(l){this._internalRoot=l}Pu.prototype.unstable_scheduleHydration=function(l){if(l){var t=Ls();l={blockedOn:null,target:l,priority:t};for(var e=0;e<ve.length&&t!==0&&t<ve[e].priority;e++);ve.splice(e,0,l),e===0&&D0(l)}};var H0=m.version;if(H0!=="19.2.4")throw Error(d(527,H0,"19.2.4"));_.findDOMNode=function(l){var t=l._reactInternals;if(t===void 0)throw typeof l.render=="function"?Error(d(188)):(l=Object.keys(l).join(","),Error(d(268,l)));return l=Z(t),l=l!==null?D(l):null,l=l===null?null:l.stateNode,l};var mh={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:z,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var li=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!li.isDisabled&&li.supportsFiber)try{Ua=li.inject(mh),Kl=li}catch{}}return Tn.createRoot=function(l,t){if(!N(l))throw Error(d(299));var e=!1,a="",n=Gd,u=Ld,c=Zd;return t!=null&&(t.unstable_strictMode===!0&&(e=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(n=t.onUncaughtError),t.onCaughtError!==void 0&&(u=t.onCaughtError),t.onRecoverableError!==void 0&&(c=t.onRecoverableError)),t=S0(l,1,!1,null,null,e,a,null,n,u,c,C0),l[Ve]=t.current,is(l),new As(t)},Tn.hydrateRoot=function(l,t,e){if(!N(l))throw Error(d(299));var a=!1,n="",u=Gd,c=Ld,s=Zd,r=null;return e!=null&&(e.unstable_strictMode===!0&&(a=!0),e.identifierPrefix!==void 0&&(n=e.identifierPrefix),e.onUncaughtError!==void 0&&(u=e.onUncaughtError),e.onCaughtError!==void 0&&(c=e.onCaughtError),e.onRecoverableError!==void 0&&(s=e.onRecoverableError),e.formState!==void 0&&(r=e.formState)),t=S0(l,1,!0,t,e??null,a,n,r,u,c,s,C0),t.context=N0(null),e=t.current,a=Pl(),a=gi(a),n=ae(a),n.callback=null,ne(e,n,a),e=a,t.current.lanes=e,Ha(t,e),zt(t),l[Ve]=t.current,is(l),new Pu(t)},Tn.version="19.2.4",Tn}var G0;function Hh(){if(G0)return Es.exports;G0=1;function f(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(f)}catch(m){console.error(m)}}return f(),Es.exports=Ch(),Es.exports}var Bh=Hh();const Rh=[{to:"/",label:"Overview",icon:Qh},{to:"/agents",label:"Agents",icon:Yh},{to:"/eval",label:"Eval",icon:Xh},{to:"/playground",label:"Playground",icon:Gh},{to:"/analytics",label:"Analytics",icon:Lh},{to:"/compliance",label:"Compliance",icon:Zh}];function qh({collapsed:f,onToggle:m}){return i.jsxs("aside",{className:`flex h-full flex-col border-r border-gray-200 bg-white transition-all dark:border-gray-800 dark:bg-gray-900 ${f?"w-16":"w-56"}`,children:[i.jsxs("div",{className:"flex h-14 items-center border-b border-gray-200 px-4 dark:border-gray-800",children:[!f&&i.jsx("span",{className:"text-lg font-bold text-indigo-600 dark:text-indigo-400",children:"HatchDX"}),i.jsx("button",{onClick:m,className:`rounded p-1 text-gray-400 hover:bg-gray-100 hover:text-gray-600 dark:hover:bg-gray-800 dark:hover:text-gray-300 ${f?"mx-auto":"ml-auto"}`,"aria-label":f?"Expand sidebar":"Collapse sidebar",children:i.jsx("svg",{className:"h-5 w-5",viewBox:"0 0 20 20",fill:"currentColor",children:f?i.jsx("path",{fillRule:"evenodd",d:"M7.21 14.77a.75.75 0 01.02-1.06L11.168 10 7.23 6.29a.75.75 0 111.04-1.08l4.5 4.25a.75.75 0 010 1.08l-4.5 4.25a.75.75 0 01-1.06-.02z",clipRule:"evenodd"}):i.jsx("path",{fillRule:"evenodd",d:"M12.79 5.23a.75.75 0 01-.02 1.06L8.832 10l3.938 3.71a.75.75 0 11-1.04 1.08l-4.5-4.25a.75.75 0 010-1.08l4.5-4.25a.75.75 0 011.06.02z",clipRule:"evenodd"})})})]}),i.jsx("nav",{className:"flex-1 space-y-1 px-2 py-3",children:Rh.map(({to:g,label:d,icon:N})=>i.jsxs(vh,{to:g,end:g==="/",className:({isActive:T})=>`flex items-center gap-3 rounded-md px-3 py-2 text-sm font-medium transition-colors ${T?"bg-indigo-50 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"text-gray-700 hover:bg-gray-100 dark:text-gray-300 dark:hover:bg-gray-800"}`,children:[i.jsx(N,{className:"h-5 w-5 shrink-0"}),!f&&i.jsx("span",{children:d})]},g))})]})}function Yh({className:f}){return i.jsxs("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:[i.jsx("path",{d:"M14 6H6v8h8V6z"}),i.jsx("path",{fillRule:"evenodd",d:"M9.25 3V1.75a.75.75 0 011.5 0V3h1.5V1.75a.75.75 0 011.5 0V3h.5A2.75 2.75 0 0117 5.75v.5h1.25a.75.75 0 010 1.5H17v1.5h1.25a.75.75 0 010 1.5H17v1.5h1.25a.75.75 0 010 1.5H17v.5A2.75 2.75 0 0114.25 17h-.5v1.25a.75.75 0 01-1.5 0V17h-1.5v1.25a.75.75 0 01-1.5 0V17h-1.5v1.25a.75.75 0 01-1.5 0V17h-.5A2.75 2.75 0 013 14.25v-.5H1.75a.75.75 0 010-1.5H3v-1.5H1.75a.75.75 0 010-1.5H3v-1.5H1.75a.75.75 0 010-1.5H3v-.5A2.75 2.75 0 015.75 3h.5V1.75a.75.75 0 011.5 0V3h1.5zM4.5 5.75c0-.69.56-1.25 1.25-1.25h8.5c.69 0 1.25.56 1.25 1.25v8.5c0 .69-.56 1.25-1.25 1.25h-8.5c-.69 0-1.25-.56-1.25-1.25v-8.5z",clipRule:"evenodd"})]})}function Qh({className:f}){return i.jsx("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:i.jsx("path",{fillRule:"evenodd",d:"M9.293 2.293a1 1 0 011.414 0l7 7A1 1 0 0117 11h-1v6a1 1 0 01-1 1h-2a1 1 0 01-1-1v-3a1 1 0 00-1-1H9a1 1 0 00-1 1v3a1 1 0 01-1 1H5a1 1 0 01-1-1v-6H3a1 1 0 01-.707-1.707l7-7z",clipRule:"evenodd"})})}function Xh({className:f}){return i.jsx("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:i.jsx("path",{d:"M15.5 2A1.5 1.5 0 0014 3.5v13a1.5 1.5 0 001.5 1.5h1a1.5 1.5 0 001.5-1.5v-13A1.5 1.5 0 0016.5 2h-1zM9.5 6A1.5 1.5 0 008 7.5v9A1.5 1.5 0 009.5 18h1a1.5 1.5 0 001.5-1.5v-9A1.5 1.5 0 0010.5 6h-1zM3.5 10A1.5 1.5 0 002 11.5v5A1.5 1.5 0 003.5 18h1A1.5 1.5 0 006 16.5v-5A1.5 1.5 0 004.5 10h-1z"})})}function Gh({className:f}){return i.jsx("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:i.jsx("path",{fillRule:"evenodd",d:"M8 3.5A1.5 1.5 0 019.5 2h1A1.5 1.5 0 0112 3.5V4h.5A1.5 1.5 0 0114 5.5v1.384l-3.27 5.89A1.5 1.5 0 009.5 14H9v3.5a.5.5 0 01-.5.5h-1a.5.5 0 01-.5-.5V14h-.5a1.5 1.5 0 01-1.23-1.226L2 5.5A1.5 1.5 0 013.5 4H8v-.5zM4.5 6h11l-3 5.4a.5.5 0 01-.438.6H7.938a.5.5 0 01-.438-.258L4.5 6z",clipRule:"evenodd"})})}function Lh({className:f}){return i.jsx("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:i.jsx("path",{fillRule:"evenodd",d:"M12.577 4.878a.75.75 0 01.919-.53l4.78 1.281a.75.75 0 01.531.919l-1.281 4.78a.75.75 0 01-1.449-.387l.81-3.022a19.407 19.407 0 00-5.594 5.203.75.75 0 01-1.139.093L7 10.06l-4.72 4.72a.75.75 0 01-1.06-1.06l5.25-5.25a.75.75 0 011.06 0l3.074 3.073a20.923 20.923 0 015.545-4.93l-3.043.815a.75.75 0 01-.53-.919z",clipRule:"evenodd"})})}function Zh({className:f}){return i.jsx("svg",{className:f,viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true",children:i.jsx("path",{fillRule:"evenodd",d:"M9.661 2.237a.531.531 0 01.678 0 11.947 11.947 0 007.078 2.749.5.5 0 01.479.425c.069.52.104 1.05.104 1.589 0 5.162-3.26 9.563-7.834 11.256a.48.48 0 01-.332 0C5.26 16.563 2 12.162 2 7c0-.538.035-1.069.104-1.589a.5.5 0 01.48-.425 11.947 11.947 0 007.077-2.75z",clipRule:"evenodd"})})}const Vh={"/":"Overview","/eval":"Eval Dashboard","/playground":"Tool Playground","/analytics":"Analytics","/compliance":"Compliance"};function Kh(){const{pathname:f}=bh(),m=f.split("/").filter(Boolean),g=Vh[f]??m[m.length-1]??"Overview";return i.jsx("header",{className:"flex h-14 items-center border-b border-gray-200 bg-white px-6 dark:border-gray-800 dark:bg-gray-900",children:i.jsxs("nav",{className:"flex items-center gap-2 text-sm",children:[i.jsx("span",{className:"text-gray-400 dark:text-gray-500",children:"hdx"}),i.jsx("span",{className:"text-gray-300 dark:text-gray-600",children:"/"}),i.jsx("span",{className:"font-medium text-gray-900 dark:text-gray-100",children:g})]})})}class Jh extends L.Component{constructor(){super(...arguments);B0(this,"state",{error:null})}static getDerivedStateFromError(g){return{error:g}}componentDidCatch(g,d){console.error("ErrorBoundary caught:",g,d)}render(){return this.state.error?this.props.fallback??i.jsxs("div",{className:"rounded-lg border border-red-200 bg-red-50 p-6 dark:border-red-900 dark:bg-red-950",children:[i.jsx("h3",{className:"font-medium text-red-800 dark:text-red-300",children:"Something went wrong"}),i.jsx("p",{className:"mt-1 text-sm text-red-600 dark:text-red-400",children:this.state.error.message}),i.jsx("button",{onClick:()=>this.setState({error:null}),className:"mt-3 text-sm font-medium text-red-700 underline hover:text-red-600 dark:text-red-400",children:"Try again"})]}):this.props.children}}function kh(){const[f,m]=L.useState(!1);return i.jsxs("div",{className:"flex h-screen overflow-hidden",children:[i.jsx(qh,{collapsed:f,onToggle:()=>m(!f)}),i.jsxs("div",{className:"flex flex-1 flex-col overflow-hidden",children:[i.jsx(Kh,{}),i.jsx("main",{className:"flex-1 overflow-y-auto p-6",children:i.jsx(Jh,{children:i.jsx(ph,{})})})]})]})}const wh="/api";class $h extends Error{constructor(m,g){super(g),this.status=m,this.name="ApiError"}}async function Mn(f,m){const g=await fetch(`${wh}${f}`,{headers:{"Content-Type":"application/json",...m==null?void 0:m.headers},...m});if(!g.ok){const d=await g.text().catch(()=>"Unknown error");throw new $h(g.status,d)}return g.json()}function Ll(f){const[m,g]=L.useState(null),[d,N]=L.useState(null),[T,E]=L.useState(f!==null),C=L.useCallback(async()=>{if(f!==null){E(!0),N(null);try{const M=await Mn(f);g(M)}catch(M){N(M instanceof Error?M:new Error(String(M)))}finally{E(!1)}}},[f]);return L.useEffect(()=>{C()},[C]),{data:m,error:d,loading:T,refetch:C}}function pe({message:f="Loading..."}){return i.jsx("div",{className:"flex items-center justify-center py-12",children:i.jsxs("div",{className:"flex items-center gap-3 text-gray-500 dark:text-gray-400",children:[i.jsxs("svg",{className:"h-5 w-5 animate-spin",viewBox:"0 0 24 24",fill:"none",children:[i.jsx("circle",{className:"opacity-25",cx:"12",cy:"12",r:"10",stroke:"currentColor",strokeWidth:"4"}),i.jsx("path",{className:"opacity-75",fill:"currentColor",d:"M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4z"})]}),i.jsx("span",{className:"text-sm",children:f})]})})}const Wh={pass:"bg-emerald-100 text-emerald-800 dark:bg-emerald-900/30 dark:text-emerald-400",fail:"bg-red-100 text-red-800 dark:bg-red-900/30 dark:text-red-400",warn:"bg-amber-100 text-amber-800 dark:bg-amber-900/30 dark:text-amber-400",info:"bg-blue-100 text-blue-800 dark:bg-blue-900/30 dark:text-blue-400",neutral:"bg-gray-100 text-gray-700 dark:bg-gray-800 dark:text-gray-300"};function At({variant:f,children:m}){return i.jsx("span",{className:`inline-flex items-center rounded-full px-2 py-0.5 text-xs font-medium ${Wh[f]}`,children:m})}function _n(f){return new Date(f).toLocaleString("en-US",{month:"short",day:"numeric",hour:"numeric",minute:"2-digit"})}function ii(f){return f<1e3?`${Math.round(f)}ms`:f<6e4?`${(f/1e3).toFixed(1)}s`:`${(f/6e4).toFixed(1)}m`}function Da(f){return`${(f*100).toFixed(1)}%`}function ui(f){return f<.01?`$${f.toFixed(4)}`:`$${f.toFixed(2)}`}function Fh(){const{data:f,loading:m}=Ll("/overview");if(m)return i.jsx(pe,{message:"Loading dashboard..."});const g=f??{project_name:"hatchdx",server_count:0,tool_count:0,recent_runs:[],servers:[]};return i.jsxs("div",{className:"space-y-8",children:[i.jsxs("div",{children:[i.jsx("h1",{className:"text-2xl font-bold",children:g.project_name}),i.jsx("p",{className:"mt-1 text-sm text-gray-500 dark:text-gray-400",children:"MCP Server Development Dashboard"})]}),i.jsxs("div",{className:"grid grid-cols-1 gap-4 sm:grid-cols-3",children:[i.jsx(Ds,{label:"Servers",value:g.server_count}),i.jsx(Ds,{label:"Tools",value:g.tool_count}),i.jsx(Ds,{label:"Eval Runs",value:g.recent_runs.length})]}),i.jsxs("section",{children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h2",{className:"text-lg font-semibold",children:"Recent Eval Runs"}),i.jsx(vt,{to:"/eval",className:"text-sm font-medium text-indigo-600 hover:text-indigo-500 dark:text-indigo-400",children:"View all"})]}),g.recent_runs.length===0?i.jsxs("p",{className:"mt-3 text-sm text-gray-500 dark:text-gray-400",children:["No eval runs yet. Run"," ",i.jsx("code",{className:"rounded bg-gray-100 px-1 py-0.5 text-xs dark:bg-gray-800",children:"hdx eval"})," ","to get started."]}):i.jsx("div",{className:"mt-3 overflow-hidden rounded-lg border border-gray-200 dark:border-gray-800",children:i.jsxs("table",{className:"min-w-full divide-y divide-gray-200 dark:divide-gray-800",children:[i.jsx("thead",{className:"bg-gray-50 dark:bg-gray-900",children:i.jsxs("tr",{children:[i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Run"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Date"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Result"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Pass Rate"})]})}),i.jsx("tbody",{className:"divide-y divide-gray-200 dark:divide-gray-800",children:g.recent_runs.map(d=>{const N=d.passed+d.failed,T=N>0?d.passed/N:0;return i.jsxs("tr",{className:"hover:bg-gray-50 dark:hover:bg-gray-900/50",children:[i.jsx("td",{className:"px-4 py-2",children:i.jsx(vt,{to:`/eval/${d.run_id}`,className:"text-sm font-medium text-indigo-600 hover:underline dark:text-indigo-400",children:d.run_id.slice(0,8)})}),i.jsx("td",{className:"px-4 py-2 text-sm text-gray-500",children:_n(d.started_at)}),i.jsx("td",{className:"px-4 py-2",children:i.jsxs(At,{variant:d.failed===0?"pass":"fail",children:[d.passed,"/",N]})}),i.jsx("td",{className:"px-4 py-2 text-sm text-gray-700 dark:text-gray-300",children:Da(T)})]},d.run_id)})})]})})]}),i.jsxs("section",{children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h2",{className:"text-lg font-semibold",children:"Servers"}),i.jsx(vt,{to:"/playground",className:"text-sm font-medium text-indigo-600 hover:text-indigo-500 dark:text-indigo-400",children:"Open Playground"})]}),g.servers.length===0?i.jsxs("p",{className:"mt-3 text-sm text-gray-500 dark:text-gray-400",children:["No servers configured. Add servers to"," ",i.jsx("code",{className:"rounded bg-gray-100 px-1 py-0.5 text-xs dark:bg-gray-800",children:"hdx.toml"})," ","to see them here."]}):i.jsx("div",{className:"mt-3 grid grid-cols-1 gap-3 sm:grid-cols-2 lg:grid-cols-3",children:g.servers.map(d=>i.jsxs("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx("span",{className:`h-2.5 w-2.5 rounded-full ${d.status==="connected"?"bg-emerald-500":d.status==="error"?"bg-red-500":"bg-gray-400"}`}),i.jsx("span",{className:"font-medium",children:d.name})]}),i.jsxs("p",{className:"mt-1 text-sm text-gray-500",children:[d.tool_count," tools · ",d.transport]})]},d.name))})]}),i.jsxs("section",{children:[i.jsx("h2",{className:"text-lg font-semibold",children:"Quick Links"}),i.jsxs("div",{className:"mt-3 grid grid-cols-1 gap-3 sm:grid-cols-2 lg:grid-cols-4",children:[i.jsx(ti,{to:"/eval",title:"Eval Dashboard",description:"Browse eval runs, trends, regressions"}),i.jsx(ti,{to:"/playground",title:"Tool Playground",description:"Test tools interactively"}),i.jsx(ti,{to:"/analytics",title:"Analytics",description:"Invocation counts, latency, cost"}),i.jsx(ti,{to:"/compliance",title:"Compliance",description:"Protocol validation results"})]})]})]})}function Ds({label:f,value:m}){return i.jsxs("div",{className:"rounded-lg border border-gray-200 bg-white p-5 dark:border-gray-800 dark:bg-gray-900",children:[i.jsx("p",{className:"text-sm font-medium text-gray-500 dark:text-gray-400",children:f}),i.jsx("p",{className:"mt-1 text-3xl font-bold tracking-tight",children:m})]})}function ti({to:f,title:m,description:g}){return i.jsxs(vt,{to:f,className:"group rounded-lg border border-gray-200 p-4 transition-colors hover:border-indigo-300 hover:bg-indigo-50 dark:border-gray-800 dark:hover:border-indigo-800 dark:hover:bg-indigo-950",children:[i.jsx("h3",{className:"font-medium text-gray-900 group-hover:text-indigo-600 dark:text-gray-100 dark:group-hover:text-indigo-400",children:m}),i.jsx("p",{className:"mt-1 text-sm text-gray-500 dark:text-gray-400",children:g})]})}function _a({title:f,description:m,action:g}){return i.jsxs("div",{className:"flex flex-col items-center justify-center rounded-lg border-2 border-dashed border-gray-300 p-12 text-center dark:border-gray-700",children:[i.jsx("h3",{className:"text-lg font-medium text-gray-900 dark:text-gray-100",children:f}),i.jsx("p",{className:"mt-1 text-sm text-gray-500 dark:text-gray-400",children:m}),g&&i.jsx("button",{onClick:g.onClick,className:"mt-4 rounded-md bg-indigo-600 px-4 py-2 text-sm font-medium text-white hover:bg-indigo-500",children:g.label})]})}function Ih(){const{data:f,loading:m,error:g}=Ll("/agents");if(m)return i.jsx(pe,{message:"Loading agents..."});if(g)return i.jsxs("div",{children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Agents"}),i.jsx("div",{className:"mt-6",children:i.jsx(_a,{title:"Failed to load agents",description:g.message||"Could not connect to the dashboard API."})})]});const d=(f==null?void 0:f.agents)??[];return d.length===0?i.jsxs("div",{children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Agents"}),i.jsx("div",{className:"mt-6",children:i.jsx(_a,{title:"No agents yet",description:"Run hdx agent create to scaffold your first agent."})})]}):i.jsxs("div",{className:"space-y-8",children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Agents"}),i.jsx("div",{className:"grid grid-cols-1 gap-3 sm:grid-cols-2 lg:grid-cols-3",children:d.map(N=>i.jsxs(vt,{to:`/agents/${N.name}`,className:"group rounded-lg border border-gray-200 p-4 transition-colors hover:border-indigo-300 hover:bg-indigo-50/50 dark:border-gray-800 dark:hover:border-indigo-800 dark:hover:bg-indigo-950/30",children:[i.jsxs("div",{className:"flex items-start justify-between",children:[i.jsx("h3",{className:"font-semibold text-gray-900 group-hover:text-indigo-600 dark:text-gray-100 dark:group-hover:text-indigo-400",children:N.name}),i.jsx(At,{variant:"neutral",children:N.version})]}),N.description&&i.jsx("p",{className:"mt-1 line-clamp-2 text-sm text-gray-500 dark:text-gray-400",children:N.description}),i.jsxs("div",{className:"mt-3 flex items-center gap-3 text-sm text-gray-500 dark:text-gray-400",children:[i.jsxs("span",{children:[N.model.provider,"/",N.model.model]}),i.jsx("span",{children:"·"}),i.jsxs("span",{children:[N.server_count," server",N.server_count!==1?"s":""]})]}),i.jsx("div",{className:"mt-3",children:N.last_eval?i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx(Ph,{rate:N.last_eval.pass_rate}),i.jsx(At,{variant:"neutral",children:N.last_eval.suite_name})]}):i.jsx("p",{className:"text-xs text-gray-400 dark:text-gray-500",children:"No evals yet"})})]},N.name))})]})}function Ph({rate:f}){const m=Math.round(f*100),g=m===100?"bg-emerald-500":m>=80?"bg-amber-500":"bg-red-500";return i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx("div",{className:"h-2 w-16 overflow-hidden rounded-full bg-gray-200 dark:bg-gray-700",children:i.jsx("div",{className:`h-full ${g}`,style:{width:`${m}%`}})}),i.jsx("span",{className:"text-xs text-gray-500",children:Da(f)})]})}function lg(){const{name:f}=Z0(),{data:m,loading:g,error:d}=Ll(f?`/agents/${f}`:null),{data:N,loading:T}=Ll(f?`/agents/${f}/evals/runs?limit=10`:null),[E,C]=L.useState(!1);if(g||T)return i.jsx(pe,{message:"Loading agent details..."});if(!m)return i.jsxs("div",{className:"py-12 text-center text-gray-500",children:[d?`Error: ${d.message}`:"Agent not found."," ",i.jsx(vt,{to:"/agents",className:"text-indigo-600 hover:underline",children:"Back to Agents"})]});const M=(N==null?void 0:N.runs)??[],Z=m.system_prompt_preview.length>500&&!E?m.system_prompt_preview.slice(0,500)+"...":m.system_prompt_preview;return i.jsxs("div",{className:"space-y-8",children:[i.jsxs("nav",{className:"text-sm",children:[i.jsx(vt,{to:"/agents",className:"text-indigo-600 hover:underline dark:text-indigo-400",children:"Agents"}),i.jsx("span",{className:"mx-2 text-gray-400",children:"/"}),i.jsx("span",{className:"text-gray-500",children:m.name})]}),i.jsxs("div",{className:"rounded-lg border border-gray-200 p-6 dark:border-gray-800",children:[i.jsxs("div",{className:"flex items-start justify-between",children:[i.jsxs("div",{children:[i.jsx("h1",{className:"text-xl font-bold",children:m.name}),m.description&&i.jsx("p",{className:"mt-1 text-sm text-gray-500 dark:text-gray-400",children:m.description})]}),i.jsx(At,{variant:"neutral",children:m.version})]}),i.jsxs("div",{className:"mt-4 grid grid-cols-2 gap-4 sm:grid-cols-4",children:[i.jsx(ei,{label:"Total Eval Runs",value:String(m.stats.total_eval_runs)}),i.jsx(ei,{label:"Avg Pass Rate",value:Da(m.stats.avg_pass_rate)}),i.jsx(ei,{label:"Total Cost",value:ui(m.stats.total_cost_usd)}),i.jsx(ei,{label:"Avg Latency",value:ii(m.stats.avg_latency_ms)})]})]}),i.jsxs("div",{className:"grid grid-cols-1 gap-6 lg:grid-cols-2",children:[i.jsxs("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsx("h2",{className:"mb-3 text-sm font-semibold uppercase tracking-wider text-gray-500",children:"Model"}),i.jsxs("dl",{className:"space-y-2",children:[i.jsx(kt,{label:"Provider",value:m.model.provider}),i.jsx(kt,{label:"Model",value:m.model.model}),i.jsx(kt,{label:"Max Tokens",value:String(m.model.max_tokens)}),i.jsx(kt,{label:"Temperature",value:String(m.model.temperature)})]})]}),i.jsxs("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsx("h2",{className:"mb-3 text-sm font-semibold uppercase tracking-wider text-gray-500",children:"Settings"}),i.jsxs("dl",{className:"space-y-2",children:[i.jsx(kt,{label:"Max Tool Calls",value:String(m.settings.max_tool_calls)}),i.jsx(kt,{label:"Timeout",value:m.settings.tool_call_timeout}),i.jsx(kt,{label:"Retry on Error",value:m.settings.retry_on_error?"Yes":"No"}),i.jsx(kt,{label:"Max Retries",value:String(m.settings.max_retries)}),i.jsx(kt,{label:"Tool Namespacing",value:m.settings.tool_namespacing})]})]})]}),i.jsxs("div",{children:[i.jsxs("h2",{className:"mb-4 text-lg font-semibold",children:["Servers (",m.servers.length,")"]}),i.jsx("div",{className:"space-y-3",children:m.servers.map(D=>i.jsxs("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx("span",{className:"font-medium",children:D.name}),i.jsx(At,{variant:"info",children:D.type})]}),i.jsx("p",{className:"mt-1 font-mono text-sm text-gray-500 dark:text-gray-400",children:D.path??D.url??D.command??"—"}),D.tool_filter&&D.tool_filter.mode!=="none"&&i.jsxs("div",{className:"mt-2 flex items-center gap-1.5",children:[i.jsxs("span",{className:"text-xs text-gray-500",children:["Tool filter (",D.tool_filter.mode,"):"]}),i.jsx("div",{className:"flex flex-wrap gap-1",children:D.tool_filter.tools.map(j=>i.jsx("span",{className:"rounded bg-gray-100 px-1.5 py-0.5 text-xs dark:bg-gray-800",children:j},j))})]}),D.env_vars.length>0&&i.jsxs("div",{className:"mt-2 flex items-center gap-1.5",children:[i.jsx("span",{className:"text-xs text-gray-500",children:"Env vars:"}),i.jsx("div",{className:"flex flex-wrap gap-1",children:D.env_vars.map(j=>i.jsx("span",{className:"rounded bg-gray-100 px-1.5 py-0.5 font-mono text-xs dark:bg-gray-800",children:j},j))})]})]},D.name))})]}),m.system_prompt_preview&&i.jsxs("div",{children:[i.jsx("h2",{className:"mb-4 text-lg font-semibold",children:"System Prompt"}),i.jsxs("div",{className:"rounded-lg border border-gray-200 bg-gray-50 p-4 dark:border-gray-800 dark:bg-gray-900",children:[i.jsx("pre",{className:"whitespace-pre-wrap font-mono text-sm text-gray-700 dark:text-gray-300",children:Z}),m.system_prompt_preview.length>500&&i.jsx("button",{onClick:()=>C(D=>!D),className:"mt-2 text-sm font-medium text-indigo-600 hover:text-indigo-500 dark:text-indigo-400",children:E?"Show less":"Show more"})]})]}),i.jsxs("div",{children:[i.jsxs("h2",{className:"mb-4 text-lg font-semibold",children:["Recent Eval Runs (",(N==null?void 0:N.total)??0,")"]}),M.length===0?i.jsxs("p",{className:"text-sm text-gray-500 dark:text-gray-400",children:["No eval runs yet. Run"," ",i.jsx("code",{className:"rounded bg-gray-100 px-1 py-0.5 text-xs dark:bg-gray-800",children:"hdx agent eval"})," ","to get started."]}):i.jsx("div",{className:"overflow-hidden rounded-lg border border-gray-200 dark:border-gray-800",children:i.jsxs("table",{className:"min-w-full divide-y divide-gray-200 dark:divide-gray-800",children:[i.jsx("thead",{className:"bg-gray-50 dark:bg-gray-900",children:i.jsxs("tr",{children:[i.jsx(Ge,{children:"Suite"}),i.jsx(Ge,{children:"Date"}),i.jsx(Ge,{children:"Cases"}),i.jsx(Ge,{children:"Result"}),i.jsx(Ge,{children:"Pass Rate"}),i.jsx(Ge,{children:"Cost"}),i.jsx(Ge,{children:"Tokens"})]})}),i.jsx("tbody",{className:"divide-y divide-gray-200 dark:divide-gray-800",children:M.map(D=>{const j=D.passed+D.failed,R=j>0?D.passed/j:0;return i.jsxs("tr",{className:"hover:bg-gray-50 dark:hover:bg-gray-900/50",children:[i.jsx("td",{className:"px-4 py-3",children:i.jsx("span",{className:"rounded bg-gray-100 px-1.5 py-0.5 text-xs dark:bg-gray-800",children:D.suite_name})}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:_n(D.started_at)}),i.jsx("td",{className:"px-4 py-3 text-sm",children:j}),i.jsx("td",{className:"px-4 py-3",children:i.jsxs(At,{variant:D.failed===0?"pass":"fail",children:[D.passed," / ",j]})}),i.jsx("td",{className:"px-4 py-3 text-sm",children:i.jsx(tg,{rate:R})}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:ui(D.total_cost_usd??0)}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:(D.total_tokens??0).toLocaleString()})]},D.id)})})]})})]})]})}function ei({label:f,value:m}){return i.jsxs("div",{children:[i.jsx("p",{className:"text-xs font-medium uppercase text-gray-500",children:f}),i.jsx("p",{className:"mt-0.5 text-lg font-semibold",children:m})]})}function Ge({children:f}){return i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase tracking-wider text-gray-500",children:f})}function kt({label:f,value:m}){return i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("dt",{className:"text-sm text-gray-500 dark:text-gray-400",children:f}),i.jsx("dd",{className:"text-sm font-medium text-gray-900 dark:text-gray-100",children:m})]})}function tg({rate:f}){const m=Math.round(f*100),g=m===100?"bg-emerald-500":m>=80?"bg-amber-500":"bg-red-500";return i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx("div",{className:"h-2 w-16 overflow-hidden rounded-full bg-gray-200 dark:bg-gray-700",children:i.jsx("div",{className:`h-full ${g}`,style:{width:`${m}%`}})}),i.jsx("span",{className:"text-xs text-gray-500",children:Da(f)})]})}function eg({runs:f}){const[m,g]=L.useState("started_at"),[d,N]=L.useState("desc"),[T,E]=L.useState(""),M=[...T?f.filter(j=>j.suites.some(R=>R.toLowerCase().includes(T.toLowerCase()))):f].sort((j,R)=>{const Y=j[m]??0,G=R[m]??0,V=Y<G?-1:Y>G?1:0;return d==="asc"?V:-V});function Z(j){m===j?N(R=>R==="asc"?"desc":"asc"):(g(j),N("desc"))}const D=[...new Set(f.flatMap(j=>j.suites))];return i.jsxs("div",{children:[D.length>1&&i.jsx("div",{className:"mb-4",children:i.jsxs("select",{value:T,onChange:j=>E(j.target.value),className:"rounded-md border border-gray-300 bg-white px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800",children:[i.jsx("option",{value:"",children:"All suites"}),D.map(j=>i.jsx("option",{value:j,children:j},j))]})}),i.jsx("div",{className:"overflow-hidden rounded-lg border border-gray-200 dark:border-gray-800",children:i.jsxs("table",{className:"min-w-full divide-y divide-gray-200 dark:divide-gray-800",children:[i.jsx("thead",{className:"bg-gray-50 dark:bg-gray-900",children:i.jsxs("tr",{children:[i.jsx(ai,{children:"Run"}),i.jsx(ai,{children:"Suites"}),i.jsx(L0,{active:m==="started_at",dir:d,onClick:()=>Z("started_at"),children:"Date"}),i.jsx(L0,{active:m==="total_cases",dir:d,onClick:()=>Z("total_cases"),children:"Cases"}),i.jsx(ai,{children:"Result"}),i.jsx(ai,{children:"Pass Rate"})]})}),i.jsx("tbody",{className:"divide-y divide-gray-200 dark:divide-gray-800",children:M.map(j=>{const R=j.passed+j.failed,Y=R>0?j.passed/R:0;return i.jsxs("tr",{className:"hover:bg-gray-50 dark:hover:bg-gray-900/50",children:[i.jsxs("td",{className:"px-4 py-3",children:[j.source==="agent"?i.jsx("span",{className:"font-mono text-sm font-medium text-gray-500",children:j.run_id.slice(0,8)}):i.jsx(vt,{to:`/eval/${j.run_id}`,className:"font-mono text-sm font-medium text-indigo-600 hover:underline dark:text-indigo-400",children:j.run_id.slice(0,8)}),j.source==="agent"&&j.agent_name&&i.jsx(vt,{to:`/agents/${j.agent_name}`,className:"ml-2 text-xs text-indigo-500 hover:underline dark:text-indigo-400",children:j.agent_name})]}),i.jsx("td",{className:"px-4 py-3",children:i.jsx("div",{className:"flex flex-wrap gap-1",children:j.suites.map(G=>i.jsx("span",{className:"rounded bg-gray-100 px-1.5 py-0.5 text-xs dark:bg-gray-800",children:G},G))})}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:_n(j.started_at)}),i.jsx("td",{className:"px-4 py-3 text-sm",children:R}),i.jsx("td",{className:"px-4 py-3",children:i.jsxs(At,{variant:j.failed===0?"pass":"fail",children:[j.passed," / ",R]})}),i.jsx("td",{className:"px-4 py-3 text-sm",children:i.jsx(ag,{rate:Y})})]},j.run_id)})})]})})]})}function ai({children:f}){return i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase tracking-wider text-gray-500",children:f})}function L0({children:f,active:m,dir:g,onClick:d}){return i.jsx("th",{className:"cursor-pointer select-none px-4 py-2 text-left text-xs font-medium uppercase tracking-wider text-gray-500 hover:text-gray-700 dark:hover:text-gray-300",onClick:d,children:i.jsxs("span",{className:"flex items-center gap-1",children:[f,m&&i.jsx("span",{children:g==="asc"?"↑":"↓"})]})})}function ag({rate:f}){const m=Math.round(f*100),g=m===100?"bg-emerald-500":m>=80?"bg-amber-500":"bg-red-500";return i.jsxs("div",{className:"flex items-center gap-2",children:[i.jsx("div",{className:"h-2 w-16 overflow-hidden rounded-full bg-gray-200 dark:bg-gray-700",children:i.jsx("div",{className:`h-full ${g}`,style:{width:`${m}%`}})}),i.jsx("span",{className:"text-xs text-gray-500",children:Da(f)})]})}const ng=[{label:"7d",days:7},{label:"30d",days:30},{label:"90d",days:90},{label:"All",days:0}];function ug({trends:f}){const[m,g]=L.useState(30),d=m===0?f:f.filter(T=>{const E=new Date(T.date),C=new Date;return C.setDate(C.getDate()-m),E>=C}),N=d.filter((T,E)=>E===0?!1:d[E-1].pass_rate-T.pass_rate>.1);return i.jsxs("div",{children:[i.jsxs("div",{className:"mb-3 flex items-center justify-between",children:[i.jsx("h3",{className:"text-sm font-medium text-gray-700 dark:text-gray-300",children:"Pass Rate Over Time"}),i.jsx("div",{className:"flex gap-1",children:ng.map(T=>i.jsx("button",{onClick:()=>g(T.days),className:`rounded px-2 py-1 text-xs font-medium ${m===T.days?"bg-indigo-100 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"text-gray-500 hover:bg-gray-100 dark:hover:bg-gray-800"}`,children:T.label},T.label))})]}),i.jsx(Dn,{width:"100%",height:280,children:i.jsxs(Us,{data:d,children:[i.jsx(On,{strokeDasharray:"3 3",opacity:.3}),i.jsx(Un,{dataKey:"date",tick:{fontSize:11},tickFormatter:T=>new Date(T).toLocaleDateString("en-US",{month:"short",day:"numeric"})}),i.jsx(Cn,{domain:[0,1],tick:{fontSize:11},tickFormatter:T=>`${Math.round(T*100)}%`}),i.jsx(Hn,{formatter:T=>[`${(T*100).toFixed(1)}%`,"Pass Rate"],labelFormatter:T=>new Date(T).toLocaleDateString()}),i.jsx(En,{type:"monotone",dataKey:"pass_rate",stroke:"#6366f1",strokeWidth:2,dot:{r:3},activeDot:{r:5}}),N.map(T=>i.jsx(zh,{x:T.date,y:T.pass_rate,r:6,fill:"#ef4444",stroke:"#fff",strokeWidth:2},T.date))]})})]})}function ig({trends:f}){const m=new Map;for(const d of f){const N=m.get(d.date)??0;m.set(d.date,N+d.avg_latency_ms)}const g=[...m.entries()].map(([d,N])=>({date:d,latency:N}));return g.length===0?i.jsx("div",{className:"flex h-64 items-center justify-center text-sm text-gray-400",children:"No latency data available"}):i.jsxs("div",{children:[i.jsx("h3",{className:"mb-3 text-sm font-medium text-gray-700 dark:text-gray-300",children:"Average Latency Over Time"}),i.jsx(Dn,{width:"100%",height:280,children:i.jsxs(Ah,{data:g,children:[i.jsx(On,{strokeDasharray:"3 3",opacity:.3}),i.jsx(Un,{dataKey:"date",tick:{fontSize:11},tickFormatter:d=>new Date(d).toLocaleDateString("en-US",{month:"short",day:"numeric"})}),i.jsx(Cn,{tick:{fontSize:11},tickFormatter:d=>`${Math.round(d)}ms`}),i.jsx(Hn,{formatter:d=>[`${d.toFixed(1)}ms`,"Avg Latency"],labelFormatter:d=>new Date(d).toLocaleDateString()}),i.jsx(Th,{type:"monotone",dataKey:"latency",stroke:"#8b5cf6",fill:"#8b5cf6",fillOpacity:.15,strokeWidth:2})]})})]})}function cg(){const[f,m]=L.useState("all"),{data:g,loading:d}=Ll(`/eval/runs?limit=50&source=${f}`),{data:N,loading:T}=Ll("/eval/trends?days=90");if(d||T)return i.jsx(pe,{message:"Loading eval data..."});const E=(g==null?void 0:g.runs)??[],C=(N==null?void 0:N.trends)??[];return E.length===0?i.jsxs("div",{children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Eval Dashboard"}),i.jsx("div",{className:"mt-6",children:i.jsx(_a,{title:"No eval runs yet",description:"Run hdx eval to generate evaluation data, then view results here."})})]}):i.jsxs("div",{className:"space-y-8",children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Eval Dashboard"}),C.length>0&&i.jsxs("div",{className:"grid grid-cols-1 gap-6 lg:grid-cols-2",children:[i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(ug,{trends:C})}),i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(ig,{trends:C})})]}),i.jsxs("div",{children:[i.jsxs("div",{className:"mb-4 flex items-center justify-between",children:[i.jsxs("h2",{className:"text-lg font-semibold",children:["All Runs (",(g==null?void 0:g.total)??0,")"]}),i.jsx("div",{className:"flex gap-1 rounded-lg bg-gray-100 p-1 dark:bg-gray-800",children:["all","server","agent"].map(M=>i.jsx("button",{onClick:()=>m(M),className:`rounded-md px-3 py-1 text-sm font-medium transition-colors ${f===M?"bg-white text-gray-900 shadow-sm dark:bg-gray-700 dark:text-gray-100":"text-gray-500 hover:text-gray-700 dark:text-gray-400 dark:hover:text-gray-300"}`,children:M==="all"?"All":M==="server"?"Servers":"Agents"},M))})]}),i.jsx(eg,{runs:E})]})]})}function sg({cases:f}){const[m,g]=L.useState(null);return i.jsx("div",{className:"overflow-hidden rounded-lg border border-gray-200 dark:border-gray-800",children:i.jsxs("table",{className:"min-w-full divide-y divide-gray-200 dark:divide-gray-800",children:[i.jsx("thead",{className:"bg-gray-50 dark:bg-gray-900",children:i.jsxs("tr",{children:[i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Status"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Suite"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Eval"}),i.jsx("th",{className:"px-4 py-2 text-left text-xs font-medium uppercase text-gray-500",children:"Latency"})]})}),i.jsx("tbody",{className:"divide-y divide-gray-200 dark:divide-gray-800",children:f.map(d=>i.jsxs(i.Fragment,{children:[i.jsxs("tr",{className:"cursor-pointer hover:bg-gray-50 dark:hover:bg-gray-900/50",onClick:()=>g(m===d.id?null:d.id),children:[i.jsx("td",{className:"px-4 py-3",children:i.jsx(At,{variant:d.passed?"pass":"fail",children:d.passed?"PASS":"FAIL"})}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:d.suite_name}),i.jsx("td",{className:"px-4 py-3 text-sm font-medium",children:d.eval_name}),i.jsx("td",{className:"px-4 py-3 text-sm text-gray-500",children:ii(d.latency_ms)})]},d.id),m===d.id&&i.jsx("tr",{children:i.jsx("td",{colSpan:4,className:"bg-gray-50 px-4 py-3 dark:bg-gray-900/50",children:i.jsxs("div",{className:"space-y-2",children:[i.jsx("h4",{className:"text-xs font-medium uppercase text-gray-500",children:"Assertions"}),d.assertion_details.map((N,T)=>i.jsxs("div",{className:"flex items-start gap-2 text-sm",children:[i.jsx("span",{className:N.passed?"text-emerald-600":"text-red-600",children:N.passed?"✓":"✗"}),i.jsxs("div",{children:[i.jsx("span",{className:"font-medium",children:N.type}),N.message&&i.jsx("span",{className:"ml-2 text-gray-500",children:N.message})]})]},T))]})})},`${d.id}-detail`)]}))})]})})}function fg(){const{runId:f}=Z0(),{data:m,loading:g}=Ll(f?`/eval/runs/${f}`:null),{data:d,loading:N}=Ll(f?`/eval/runs/${f}/cases`:null);if(g||N)return i.jsx(pe,{message:"Loading run details..."});if(!m)return i.jsxs("div",{className:"text-center py-12 text-gray-500",children:["Run not found."," ",i.jsx(vt,{to:"/eval",className:"text-indigo-600 hover:underline",children:"Back to Eval Dashboard"})]});const T=m.passed+m.failed,E=T>0?m.passed/T:0,C=(d==null?void 0:d.cases)??[];return i.jsxs("div",{className:"space-y-6",children:[i.jsxs("nav",{className:"text-sm",children:[i.jsx(vt,{to:"/eval",className:"text-indigo-600 hover:underline dark:text-indigo-400",children:"Eval Dashboard"}),i.jsx("span",{className:"mx-2 text-gray-400",children:"/"}),i.jsx("span",{className:"text-gray-500",children:m.run_id.slice(0,8)})]}),i.jsxs("div",{className:"rounded-lg border border-gray-200 p-6 dark:border-gray-800",children:[i.jsxs("div",{className:"flex items-start justify-between",children:[i.jsxs("div",{children:[i.jsxs("h1",{className:"font-mono text-xl font-bold",children:["Run ",m.run_id.slice(0,8)]}),i.jsxs("p",{className:"mt-1 text-sm text-gray-500",children:[_n(m.started_at),m.finished_at&&` — ${_n(m.finished_at)}`]})]}),i.jsx(At,{variant:m.failed===0?"pass":"fail",children:m.failed===0?"ALL PASSED":`${m.failed} FAILED`})]}),i.jsxs("div",{className:"mt-4 grid grid-cols-2 gap-4 sm:grid-cols-4",children:[i.jsx(Ma,{label:"Total Cases",value:String(T)}),i.jsx(Ma,{label:"Passed",value:String(m.passed)}),i.jsx(Ma,{label:"Failed",value:String(m.failed)}),i.jsx(Ma,{label:"Pass Rate",value:Da(E)}),i.jsx(Ma,{label:"Avg Latency",value:ii(m.avg_latency_ms)}),i.jsx(Ma,{label:"Suites",value:m.suites.join(", ")||"—"})]})]}),i.jsxs("div",{children:[i.jsxs("h2",{className:"mb-4 text-lg font-semibold",children:["Cases (",C.length,")"]}),i.jsx(sg,{cases:C})]})]})}function Ma({label:f,value:m}){return i.jsxs("div",{children:[i.jsx("p",{className:"text-xs font-medium uppercase text-gray-500",children:f}),i.jsx("p",{className:"mt-0.5 text-lg font-semibold",children:m})]})}function dg({servers:f,tools:m,selectedServer:g,selectedTool:d,onSelectServer:N,onSelectTool:T,loading:E}){const[C,M]=L.useState(""),Z=g?m.get(g)??[]:[],D=C?Z.filter(j=>j.name.toLowerCase().includes(C.toLowerCase())||j.description.toLowerCase().includes(C.toLowerCase())):Z;return i.jsxs("div",{className:"space-y-4",children:[i.jsxs("div",{children:[i.jsx("label",{className:"mb-1 block text-xs font-medium uppercase text-gray-500",children:"Server"}),i.jsxs("div",{className:"space-y-1",children:[f.map(j=>i.jsxs("button",{onClick:()=>N(j.name),className:`flex w-full items-center gap-2 rounded-md px-3 py-2 text-left text-sm transition-colors ${g===j.name?"bg-indigo-50 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"hover:bg-gray-100 dark:hover:bg-gray-800"}`,children:[i.jsx("span",{className:`h-2 w-2 rounded-full ${j.status==="connected"?"bg-emerald-500":"bg-gray-400"}`}),i.jsx("span",{className:"font-medium",children:j.name}),i.jsxs("span",{className:"ml-auto text-xs text-gray-400",children:[j.tool_count," tools"]})]},j.name)),f.length===0&&i.jsx("p",{className:"px-3 py-2 text-sm text-gray-400",children:"No servers configured"})]})]}),g&&i.jsxs("div",{children:[i.jsx("label",{className:"mb-1 block text-xs font-medium uppercase text-gray-500",children:"Tool"}),Z.length>3&&i.jsx("input",{type:"text",placeholder:"Search tools...",value:C,onChange:j=>M(j.target.value),className:"mb-2 w-full rounded-md border border-gray-300 bg-white px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800"}),i.jsx("div",{className:"max-h-64 space-y-1 overflow-y-auto",children:E?i.jsx("p",{className:"px-3 py-2 text-sm text-gray-400",children:"Loading tools..."}):D.map(j=>i.jsxs("button",{onClick:()=>T(j.name),className:`w-full rounded-md px-3 py-2 text-left text-sm transition-colors ${d===j.name?"bg-indigo-50 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"hover:bg-gray-100 dark:hover:bg-gray-800"}`,children:[i.jsx("div",{className:"font-medium",children:j.name}),j.description&&i.jsx("div",{className:"mt-0.5 text-xs text-gray-500 line-clamp-2",children:j.description})]},j.name))})]})]})}function rg({schema:f,onSubmit:m,loading:g}){const d=f.properties??{},N=f.required??[],T=Object.entries(d),[E,C]=L.useState({}),[M,Z]=L.useState(!1),[D,j]=L.useState("{}");function R(Y){if(Y.preventDefault(),M){try{m(JSON.parse(D))}catch{}return}const G={};for(const[V,mt]of T){const Tl=E[V];if(!(Tl===void 0||Tl===""))switch(mt.type){case"number":case"integer":G[V]=Number(Tl);break;case"boolean":G[V]=Tl==="true";break;case"object":case"array":try{G[V]=JSON.parse(Tl)}catch{G[V]=Tl}break;default:G[V]=Tl}}m(G)}return i.jsxs("form",{onSubmit:R,className:"space-y-4",children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h3",{className:"text-sm font-medium text-gray-700 dark:text-gray-300",children:"Arguments"}),i.jsx("button",{type:"button",onClick:()=>Z(!M),className:"text-xs text-indigo-600 hover:underline dark:text-indigo-400",children:M?"Use form":"Use JSON"})]}),M?i.jsx("textarea",{value:D,onChange:Y=>j(Y.target.value),rows:8,className:"w-full rounded-md border border-gray-300 bg-white px-3 py-2 font-mono text-sm dark:border-gray-700 dark:bg-gray-800",placeholder:'{"key": "value"}'}):T.length===0?i.jsx("p",{className:"text-sm text-gray-400",children:"No arguments required"}):T.map(([Y,G])=>i.jsxs("div",{children:[i.jsxs("label",{className:"mb-1 flex items-center gap-1 text-sm font-medium",children:[Y,N.includes(Y)&&i.jsx("span",{className:"text-red-500",children:"*"})]}),G.description&&i.jsx("p",{className:"mb-1 text-xs text-gray-500",children:G.description}),G.enum?i.jsxs("select",{value:E[Y]??"",onChange:V=>C({...E,[Y]:V.target.value}),className:"w-full rounded-md border border-gray-300 bg-white px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800",children:[i.jsx("option",{value:"",children:"Select..."}),G.enum.map(V=>i.jsx("option",{value:V,children:V},V))]}):G.type==="boolean"?i.jsxs("select",{value:E[Y]??"",onChange:V=>C({...E,[Y]:V.target.value}),className:"w-full rounded-md border border-gray-300 bg-white px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800",children:[i.jsx("option",{value:"",children:"Select..."}),i.jsx("option",{value:"true",children:"true"}),i.jsx("option",{value:"false",children:"false"})]}):G.type==="object"||G.type==="array"?i.jsx("textarea",{value:E[Y]??"",onChange:V=>C({...E,[Y]:V.target.value}),rows:3,className:"w-full rounded-md border border-gray-300 bg-white px-3 py-2 font-mono text-sm dark:border-gray-700 dark:bg-gray-800",placeholder:G.type==="array"?"[]":"{}"}):i.jsx("input",{type:G.type==="number"||G.type==="integer"?"number":"text",value:E[Y]??"",onChange:V=>C({...E,[Y]:V.target.value}),className:"w-full rounded-md border border-gray-300 bg-white px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800",placeholder:String(G.default??"")})]},Y)),i.jsx("button",{type:"submit",disabled:g,className:"w-full rounded-md bg-indigo-600 px-4 py-2 text-sm font-medium text-white hover:bg-indigo-500 disabled:opacity-50",children:g?"Calling...":"Call Tool"})]})}function og({response:f,onSaveFixture:m}){const[g,d]=L.useState("tree");return i.jsxs("div",{className:"space-y-3",children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsxs("div",{className:"flex items-center gap-3",children:[i.jsx("span",{className:`inline-flex items-center rounded-full px-2 py-0.5 text-xs font-medium ${f.is_error?"bg-red-100 text-red-700 dark:bg-red-900/30 dark:text-red-400":"bg-emerald-100 text-emerald-700 dark:bg-emerald-900/30 dark:text-emerald-400"}`,children:f.is_error?"Error":"Success"}),i.jsx("span",{className:"text-sm text-gray-500",children:ii(f.latency_ms)})]}),i.jsxs("div",{className:"flex gap-2",children:[i.jsx("button",{onClick:()=>d(g==="tree"?"raw":"tree"),className:"text-xs text-gray-500 hover:text-gray-700 dark:hover:text-gray-300",children:g==="tree"?"Raw":"Tree"}),i.jsx("button",{onClick:()=>navigator.clipboard.writeText(JSON.stringify(f.content,null,2)),className:"text-xs text-gray-500 hover:text-gray-700 dark:hover:text-gray-300",children:"Copy"}),i.jsx("button",{onClick:m,className:"text-xs text-indigo-600 hover:underline dark:text-indigo-400",children:"Save as Fixture"})]})]}),i.jsx("div",{className:`overflow-auto rounded-md border p-3 font-mono text-sm ${f.is_error?"border-red-200 bg-red-50 dark:border-red-900 dark:bg-red-950":"border-gray-200 bg-gray-50 dark:border-gray-800 dark:bg-gray-900"}`,children:g==="raw"?i.jsx("pre",{className:"whitespace-pre-wrap",children:JSON.stringify(f.content,null,2)}):i.jsx(Os,{data:f.content})})]})}function Os({data:f,depth:m=0}){if(f===null)return i.jsx("span",{className:"text-gray-400",children:"null"});if(typeof f=="boolean")return i.jsx("span",{className:"text-amber-600",children:String(f)});if(typeof f=="number")return i.jsx("span",{className:"text-blue-600",children:f});if(typeof f=="string")return f.length>200?i.jsxs("span",{className:"text-emerald-700 dark:text-emerald-400",children:['"',f.slice(0,200),'..."']}):i.jsxs("span",{className:"text-emerald-700 dark:text-emerald-400",children:['"',f,'"']});if(Array.isArray(f))return f.length===0?i.jsx("span",{children:"[]"}):i.jsxs("div",{style:{paddingLeft:m>0?16:0},children:["[",f.map((g,d)=>i.jsxs("div",{className:"pl-4",children:[i.jsx(Os,{data:g,depth:m+1}),d<f.length-1&&","]},d)),"]"]});if(typeof f=="object"){const g=Object.entries(f);return g.length===0?i.jsx("span",{children:"{}"}):i.jsxs("div",{style:{paddingLeft:m>0?16:0},children:["{",g.map(([d,N],T)=>i.jsxs("div",{className:"pl-4",children:[i.jsxs("span",{className:"text-purple-600 dark:text-purple-400",children:['"',d,'"']}),": ",i.jsx(Os,{data:N,depth:m+1}),T<g.length-1&&","]},d)),"}"]})}return i.jsx("span",{children:String(f)})}function mg({toolName:f,arguments:m,response:g,open:d,onClose:N}){const[T,E]=L.useState(`test ${f}`);if(!d)return null;const C=hg(T,f,m,g);function M(){navigator.clipboard.writeText(C)}function Z(){const D=new Blob([C],{type:"text/yaml"}),j=URL.createObjectURL(D),R=document.createElement("a");R.href=j,R.download=`${f.replace(/[^a-z0-9]/gi,"_")}_fixture.yaml`,R.click(),URL.revokeObjectURL(j)}return i.jsx("div",{className:"fixed inset-0 z-50 flex items-center justify-center bg-black/50",children:i.jsxs("div",{className:"mx-4 w-full max-w-lg rounded-lg bg-white p-6 shadow-xl dark:bg-gray-900",children:[i.jsx("h2",{className:"text-lg font-semibold",children:"Save as Test Fixture"}),i.jsxs("div",{className:"mt-4",children:[i.jsx("label",{className:"mb-1 block text-sm font-medium",children:"Test Name"}),i.jsx("input",{type:"text",value:T,onChange:D=>E(D.target.value),className:"w-full rounded-md border border-gray-300 px-3 py-1.5 text-sm dark:border-gray-700 dark:bg-gray-800"})]}),i.jsxs("div",{className:"mt-4",children:[i.jsx("label",{className:"mb-1 block text-sm font-medium",children:"Generated YAML"}),i.jsx("pre",{className:"max-h-64 overflow-auto rounded-md border border-gray-200 bg-gray-50 p-3 font-mono text-xs dark:border-gray-800 dark:bg-gray-950",children:C})]}),i.jsxs("div",{className:"mt-4 flex justify-end gap-2",children:[i.jsx("button",{onClick:N,className:"rounded-md px-4 py-2 text-sm text-gray-500 hover:bg-gray-100 dark:hover:bg-gray-800",children:"Cancel"}),i.jsx("button",{onClick:M,className:"rounded-md border border-gray-300 px-4 py-2 text-sm font-medium hover:bg-gray-50 dark:border-gray-700 dark:hover:bg-gray-800",children:"Copy"}),i.jsx("button",{onClick:Z,className:"rounded-md bg-indigo-600 px-4 py-2 text-sm font-medium text-white hover:bg-indigo-500",children:"Download .yaml"})]})]})})}function hg(f,m,g,d){const N=Object.entries(g).map(([T,E])=>`      ${T}: ${JSON.stringify(E)}`).join(`
`);return`tests:
  - name: "${f}"
    tool: "${m}"
    input:
${N||"      {}"}
    expect:
      status: "${d.is_error?"error":"success"}"
`}function gg(){const[f,m]=L.useState(null),[g,d]=L.useState(null),[N,T]=L.useState(new Map),[E,C]=L.useState(!1),[M,Z]=L.useState(!1),[D,j]=L.useState(null),[R,Y]=L.useState({}),[G,V]=L.useState(!1),[mt,Tl]=L.useState([]),[je,Hl]=L.useState(1),{data:lt,loading:Tt}=Ll("/servers"),Zl=(lt==null?void 0:lt.servers)??[],ht=L.useCallback(async il=>{if(m(il),d(null),j(null),!N.has(il)){C(!0);try{const jl=await Mn(`/servers/${il}/tools`);T(bt=>new Map(bt).set(il,jl.tools))}catch{}finally{C(!1)}}},[N]),et=(f?N.get(f)??[]:[]).find(il=>il.name===g);async function Le(il){if(!(!f||!g)){Z(!0),Y(il);try{const jl=await Mn(`/servers/${f}/tools/${g}/call`,{method:"POST",body:JSON.stringify({arguments:il})});j(jl),Tl(bt=>[{id:je,server:f,tool:g,arguments:il,response:jl},...bt]),Hl(bt=>bt+1)}catch(jl){j({content:{error:String(jl)},is_error:!0,latency_ms:0})}finally{Z(!1)}}}return Tt?i.jsx(pe,{message:"Loading servers..."}):Zl.length===0?i.jsxs("div",{children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Tool Playground"}),i.jsx("div",{className:"mt-6",children:i.jsx(_a,{title:"No servers configured",description:"Configure MCP servers in hdx.toml, then use this playground to test tools interactively."})})]}):i.jsxs("div",{className:"space-y-6",children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Tool Playground"}),i.jsxs("div",{className:"grid grid-cols-1 gap-6 lg:grid-cols-12",children:[i.jsxs("div",{className:"lg:col-span-3",children:[i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(dg,{servers:Zl,tools:N,selectedServer:f,selectedTool:g,onSelectServer:ht,onSelectTool:d,loading:E})}),mt.length>0&&i.jsxs("div",{className:"mt-4 rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h3",{className:"text-xs font-medium uppercase text-gray-500",children:"History"}),i.jsx("button",{onClick:()=>Tl([]),className:"text-xs text-gray-400 hover:text-gray-600",children:"Clear"})]}),i.jsx("div",{className:"mt-2 max-h-48 space-y-1 overflow-y-auto",children:mt.map(il=>i.jsxs("button",{onClick:()=>{m(il.server),d(il.tool),j(il.response),Y(il.arguments)},className:"flex w-full items-center gap-2 rounded px-2 py-1 text-left text-xs hover:bg-gray-100 dark:hover:bg-gray-800",children:[i.jsx("span",{className:`h-1.5 w-1.5 rounded-full ${il.response.is_error?"bg-red-500":"bg-emerald-500"}`}),i.jsx("span",{className:"truncate font-medium",children:il.tool}),i.jsxs("span",{className:"ml-auto text-gray-400",children:[Math.round(il.response.latency_ms),"ms"]})]},il.id))})]})]}),i.jsx("div",{className:"lg:col-span-4",children:et?i.jsxs("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:[i.jsxs("div",{className:"mb-4",children:[i.jsx("h2",{className:"font-medium",children:et.name}),et.description&&i.jsx("p",{className:"mt-1 text-sm text-gray-500",children:et.description})]}),i.jsx(rg,{schema:et.input_schema,onSubmit:Le,loading:M})]}):i.jsx("div",{className:"flex h-48 items-center justify-center rounded-lg border-2 border-dashed border-gray-300 text-sm text-gray-400 dark:border-gray-700",children:"Select a tool to get started"})}),i.jsx("div",{className:"lg:col-span-5",children:D?i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(og,{response:D,onSaveFixture:()=>V(!0)})}):i.jsx("div",{className:"flex h-48 items-center justify-center rounded-lg border-2 border-dashed border-gray-300 text-sm text-gray-400 dark:border-gray-700",children:"Response will appear here"})})]}),G&&D&&g&&i.jsx(mg,{toolName:g,arguments:R,response:D,open:G,onClose:()=>V(!1)})]})}function yg({series:f}){const m=new Map,g=new Set;for(const T of f){const E=T.label??"unknown";g.add(E);const C=m.get(T.timestamp)??{};C[E]=(C[E]??0)+T.value,m.set(T.timestamp,C)}const d=[...m.entries()].map(([T,E])=>({date:T,...E})),N=["#6366f1","#8b5cf6","#a78bfa","#c4b5fd","#ddd6fe"];return i.jsxs("div",{children:[i.jsx("h3",{className:"mb-3 text-sm font-medium text-gray-700 dark:text-gray-300",children:"Tool Invocations"}),i.jsx(Dn,{width:"100%",height:280,children:i.jsxs(Eh,{data:d,children:[i.jsx(On,{strokeDasharray:"3 3",opacity:.3}),i.jsx(Un,{dataKey:"date",tick:{fontSize:11},tickFormatter:T=>new Date(T).toLocaleDateString("en-US",{month:"short",day:"numeric"})}),i.jsx(Cn,{tick:{fontSize:11}}),i.jsx(Hn,{}),i.jsx(V0,{}),[...g].slice(0,5).map((T,E)=>i.jsx(Mh,{dataKey:T,fill:N[E%N.length],stackId:"stack"},T))]})})]})}function xg({series:f}){return i.jsxs("div",{children:[i.jsx("h3",{className:"mb-3 text-sm font-medium text-gray-700 dark:text-gray-300",children:"Latency Percentiles"}),i.jsx(Dn,{width:"100%",height:280,children:i.jsxs(Us,{data:f,children:[i.jsx(On,{strokeDasharray:"3 3",opacity:.3}),i.jsx(Un,{dataKey:"timestamp",tick:{fontSize:11},tickFormatter:m=>new Date(m).toLocaleDateString("en-US",{month:"short",day:"numeric"})}),i.jsx(Cn,{tick:{fontSize:11},tickFormatter:m=>`${Math.round(m)}ms`}),i.jsx(Hn,{formatter:(m,g)=>[`${m.toFixed(1)}ms`,g]}),i.jsx(V0,{}),i.jsx(En,{type:"monotone",dataKey:"p50",stroke:"#22c55e",strokeWidth:2,dot:!1,name:"p50"}),i.jsx(En,{type:"monotone",dataKey:"p95",stroke:"#f59e0b",strokeWidth:2,dot:!1,name:"p95"}),i.jsx(En,{type:"monotone",dataKey:"p99",stroke:"#ef4444",strokeWidth:2,dot:!1,name:"p99"})]})})]})}function vg({series:f}){const m=f.map(g=>({date:g.timestamp,rate:g.value,label:g.label}));return i.jsxs("div",{children:[i.jsx("h3",{className:"mb-3 text-sm font-medium text-gray-700 dark:text-gray-300",children:"Error Rate"}),i.jsx(Dn,{width:"100%",height:280,children:i.jsxs(Us,{data:m,children:[i.jsx(On,{strokeDasharray:"3 3",opacity:.3}),i.jsx(Un,{dataKey:"date",tick:{fontSize:11},tickFormatter:g=>new Date(g).toLocaleDateString("en-US",{month:"short",day:"numeric"})}),i.jsx(Cn,{domain:[0,1],tick:{fontSize:11},tickFormatter:g=>`${Math.round(g*100)}%`}),i.jsx(Hn,{formatter:g=>[`${(g*100).toFixed(1)}%`,"Error Rate"]}),i.jsx(En,{type:"monotone",dataKey:"rate",stroke:"#ef4444",strokeWidth:2,dot:{r:3}})]})})]})}function bg({breakdown:f}){const m=f.reduce((g,d)=>g+d.cost_usd,0);return f.length===0?i.jsxs("div",{children:[i.jsx("h3",{className:"mb-3 text-sm font-medium text-gray-700 dark:text-gray-300",children:"Cost Breakdown"}),i.jsx("p",{className:"text-sm text-gray-400",children:"No cost data available yet. Cost tracking requires agent evaluations."})]}):i.jsxs("div",{children:[i.jsxs("div",{className:"mb-3 flex items-center justify-between",children:[i.jsx("h3",{className:"text-sm font-medium text-gray-700 dark:text-gray-300",children:"Cost Breakdown"}),i.jsxs("span",{className:"text-sm font-medium",children:[ui(m)," total"]})]}),i.jsx("div",{className:"space-y-2",children:f.map(g=>{const d=m>0?g.cost_usd/m*100:0;return i.jsxs("div",{className:"flex items-center gap-3",children:[i.jsx("span",{className:"w-24 truncate text-sm",children:g.label}),i.jsx("div",{className:"flex-1",children:i.jsx("div",{className:"h-2 overflow-hidden rounded-full bg-gray-200 dark:bg-gray-700",children:i.jsx("div",{className:"h-full bg-indigo-500",style:{width:`${d}%`}})})}),i.jsx("span",{className:"w-16 text-right text-sm text-gray-500",children:ui(g.cost_usd)})]},g.label)})})]})}const pg=[{label:"7d",days:7},{label:"30d",days:30},{label:"90d",days:90}];function jg(){const[f,m]=L.useState(30),{data:g,loading:d}=Ll(`/analytics/invocations?days=${f}`),{data:N,loading:T}=Ll(`/analytics/latency?days=${f}`),{data:E,loading:C}=Ll(`/analytics/errors?days=${f}`),{data:M}=Ll("/analytics/cost"),Z=d||T||C,D=((g==null?void 0:g.series.length)??0)>0||((N==null?void 0:N.series.length)??0)>0||((E==null?void 0:E.series.length)??0)>0;return i.jsxs("div",{className:"space-y-6",children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Analytics"}),i.jsx("div",{className:"flex gap-1",children:pg.map(j=>i.jsx("button",{onClick:()=>m(j.days),className:`rounded px-3 py-1 text-sm font-medium ${f===j.days?"bg-indigo-100 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"text-gray-500 hover:bg-gray-100 dark:hover:bg-gray-800"}`,children:j.label},j.label))})]}),Z?i.jsx(pe,{message:"Loading analytics..."}):D?i.jsxs("div",{className:"grid grid-cols-1 gap-6 lg:grid-cols-2",children:[i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(yg,{series:(g==null?void 0:g.series)??[]})}),i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(xg,{series:(N==null?void 0:N.series)??[]})}),i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(vg,{series:(E==null?void 0:E.series)??[]})}),i.jsx("div",{className:"rounded-lg border border-gray-200 p-4 dark:border-gray-800",children:i.jsx(bg,{breakdown:(M==null?void 0:M.breakdown)??[]})})]}):i.jsx(_a,{title:"No telemetry data yet",description:"Analytics will populate as you use hdx eval and hdx test."})]})}function Sg({score:f,passed:m,failed:g,warned:d,total:N}){const T=f>=90?"text-emerald-600 dark:text-emerald-400":f>=70?"text-amber-600 dark:text-amber-400":"text-red-600 dark:text-red-400",E=f>=90?"stroke-emerald-500":f>=70?"stroke-amber-500":"stroke-red-500",C=2*Math.PI*45,M=C-f/100*C;return i.jsxs("div",{className:"flex items-center gap-8",children:[i.jsxs("div",{className:"relative h-28 w-28",children:[i.jsxs("svg",{className:"h-28 w-28 -rotate-90",viewBox:"0 0 100 100",children:[i.jsx("circle",{cx:"50",cy:"50",r:"45",fill:"none",stroke:"currentColor",strokeWidth:"8",className:"text-gray-200 dark:text-gray-800"}),i.jsx("circle",{cx:"50",cy:"50",r:"45",fill:"none",strokeWidth:"8",strokeLinecap:"round",strokeDasharray:C,strokeDashoffset:M,className:E})]}),i.jsx("div",{className:"absolute inset-0 flex items-center justify-center",children:i.jsxs("span",{className:`text-2xl font-bold ${T}`,children:[f,"%"]})})]}),i.jsxs("div",{className:"grid grid-cols-2 gap-x-8 gap-y-2",children:[i.jsx(ni,{label:"Total Rules",value:N}),i.jsx(ni,{label:"Passed",value:m,color:"text-emerald-600"}),i.jsx(ni,{label:"Failed",value:g,color:"text-red-600"}),i.jsx(ni,{label:"Warnings",value:d,color:"text-amber-600"})]})]})}function ni({label:f,value:m,color:g}){return i.jsxs("div",{children:[i.jsx("p",{className:"text-xs text-gray-500",children:f}),i.jsx("p",{className:`text-lg font-semibold ${g??""}`,children:m})]})}function Ng({rules:f}){const[m,g]=L.useState(null),[d,N]=L.useState("all"),T=[...new Set(f.map(M=>M.category))],E=d==="all"?f:f.filter(M=>M.status===d),C=T.map(M=>({category:M,rules:E.filter(Z=>Z.category===M)}));return i.jsxs("div",{className:"space-y-4",children:[i.jsx("div",{className:"flex gap-2",children:["all","fail","warn","pass"].map(M=>i.jsxs("button",{onClick:()=>N(M),className:`rounded px-3 py-1 text-sm font-medium capitalize ${d===M?"bg-indigo-100 text-indigo-700 dark:bg-indigo-900/30 dark:text-indigo-400":"text-gray-500 hover:bg-gray-100 dark:hover:bg-gray-800"}`,children:[M," (",M==="all"?f.length:f.filter(Z=>Z.status===M).length,")"]},M))}),C.filter(M=>M.rules.length>0).map(({category:M,rules:Z})=>i.jsxs("div",{children:[i.jsx("h3",{className:"mb-2 text-sm font-medium uppercase tracking-wider text-gray-500",children:M}),i.jsx("div",{className:"space-y-1",children:Z.map(D=>i.jsxs("div",{children:[i.jsxs("button",{onClick:()=>g(m===D.id?null:D.id),className:"flex w-full items-center gap-3 rounded-md px-3 py-2 text-left text-sm hover:bg-gray-50 dark:hover:bg-gray-900/50",children:[i.jsx(At,{variant:D.status==="pass"?"pass":D.status==="warn"?"warn":"fail",children:D.status.toUpperCase()}),i.jsx("span",{className:"font-medium",children:D.name}),i.jsx("span",{className:"ml-auto text-xs text-gray-400",children:m===D.id?"▲":"▼"})]}),m===D.id&&i.jsxs("div",{className:"ml-6 mt-1 mb-2 rounded-md bg-gray-50 p-3 text-sm dark:bg-gray-900",children:[i.jsx("p",{className:"text-gray-600 dark:text-gray-400",children:D.description}),D.affected_tools.length>0&&i.jsxs("div",{className:"mt-2",children:[i.jsxs("span",{className:"text-xs font-medium text-gray-500",children:["Affected tools:"," "]}),D.affected_tools.map(j=>i.jsx("span",{className:"mr-1 rounded bg-gray-200 px-1.5 py-0.5 text-xs dark:bg-gray-800",children:j},j))]}),D.fix_hint&&i.jsxs("div",{className:"mt-2 rounded border border-blue-200 bg-blue-50 p-2 text-xs text-blue-800 dark:border-blue-900 dark:bg-blue-950 dark:text-blue-300",children:["Suggestion: ",D.fix_hint]})]})]},D.id))})]},M))]})}function zg(){const[f,m]=L.useState(null),[g,d]=L.useState(null),[N,T]=L.useState(!1),[E,C]=L.useState(null),{data:M}=Ll("/servers"),Z=(M==null?void 0:M.servers)??[];async function D(R){m(R),T(!0),C(null);try{const Y=await Mn(`/validate/${R}/run`,{method:"POST"});d(Y)}catch(Y){C(Y instanceof Error?Y.message:String(Y))}finally{T(!1)}}async function j(R){m(R),T(!0),C(null);try{const Y=await Mn(`/validate/${R}`);d(Y)}catch(Y){C(Y instanceof Error?Y.message:String(Y))}finally{T(!1)}}return i.jsxs("div",{className:"space-y-6",children:[i.jsxs("div",{className:"flex items-center justify-between",children:[i.jsx("h1",{className:"text-2xl font-bold",children:"Compliance"}),f&&i.jsx("button",{onClick:()=>D(f),disabled:N,className:"rounded-md bg-indigo-600 px-4 py-2 text-sm font-medium text-white hover:bg-indigo-500 disabled:opacity-50",children:N?"Validating...":"Re-run Validation"})]}),!f&&i.jsx("div",{children:Z.length===0?i.jsx(_a,{title:"No servers configured",description:"Configure MCP servers in hdx.toml, then validate protocol compliance."}):i.jsxs("div",{className:"space-y-2",children:[i.jsx("p",{className:"text-sm text-gray-500",children:"Select a server to validate:"}),Z.map(R=>i.jsxs("button",{onClick:()=>j(R.name),className:"flex w-full items-center gap-3 rounded-lg border border-gray-200 p-4 text-left hover:border-indigo-300 hover:bg-indigo-50 dark:border-gray-800 dark:hover:border-indigo-800 dark:hover:bg-indigo-950",children:[i.jsx("span",{className:`h-2.5 w-2.5 rounded-full ${R.status==="connected"?"bg-emerald-500":"bg-gray-400"}`}),i.jsx("span",{className:"font-medium",children:R.name})]},R.name))]})}),N&&i.jsx(pe,{message:"Running validation..."}),E&&i.jsx("div",{className:"rounded-lg border border-red-200 bg-red-50 p-4 dark:border-red-900 dark:bg-red-950",children:i.jsx("p",{className:"text-sm text-red-700 dark:text-red-400",children:E})}),g&&!N&&i.jsxs("div",{className:"space-y-6",children:[i.jsx("div",{className:"rounded-lg border border-gray-200 p-6 dark:border-gray-800",children:i.jsx(Sg,{score:g.score,passed:g.passed,failed:g.failed,warned:g.warned,total:g.total_rules})}),i.jsx(Ng,{rules:g.rules})]})]})}function Ag(){return i.jsx(jh,{children:i.jsx(Sh,{children:i.jsxs(Jt,{element:i.jsx(kh,{}),children:[i.jsx(Jt,{index:!0,element:i.jsx(Fh,{})}),i.jsx(Jt,{path:"agents",element:i.jsx(Ih,{})}),i.jsx(Jt,{path:"agents/:name",element:i.jsx(lg,{})}),i.jsx(Jt,{path:"eval",element:i.jsx(cg,{})}),i.jsx(Jt,{path:"eval/:runId",element:i.jsx(fg,{})}),i.jsx(Jt,{path:"playground",element:i.jsx(gg,{})}),i.jsx(Jt,{path:"analytics",element:i.jsx(jg,{})}),i.jsx(Jt,{path:"compliance",element:i.jsx(zg,{})})]})})})}Bh.createRoot(document.getElementById("root")).render(i.jsx(L.StrictMode,{children:i.jsx(Ag,{})}));
